@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2009-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,7 +26,6 @@
 #include "../fbreader/FBReader.h"
 #include "../options/FBOptions.h"
 #include "../options/FBTextStyle.h"
-#include "../library/Library.h"
 
 const ZLTypeId FBReaderNode::TYPE_ID(ZLBlockTreeNode::TYPE_ID);
 
@@ -41,9 +40,9 @@ private:
 	FBReaderNode &myNode;
 };
 
-std::map<std::string,shared_ptr<ZLImage> > FBReaderNode::ourDefaultCovers;
+std::map<std::string,shared_ptr<const ZLImage> > FBReaderNode::ourDefaultCovers;
 
-FBReaderNode::FBReaderNode(ZLBlockTreeNode *parent, size_t atPosition) : ZLBlockTreeNode(parent, atPosition), myCoverImageIsStored(false), myIsInitialized(false) {
+FBReaderNode::FBReaderNode(ZLBlockTreeNode *parent, std::size_t atPosition) : ZLBlockTreeNode(parent, atPosition), myCoverImageIsStored(false), myIsInitialized(false) {
 }
 
 void FBReaderNode::init() {
@@ -60,7 +59,7 @@ const ZLTypeId &FBReaderNode::typeId() const {
 	return TYPE_ID;
 }
 
-shared_ptr<ZLImage> FBReaderNode::coverImage() const {
+shared_ptr<const ZLImage> FBReaderNode::coverImage() const {
 	if (!myCoverImageIsStored) {
 		myCoverImageIsStored = true;
 		myStoredCoverImage = extractCoverImage();
@@ -73,7 +72,7 @@ void FBReaderNode::drawCover(ZLPaintContext &context, int vOffset) {
 }
 
 void FBReaderNode::drawCoverReal(ZLPaintContext &context, int vOffset) {
-	shared_ptr<ZLImage> cover = coverImage();
+	shared_ptr<const ZLImage> cover = coverImage();
 	if (cover.isNull()) {
 		return;
 	}
@@ -106,7 +105,6 @@ void FBReaderNode::drawCoverReal(ZLPaintContext &context, int vOffset) {
 		height = context.imageHeight(*coverData, w, h, ZLPaintContext::SCALE_REDUCE_SIZE);
 	}
 	context.drawImage(hOffset + (w - width) / 2, vOffset + (h + height) / 2, *coverData, width, height, ZLPaintContext::SCALE_FIT_TO_SIZE);
-	addExtraHyperlinks(hOffset + (w - width) / 2, (h - height) / 2, hOffset + (w + width) / 2, (h + height) / 2);
 }
 
 void FBReaderNode::drawTitle(ZLPaintContext &context, int vOffset) {
@@ -119,16 +117,8 @@ void FBReaderNode::drawTitle(ZLPaintContext &context, int vOffset) {
 		FBOptions::Instance().RegularTextColorOption.value());
 	context.setFont(style.fontFamily(), style.fontSize(), style.bold(), style.italic());
 
-	std::string text;
-	if ((Library::Instance().BasicLibraryViewOption.value()) && !children().empty()) {
-		text = (isOpen()? "- " : "+ ") + title();
-	} else {
-		text = title();
-	}
-	const int stringW = context.stringWidth(text.data(), text.size(), false);
-	const int stringH = context.stringHeight();
+	const std::string text = title();
 	context.drawString(hOffset, vOffset + 2 * unit, text.data(), text.size(), false);
-	addExtraHyperlinks(hOffset, 2 * unit - stringH, hOffset + stringW, 2 * unit);
 }
 
 void FBReaderNode::drawSummary(ZLPaintContext &context, int vOffset) {
@@ -162,9 +152,9 @@ void FBReaderNode::drawHyperlink(ZLPaintContext &context, int &hOffset, int &vOf
 
 	context.setColor(FBOptions::Instance().colorOption("internal").value());
 	context.setFont(
-		style.fontFamily(), 
-		auxiliary ? (7 * style.fontSize() / 15) : (style.fontSize() * 2 / 3), 
-		style.bold(), 
+		style.fontFamily(),
+		auxiliary ? (7 * style.fontSize() / 15) : (style.fontSize() * 2 / 3),
+		style.bold(),
 		style.italic()
 	);
 
@@ -213,12 +203,12 @@ void FBReaderNode::registerExpandTreeAction() {
 	registerAction(new ExpandTreeAction(*this));
 }
 
-shared_ptr<ZLImage> FBReaderNode::defaultCoverImage(const std::string &id) {
-	shared_ptr<ZLImage> cover = ourDefaultCovers[id];
+shared_ptr<const ZLImage> FBReaderNode::defaultCoverImage(const std::string &id) {
+	shared_ptr<const ZLImage> cover = ourDefaultCovers[id];
 	if (cover.isNull()) {
-		cover = new ZLFileImage("image/auto",
-			ZLibrary::ApplicationImageDirectory() + ZLibrary::FileNameDelimiter + id,
-			0);
+		cover = new ZLFileImage(
+			ZLFile(ZLibrary::ApplicationImageDirectory() + ZLibrary::FileNameDelimiter + id), 0
+		);
 		ourDefaultCovers[id] = cover;
 	}
 	return cover;
@@ -232,13 +222,9 @@ int FBReaderNode::height(ZLPaintContext &context) const {
 			break;
 		}
 	}
-	if (Library::Instance().BasicLibraryViewOption.value()) {
-		return unitSize(context, FBTextStyle::Instance()) * 3;
-	} else {
-		return
-			unitSize(context, FBTextStyle::Instance()) *
-				(hasAuxHyperlink ? 13 : 11) / 2;
-	}
+	return
+		unitSize(context, FBTextStyle::Instance()) *
+			(hasAuxHyperlink ? 13 : 11) / 2;
 }
 
 int FBReaderNode::unitSize(ZLPaintContext &context, const FBTextStyle &style) const {
@@ -271,34 +257,18 @@ void FBReaderNode::paint(ZLPaintContext &context, int vOffset) {
 
 	removeAllHyperlinks();
 
+	drawCover(context, vOffset);
 	drawTitle(context, vOffset);
+	drawSummary(context, vOffset);
 
-	if (! Library::Instance().BasicLibraryViewOption.value()) {
-		drawCover(context, vOffset);
-		drawSummary(context, vOffset);
-
-		int left = 0;
-		int auxLeft = 0;
-		for (std::vector<std::pair<shared_ptr<ZLRunnableWithKey>,bool> >::const_iterator it = myActions.begin(); it != myActions.end(); ++it) {
-			if (it->first->makesSense()) {
-				if (it->second) {
-					drawHyperlink(context, auxLeft, vOffset, it->first, true);
-				} else {
-					drawHyperlink(context, left, vOffset, it->first);
-				}
-			}
-		}
-	}
-}
-
-void FBReaderNode::addExtraHyperlinks(size_t left, size_t top, size_t right, size_t bottom) {
+	int left = 0;
+	int auxLeft = 0;
 	for (std::vector<std::pair<shared_ptr<ZLRunnableWithKey>,bool> >::const_iterator it = myActions.begin(); it != myActions.end(); ++it) {
 		if (it->first->makesSense()) {
-			std::string actionName = it->first->key().Name;
-
-			if ((actionName == "read") || (actionName == (isOpen() ? "collapseTree" : "expandTree"))) {
-				addHyperlink(left, top, right, bottom, it->first);
-				return;
+			if (it->second) {
+				drawHyperlink(context, auxLeft, vOffset, it->first, true);
+			} else {
+				drawHyperlink(context, left, vOffset, it->first);
 			}
 		}
 	}
