@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
 
 #include <ZLImage.h>
 #include <ZLLogger.h>
+#include <ZLTextStyleEntry.h>
 
 #include "BookReader.h"
 #include "BookModel.h"
@@ -29,7 +30,6 @@ BookReader::BookReader(BookModel &model) : myModel(model) {
 	myCurrentTextModel = 0;
 	myLastTOCParagraphIsEmpty = false;
 
-	myTextParagraphExists = false;
 	myContentsParagraphExists = false;
 
 	myInsideTitle = false;
@@ -49,12 +49,24 @@ void BookReader::setFootnoteTextModel(const std::string &id) {
 		myCurrentTextModel = (*it).second;
 	} else {
 		myCurrentTextModel = new ZLTextPlainModel(myModel.myBookTextModel->language(), 8192);
-		myModel.myFootnotes.insert(std::pair<std::string,shared_ptr<ZLTextModel> >(id, myCurrentTextModel));
+		myModel.myFootnotes.insert(std::make_pair(id, myCurrentTextModel));
 	}
 }
 
+bool BookReader::paragraphIsOpen() const {
+	if (myCurrentTextModel.isNull()) {
+		return false;
+	}
+	for (std::list<shared_ptr<ZLTextModel> >::const_iterator it = myModelsWithOpenParagraphs.begin(); it != myModelsWithOpenParagraphs.end(); ++it) {
+		if (*it == myCurrentTextModel) {
+			return true;
+		}
+	}
+	return false;
+}
+
 void BookReader::unsetTextModel() {
-	myCurrentTextModel = 0;
+	myCurrentTextModel.reset();
 }
 
 void BookReader::pushKind(FBTextKind kind) {
@@ -74,27 +86,28 @@ bool BookReader::isKindStackEmpty() const {
 }
 
 void BookReader::beginParagraph(ZLTextParagraph::Kind kind) {
+	endParagraph();
 	if (myCurrentTextModel != 0) {
 		((ZLTextPlainModel&)*myCurrentTextModel).createParagraph(kind);
 		for (std::vector<FBTextKind>::const_iterator it = myKindStack.begin(); it != myKindStack.end(); ++it) {
 			myCurrentTextModel->addControl(*it, true);
 		}
 		if (!myHyperlinkReference.empty()) {
-			myCurrentTextModel->addHyperlinkControl(myHyperlinkKind, myHyperlinkReference, myHyperlinkType);
+			myCurrentTextModel->addHyperlinkControl(myHyperlinkKind, myHyperlinkType, myHyperlinkReference);
 		}
-		myTextParagraphExists = true;
+		myModelsWithOpenParagraphs.push_back(myCurrentTextModel);
 	}
 }
 
 void BookReader::endParagraph() {
-	if (myTextParagraphExists) {
+	if (paragraphIsOpen()) {
 		flushTextBufferToParagraph();
-		myTextParagraphExists = false;
+		myModelsWithOpenParagraphs.remove(myCurrentTextModel);
 	}
 }
 
 void BookReader::addControl(FBTextKind kind, bool start) {
-	if (myTextParagraphExists) {
+	if (paragraphIsOpen()) {
 		flushTextBufferToParagraph();
 		myCurrentTextModel->addControl(kind, start);
 	}
@@ -103,43 +116,57 @@ void BookReader::addControl(FBTextKind kind, bool start) {
 	}
 }
 
-void BookReader::addFixedHSpace(unsigned char length) {
-	if (myTextParagraphExists) {
-		myCurrentTextModel->addFixedHSpace(length);
+void BookReader::addStyleEntry(const ZLTextStyleEntry &entry) {
+	if (paragraphIsOpen()) {
+		flushTextBufferToParagraph();
+		myCurrentTextModel->addStyleEntry(entry);
 	}
 }
 
-void BookReader::addControl(const ZLTextStyleEntry &entry) {
-	if (myTextParagraphExists) {
+void BookReader::addStyleCloseEntry() {
+	addControl(REGULAR, false); //used instead in XHTMLReader
+	//TODO implement ZLTextModel::addStyleCloseEntry()
+//	if (paragraphIsOpen()) {
+//		flushTextBufferToParagraph();
+//		myCurrentTextModel->addStyleCloseEntry();
+//	}
+}
+
+void BookReader::addFixedHSpace(unsigned char length) {
+	if (paragraphIsOpen()) {
 		flushTextBufferToParagraph();
-		myCurrentTextModel->addControl(entry);
+		myCurrentTextModel->addFixedHSpace(length);
 	}
 }
 
 void BookReader::addHyperlinkControl(FBTextKind kind, const std::string &label) {
 	myHyperlinkKind = kind;
+	std::string type;
 	switch (myHyperlinkKind) {
 		case INTERNAL_HYPERLINK:
 		case FOOTNOTE:
-			myHyperlinkType = "internal";
+			myHyperlinkType = HYPERLINK_INTERNAL;
+			type = "internal";
 			break;
 		case EXTERNAL_HYPERLINK:
-			myHyperlinkType = "external";
+			myHyperlinkType = HYPERLINK_EXTERNAL;
+			type = "external";
 			break;
 		case BOOK_HYPERLINK:
-			myHyperlinkType = "book";
+			myHyperlinkType = HYPERLINK_BOOK;
+			type = "book";
 			break;
 		default:
-			myHyperlinkType.erase();
+			myHyperlinkType = HYPERLINK_NONE;
 			break;
 	}
 	ZLLogger::Instance().println(
 		"hyperlink",
-		" + control (" + myHyperlinkType + "): " + label
+		" + control (" + type + "): " + label
 	);
-	if (myTextParagraphExists) {
+	if (paragraphIsOpen()) {
 		flushTextBufferToParagraph();
-		myCurrentTextModel->addHyperlinkControl(kind, label, myHyperlinkType);
+		myCurrentTextModel->addHyperlinkControl(kind, myHyperlinkType, label);
 	}
 	myHyperlinkReference = label;
 }
@@ -147,7 +174,7 @@ void BookReader::addHyperlinkControl(FBTextKind kind, const std::string &label)
 void BookReader::addHyperlinkLabel(const std::string &label) {
 	if (!myCurrentTextModel.isNull()) {
 		int paragraphNumber = myCurrentTextModel->paragraphsNumber();
-		if (myTextParagraphExists) {
+		if (paragraphIsOpen()) {
 			--paragraphNumber;
 		}
 		addHyperlinkLabel(label, paragraphNumber);
@@ -159,15 +186,13 @@ void BookReader::addHyperlinkLabel(const std::string &label, int paragraphNumber
 		"hyperlink",
 		" + label: " + label
 	);
-	myModel.myInternalHyperlinks.insert(
-		std::pair<std::string,BookModel::Label>(
-			label, BookModel::Label(myCurrentTextModel, paragraphNumber)
-		)
-	);
+	myModel.myInternalHyperlinks.insert(std::make_pair(
+		label, BookModel::Label(myCurrentTextModel, paragraphNumber)
+	));
 }
 
 void BookReader::addData(const std::string &data) {
-	if (!data.empty() && myTextParagraphExists) {
+	if (!data.empty() && paragraphIsOpen()) {
 		if (!myInsideTitle) {
 			mySectionContainsRegularContents = true;
 		}
@@ -192,8 +217,8 @@ void BookReader::addImage(const std::string &id, shared_ptr<const ZLImage> image
 
 void BookReader::insertEndParagraph(ZLTextParagraph::Kind kind) {
 	if ((myCurrentTextModel != 0) && mySectionContainsRegularContents) {
-		size_t size = myCurrentTextModel->paragraphsNumber();
-		if ((size > 0) && (((*myCurrentTextModel)[(size_t)-1])->kind() != kind)) {
+		std::size_t size = myCurrentTextModel->paragraphsNumber();
+		if ((size > 0) && (((*myCurrentTextModel)[(std::size_t)-1])->kind() != kind)) {
 			((ZLTextPlainModel&)*myCurrentTextModel).createParagraph(kind);
 			mySectionContainsRegularContents = false;
 		}
@@ -211,7 +236,7 @@ void BookReader::insertEndOfTextParagraph() {
 void BookReader::addImageReference(const std::string &id, short vOffset) {
 	if (myCurrentTextModel != 0) {
 		mySectionContainsRegularContents = true;
-		if (myTextParagraphExists) {
+		if (paragraphIsOpen()) {
 			flushTextBufferToParagraph();
 			myCurrentTextModel->addImage(id, myModel.imageMap(), vOffset);
 		} else {
@@ -265,7 +290,7 @@ void BookReader::endContentsParagraph() {
 	myContentsParagraphExists = false;
 }
 
-void BookReader::setReference(size_t contentsParagraphNumber, int referenceNumber) {
+void BookReader::setReference(std::size_t contentsParagraphNumber, int referenceNumber) {
 	ContentsModel &contentsModel = (ContentsModel&)*myModel.myContentsModel;
 	if (contentsParagraphNumber >= contentsModel.paragraphsNumber()) {
 		return;
