@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,16 +21,19 @@
 #define __BOOKREADER_H__
 
 #include <vector>
+#include <list>
 #include <stack>
 #include <string>
 
 #include <ZLTextParagraph.h>
 
+#include "FBHyperlinkType.h"
 #include "FBTextKind.h"
 
 class BookModel;
 class ZLTextModel;
 class ZLInputStream;
+class ZLTextStyleEntry;
 
 class BookReader {
 
@@ -53,7 +56,8 @@ public:
 	void endParagraph();
 	bool paragraphIsOpen() const;
 	void addControl(FBTextKind kind, bool start);
-	void addControl(const ZLTextStyleEntry &entry);
+	void addStyleEntry(const ZLTextStyleEntry &entry);
+	void addStyleCloseEntry(); //TODO reimplement
 	void addHyperlinkControl(FBTextKind kind, const std::string &label);
 	void addHyperlinkLabel(const std::string &label);
 	void addHyperlinkLabel(const std::string &label, int paragraphNumber);
@@ -65,7 +69,7 @@ public:
 	void beginContentsParagraph(int referenceNumber = -1);
 	void endContentsParagraph();
 	bool contentsParagraphIsOpen() const;
-	void setReference(size_t contentsParagraphNumber, int referenceNumber);
+	void setReference(std::size_t contentsParagraphNumber, int referenceNumber);
 
 	void addData(const std::string &data);
 	void addContentsData(const std::string &data);
@@ -84,10 +88,10 @@ private:
 private:
 	BookModel &myModel;
 	shared_ptr<ZLTextModel> myCurrentTextModel;
+	std::list<shared_ptr<ZLTextModel> > myModelsWithOpenParagraphs;
 
 	std::vector<FBTextKind> myKindStack;
 
-	bool myTextParagraphExists;
 	bool myContentsParagraphExists;
 	std::stack<ZLTextTreeParagraph*> myTOCStack;
 	bool myLastTOCParagraphIsEmpty;
@@ -99,14 +103,10 @@ private:
 	std::vector<std::string> myContentsBuffer;
 
 	std::string myHyperlinkReference;
-	std::string myHyperlinkType;
+	FBHyperlinkType myHyperlinkType;
 	FBTextKind myHyperlinkKind;
 };
 
-inline bool BookReader::paragraphIsOpen() const {
-	return myTextParagraphExists;
-}
-
 inline bool BookReader::contentsParagraphIsOpen() const {
 	return myContentsParagraphExists;
 }
