@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -90,8 +90,8 @@ int BookTextView::readStackPos(const Book &book) {
 
 void BookTextView::saveBookState(const Book &book) {
 	const ReadingState state(
-		ZLIntegerOption(ZLCategoryKey::STATE, LAST_STATE_GROUP, PARAGRAPH_OPTION_NAME, 0).value(), 
-		ZLIntegerOption(ZLCategoryKey::STATE, LAST_STATE_GROUP, WORD_OPTION_NAME, 0).value(), 
+		ZLIntegerOption(ZLCategoryKey::STATE, LAST_STATE_GROUP, PARAGRAPH_OPTION_NAME, 0).value(),
+		ZLIntegerOption(ZLCategoryKey::STATE, LAST_STATE_GROUP, WORD_OPTION_NAME, 0).value(),
 		ZLIntegerOption(ZLCategoryKey::STATE, LAST_STATE_GROUP, CHAR_OPTION_NAME, 0).value()
 	);
 	const int stackPos = ZLIntegerOption(ZLCategoryKey::STATE, LAST_STATE_GROUP, POSITION_IN_BUFFER, 0).value();
@@ -272,7 +272,7 @@ void BookTextView::redoPageMove() {
 	}
 }
 
-bool BookTextView::getHyperlinkInfo(const ZLTextElementRectangle &rectangle, std::string &id, std::string &type) const {
+bool BookTextView::getHyperlinkInfo(const ZLTextElementRectangle &rectangle, std::string &id, ZLHyperlinkType &type) const {
 	if ((rectangle.Kind != ZLTextElement::WORD_ELEMENT) &&
 			(rectangle.Kind != ZLTextElement::IMAGE_ELEMENT)) {
 		return false;
@@ -308,12 +308,12 @@ bool BookTextView::onStylusClick(int x, int y, int count) {
 	const ZLTextElementRectangle *rectangle = textArea().elementByCoordinates(x, y);
 	if (rectangle != 0) {
 		std::string id;
-		std::string type;
+		ZLHyperlinkType type;
 		if (getHyperlinkInfo(*rectangle, id, type)) {
 			fbreader.tryShowFootnoteView(id, type);
 			return true;
 		}
-		
+
 		if (fbreader.isDictionarySupported() &&
 				fbreader.EnableSingleClickDictionaryOption.value()) {
 			const std::string txt = word(*rectangle);
@@ -329,19 +329,19 @@ bool BookTextView::onStylusClick(int x, int y, int count) {
 
 bool BookTextView::_onStylusRelease(int x, int y) {
 	FBReader &fbreader = FBReader::Instance();
-	if (isPressProcessed()) {
+	if (!isReleasedWithoutMotion()) {
 		return false;
 	}
 
 	const ZLTextElementRectangle *rectangle = textArea().elementByCoordinates(x, y);
 	if (rectangle != 0) {
 		std::string id;
-		std::string type;
+		ZLHyperlinkType type;
 		if (getHyperlinkInfo(*rectangle, id, type)) {
 			fbreader.tryShowFootnoteView(id, type);
 			return true;
 		}
-		
+
 		if (fbreader.isDictionarySupported() &&
 				fbreader.EnableSingleClickDictionaryOption.value()) {
 			const std::string txt = word(*rectangle);
@@ -358,7 +358,7 @@ bool BookTextView::_onStylusRelease(int x, int y) {
 bool BookTextView::_onStylusMove(int x, int y) {
 	const ZLTextElementRectangle *rectangle = textArea().elementByCoordinates(x, y);
 	std::string id;
-	std::string type;
+	ZLHyperlinkType type;
 	FBReader::Instance().setHyperlinkCursor((rectangle != 0) && getHyperlinkInfo(*rectangle, id, type));
 	return true;
 }
@@ -380,16 +380,16 @@ void BookTextView::PositionIndicatorWithLabels::draw() {
 		if (!contentsModelPtr.isNull()) {
 			ContentsModel &contentsModel = (ContentsModel&)*contentsModelPtr;
 			const int marksNumber = contentsModel.paragraphsNumber();
-			const size_t startIndex = startTextIndex();
-			const size_t endIndex = endTextIndex();
-			const std::vector<size_t> &textSizeVector = textSize();
+			const std::size_t startIndex = startTextIndex();
+			const std::size_t endIndex = endTextIndex();
+			const std::vector<std::size_t> &textSizeVector = textSize();
 			const int fullWidth = right() - left() - 1;
-			const size_t startPosition = textSizeVector[startIndex];
-			const size_t fullTextSize = textSizeVector[endIndex] - startPosition;
+			const std::size_t startPosition = textSizeVector[startIndex];
+			const std::size_t fullTextSize = textSizeVector[endIndex] - startPosition;
 			const int bottom = this->bottom();
 			const int top = this->top();
 			for (int i = 0; i < marksNumber; ++i) {
-				size_t reference = contentsModel.reference((ZLTextTreeParagraph*)contentsModel[i]);
+				std::size_t reference = contentsModel.reference((ZLTextTreeParagraph*)contentsModel[i]);
 				if ((startIndex < reference) && (reference < endIndex)) {
 					int position = left() + 2 + (int)
 						(1.0 * fullWidth * (textSizeVector[reference] - startPosition) / fullTextSize);
