@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2008-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,9 +20,9 @@
 #include "FBReader.h"
 #include "FBReaderActions.h"
 
-BooksOrderAction::BooksOrderAction(const std::string &actionId) : ModeDependentAction(FBReader::LIBRARY_MODE), myActionId(actionId) {
+BooksOrderAction::BooksOrderAction() : ModeDependentAction(FBReader::LIBRARY_MODE) {
 }
 
 void BooksOrderAction::run() {
-	FBReader::Instance().showLibraryView(myActionId);
+	FBReader::Instance().showLibraryView();
 }
