@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@ public:
 	~ContentsView();
 
 	bool isEmpty() const;
-	size_t currentTextViewParagraph(bool includeStart = true) const;
+	std::size_t currentTextViewParagraph(bool includeStart = true) const;
 	void gotoReference();
 
 private:
