@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 #include <ZLMessage.h>
 #include <ZLTimeManager.h>
 #include <ZLLogger.h>
+#include <ZLNetworkManager.h>
 
 #include <ZLTextStyleCollection.h>
 #include <ZLTextHyphenator.h>
@@ -40,25 +41,25 @@
 #include "FootnoteView.h"
 #include "ContentsView.h"
 #include "RecentBooksPopupData.h"
-#include "BookInfoDialog.h"
+#include "PreferencesPopupData.h"
 #include "TimeUpdater.h"
-#include "FBColorSchemeFileHandler.h"
 
 #include "../libraryTree/LibraryView.h"
 #include "../network/NetworkLinkCollection.h"
 #include "../networkActions/NetworkOperationRunnable.h"
-#include "../networkTree/NetworkView.h"
 
 #include "../migration/migrate.h"
 
 #include "../options/FBCategoryKey.h"
-#include "../options/FBOptions.h"
 #include "../bookmodel/BookModel.h"
+#include "../bookmodel/FBHyperlinkType.h"
 #include "../formats/FormatPlugin.h"
 
 #include "../database/booksdb/BooksDB.h"
 #include "../database/booksdb/BooksDBUtil.h"
 #include "../library/Book.h"
+#include "../networkActions/AuthenticationDialog.h"
+#include "../network/NetworkErrors.h"
 
 static const std::string OPTIONS = "Options";
 
@@ -72,7 +73,7 @@ public:
 			FBReader &fbreader = FBReader::Instance();
 			fbreader.myBookAlreadyOpen = true;
 			fbreader.presentWindow();
-			fbreader.openFile(arguments[0]);
+			fbreader.openFile(ZLFile(arguments[0]));
 		}
 	}
 };
@@ -84,13 +85,14 @@ FBReader &FBReader::Instance() {
 FBReader::FBReader(const std::string &bookToOpen) :
 	ZLApplication("FBReader"),
 	QuitOnCancelOption(ZLCategoryKey::CONFIG, OPTIONS, "QuitOnCancel", false),
-	AlwaysStartInLibraryOption(ZLCategoryKey::CONFIG, OPTIONS, "AlwaysStartInLibrary", false),
-	StartFullscreenOption(ZLCategoryKey::CONFIG, OPTIONS, "StartFullscreen", false),
 	KeyScrollingDelayOption(ZLCategoryKey::CONFIG, "Scrollings", "Delay", 0, 2000, 100),
 	LinesToScrollOption(ZLCategoryKey::CONFIG, "SmallScrolling", "LinesToScroll", 1, 20, 1),
 	LinesToKeepOption(ZLCategoryKey::CONFIG, "LargeScrolling", "LinesToKeepOption", 0, 20, 0),
+	EnableTapScrollingOption(ZLCategoryKey::CONFIG, "TapScrolling", "Enabled", true),
+	TapScrollingOnFingerOnlyOption(ZLCategoryKey::CONFIG, "TapScrolling", "FingerOnly", true),
 	UseSeparateBindingsOption(ZLCategoryKey::CONFIG, "KeysOptions", "UseSeparateBindings", false),
 	EnableSingleClickDictionaryOption(ZLCategoryKey::CONFIG, "Dictionary", "SingleClick", false),
+	LastOpenedPreferencesDialog(ZLCategoryKey::CONFIG, "PreferencesDialog", "LastOpened", ""),
 	myBindings0(new ZLKeyBindings("Keys")),
 	myBindings90(new ZLKeyBindings("Keys90")),
 	myBindings180(new ZLKeyBindings("Keys180")),
@@ -102,24 +104,27 @@ FBReader::FBReader(const std::string &bookToOpen) :
 	myBookTextView = new BookTextView(*context());
 	myFootnoteView = new FootnoteView(*context());
 	myContentsView = new ContentsView(*context());
-	myNetworkLibraryView = new NetworkView(*context());
+
 	myLibraryByAuthorView = new LibraryByAuthorView(*context());
 	myLibraryByTagView = new LibraryByTagView(*context());
-	myLibraryByBookView = new LibraryByBookView(*context());
 	myRecentBooksPopupData = new RecentBooksPopupData();
+	myPreferencesPopupData = new PreferencesPopupData();
 	myMode = UNDEFINED_MODE;
 	myPreviousMode = BOOK_TEXT_MODE;
 	setMode(BOOK_TEXT_MODE);
 
-	addAction(ActionCode::SHOW_READING, new BookViewOption());
+	addAction(ActionCode::SHOW_READING, new UndoAction(FBReader::ALL_MODES & ~FBReader::BOOK_TEXT_MODE));
 	addAction(ActionCode::SHOW_LIBRARY, new SetModeAction(FBReader::LIBRARY_MODE, FBReader::BOOK_TEXT_MODE | FBReader::CONTENTS_MODE));
-	addAction(ActionCode::SHOW_NETWORK_LIBRARY, new ShowNetworkLibraryAction());
-	addAction(ActionCode::SEARCH_ON_NETWORK, new SimpleSearchOnNetworkAction());
-	addAction(ActionCode::ADVANCED_SEARCH_ON_NETWORK, new AdvancedSearchOnNetworkAction());
+	addAction(ActionCode::SHOW_NETWORK_LIBRARY, new ShowNetworkTreeLibraryAction());
 	registerPopupData(ActionCode::SHOW_LIBRARY, myRecentBooksPopupData);
 	addAction(ActionCode::SHOW_OPTIONS_DIALOG, new ShowOptionsDialogAction());
 	addAction(ActionCode::SHOW_TOC, new ShowContentsAction());
 	addAction(ActionCode::SHOW_BOOK_INFO_DIALOG, new ShowBookInfoAction());
+	addAction(ActionCode::SHOW_LIBRARY_OPTIONS_DIALOG, new ShowLibraryOptionsDialogAction());
+	addAction(ActionCode::SHOW_NETWORK_OPTIONS_DIALOG, new ShowNetworkOptionsDialogAction());
+	addAction(ActionCode::SHOW_SYSTEM_OPTIONS_DIALOG, new ShowSystemOptionsDialogAction());
+	addAction(ActionCode::SHOW_READING_OPTIONS_DIALOG, new ShowReadingOptionsDialogAction());
+	addAction(ActionCode::SHOW_LOOKANDFEEL_OPTIONS_DIALOG, new ShowLookAndFeelOptionsDialogAction());
 	addAction(ActionCode::ADD_BOOK, new AddBookAction(FBReader::BOOK_TEXT_MODE | FBReader::LIBRARY_MODE | FBReader::CONTENTS_MODE));
 	addAction(ActionCode::UNDO, new UndoAction(FBReader::BOOK_TEXT_MODE));
 	addAction(ActionCode::REDO, new RedoAction());
@@ -155,15 +160,17 @@ FBReader::FBReader(const std::string &bookToOpen) :
 	addAction(ActionCode::CLEAR_SELECTION, new ClearSelectionAction());
 	addAction(ActionCode::GOTO_PAGE_NUMBER, new GotoPageNumberAction(std::string()));
 	addAction(ActionCode::GOTO_PAGE_NUMBER_WITH_PARAMETER, new GotoPageNumberAction(PageIndexParameter));
-	addAction(ActionCode::ORGANIZE_BOOKS_BY_AUTHOR, new BooksOrderAction(ActionCode::ORGANIZE_BOOKS_BY_AUTHOR));
-	addAction(ActionCode::ORGANIZE_BOOKS_BY_TAG, new BooksOrderAction(ActionCode::ORGANIZE_BOOKS_BY_TAG));
-	addAction(ActionCode::ORGANIZE_BOOKS_BY_NAME, new BooksOrderAction(ActionCode::ORGANIZE_BOOKS_BY_NAME));
+	shared_ptr<Action> booksOrderAction = new BooksOrderAction();
+	addAction(ActionCode::ORGANIZE_BOOKS_BY_AUTHOR, booksOrderAction);
+	addAction(ActionCode::ORGANIZE_BOOKS_BY_TAG, booksOrderAction);
 	addAction(ActionCode::FILTER_LIBRARY, new FilterLibraryAction());
-	addAction(ActionCode::SAVE_COLOR_SCHEME, new SaveColorSchemeAction());
-	addAction(ActionCode::LOAD_COLOR_SCHEME, new LoadColorSchemeAction());
+
+	registerPopupData(ActionCode::SHOW_OPTIONS_DIALOG, myPreferencesPopupData);
 
 	myOpenFileHandler = new OpenFileHandler();
 	ZLCommunicationManager::Instance().registerHandler("openFile", myOpenFileHandler);
+
+	ZLNetworkManager::Instance().setUserAgent(std::string("FBReader/") + VERSION);
 }
 
 FBReader::~FBReader() {
@@ -184,14 +191,7 @@ void FBReader::initWindow() {
 	if (!myBookAlreadyOpen) {
 		shared_ptr<Book> book;
 		if (!myBookToOpen.empty()) {
-			createBook(myBookToOpen, book);
-		}
-		if ((book.isNull()) && AlwaysStartInLibraryOption.value()) {
-			book = BooksDBUtil::getBook(helpFileName(ZLibrary::Language()));
-
-			if (book.isNull()) {
-				book = BooksDBUtil::getBook(helpFileName("en"));
-			}
+			createBook(ZLFile(myBookToOpen), book);
 		}
 		if (book.isNull()) {
 			const BookList &books = Library::Instance().recentBooks();
@@ -209,33 +209,20 @@ void FBReader::initWindow() {
 	}
 	refreshWindow();
 
-#ifdef MAEMO_VERSION
-	// Update clock once a minute on Maemo, to save battery power
-	ZLTimeManager::Instance().addTask(new TimeUpdater(), 60000);
-#else
 	ZLTimeManager::Instance().addTask(new TimeUpdater(), 1000);
-#endif
-
-	if (AlwaysStartInLibraryOption.value()) {
-		setMode(LIBRARY_MODE);
-	}
-	if (StartFullscreenOption.value()) {
-		doAction(ActionCode::FULLSCREEN_ON);
-	}
 }
 
 void FBReader::refreshWindow() {
 	ZLApplication::refreshWindow();
 	((RecentBooksPopupData&)*myRecentBooksPopupData).updateId();
+	((PreferencesPopupData&)*myPreferencesPopupData).updateId();
 }
 
-bool FBReader::createBook(const std::string& fileName, shared_ptr<Book> &book) {
-	ZLFile bookFile = ZLFile(fileName);
-
+bool FBReader::createBook(const ZLFile &bookFile, shared_ptr<Book> &book) {
 	shared_ptr<FormatPlugin> plugin =
-		PluginCollection::Instance().plugin(ZLFile(fileName), false);
+		PluginCollection::Instance().plugin(bookFile, false);
 	if (!plugin.isNull()) {
-		std::string error = plugin->tryOpen(fileName);
+		std::string error = plugin->tryOpen(bookFile);
 		if (!error.empty()) {
 			ZLResourceKey boxKey("openBookErrorBox");
 			ZLDialogManager::Instance().errorBox(
@@ -272,7 +259,7 @@ bool FBReader::createBook(const std::string& fileName, shared_ptr<Book> &book) {
 			ZLFile subFile(itemName);
 			if (subFile.isArchive()) {
 				archiveNames.push(itemName);
-			} else if (createBook(itemName, book)) {
+			} else if (createBook(subFile, book)) {
 				return true;
 			}
 		}
@@ -285,22 +272,23 @@ bool FBReader::createBook(const std::string& fileName, shared_ptr<Book> &book) {
 class OpenBookRunnable : public ZLRunnable {
 
 public:
-	OpenBookRunnable(shared_ptr<Book> book, bool forceReload) : myBook(book), myForceReload(forceReload) {}
-	void run() { FBReader::Instance().openBookInternal(myBook, myForceReload); }
+	OpenBookRunnable(shared_ptr<Book> book) : myBook(book) {}
+	void run() { FBReader::Instance().openBookInternal(myBook); }
 
 private:
 	shared_ptr<Book> myBook;
-    bool myForceReload;
 };
 
-void FBReader::openBook(shared_ptr<Book> book, bool forceReload) {
-	OpenBookRunnable runnable(book, forceReload);
+void FBReader::openBook(shared_ptr<Book> book) {
+	OpenBookRunnable runnable(book);
 	ZLDialogManager::Instance().wait(ZLResourceKey("loadingBook"), runnable);
+	if (!book.isNull()) {
+		showBookTextView();
+	}
 	resetWindowCaption();
-	refreshWindow();
 }
 
-void FBReader::openBookInternal(shared_ptr<Book> book, bool forceReload) {
+void FBReader::openBookInternal(shared_ptr<Book> book) {
 	if (!book.isNull()) {
 		BookTextView &bookTextView = (BookTextView&)*myBookTextView;
 		ContentsView &contentsView = (ContentsView&)*myContentsView;
@@ -310,15 +298,9 @@ void FBReader::openBookInternal(shared_ptr<Book> book, bool forceReload) {
 		bookTextView.setModel(0, 0);
 		bookTextView.setContentsModel(0);
 		contentsView.setModel(0);
-
-		if ((myModel.isNull()) ||
-                (book->filePath() != myModel->book()->filePath()) ||
-				forceReload) {
-			myModel.reset();
-			myModel = new BookModel(book);
-			ZLTextHyphenator::Instance().load(book->language());
-		}
-
+		myModel.reset();
+		myModel = new BookModel(book);
+		ZLTextHyphenator::Instance().load(book->language());
 		bookTextView.setModel(myModel->bookTextModel(), book);
 		bookTextView.setCaption(book->title());
 		bookTextView.setContentsModel(myModel->contentsModel());
@@ -330,7 +312,6 @@ void FBReader::openBookInternal(shared_ptr<Book> book, bool forceReload) {
 		Library::Instance().addBook(book);
 		Library::Instance().addBookToRecentList(book);
 		((RecentBooksPopupData&)*myRecentBooksPopupData).updateId();
-		showBookTextView();
 	}
 }
 
@@ -352,39 +333,43 @@ void FBReader::openLinkInBrowser(const std::string &url) const {
 	program->run("openLink", copy);
 }
 
-void FBReader::tryShowFootnoteView(const std::string &id, const std::string &type) {
-	if (type == "external") {
-		openLinkInBrowser(id);
-	} else if (type == "internal") {
-		if (myMode == BOOK_TEXT_MODE && !myModel.isNull()) {
-			BookModel::Label label = myModel->label(id);
-			if (!label.Model.isNull()) {
-				if (label.Model == myModel->bookTextModel()) {
-					bookTextView().gotoParagraph(label.ParagraphNumber);
-				} else {
-					FootnoteView &view = ((FootnoteView&)*myFootnoteView);
-					view.setModel(label.Model);
-					setMode(FOOTNOTE_MODE);
-					view.gotoParagraph(label.ParagraphNumber);
+void FBReader::tryShowFootnoteView(const std::string &id, ZLHyperlinkType type) {
+	switch (type) {
+		case HYPERLINK_EXTERNAL:
+			openLinkInBrowser(id);
+			break;
+		case HYPERLINK_INTERNAL:
+			if (myMode == BOOK_TEXT_MODE && !myModel.isNull()) {
+				BookModel::Label label = myModel->label(id);
+				if (!label.Model.isNull()) {
+					if (label.Model == myModel->bookTextModel()) {
+						bookTextView().gotoParagraph(label.ParagraphNumber);
+					} else {
+						FootnoteView &view = ((FootnoteView&)*myFootnoteView);
+						view.setModel(label.Model);
+						setMode(FOOTNOTE_MODE);
+						view.gotoParagraph(label.ParagraphNumber);
+					}
+					setHyperlinkCursor(false);
+					refreshWindow();
 				}
-				setHyperlinkCursor(false);
-				refreshWindow();
 			}
-		}
-	} else if (type == "book") {
-		DownloadBookRunnable downloader(id);
-		downloader.executeWithUI();
-		if (downloader.hasErrors()) {
-			downloader.showErrorMessage();
-		} else {
-			shared_ptr<Book> book;
-			createBook(downloader.fileName(), book);
-			if (!book.isNull()) {
-				Library::Instance().addBook(book);
-				openBook(book);
-				refreshWindow();
-			}
-		}
+			break;
+		case HYPERLINK_BOOK:
+//		DownloadBookRunnable downloader(id);
+//		downloader.executeWithUI();
+//		if (downloader.hasErrors()) {
+//			downloader.showErrorMessage();
+//		} else {
+//			shared_ptr<Book> book;
+//			createBook(ZLFile(downloader.fileName()), book);
+//			if (!book.isNull()) {
+//				Library::Instance().addBook(book);
+//				openBook(book);
+//				refreshWindow();
+//			}
+//		}
+			break;
 	}
 }
 
@@ -399,22 +384,13 @@ bool FBReader::isViewFinal() const {
 void FBReader::showLibraryView() {
 	if (ZLStringOption(ZLCategoryKey::LOOK_AND_FEEL, "ToggleButtonGroup", "booksOrder", "").value() == ActionCode::ORGANIZE_BOOKS_BY_TAG) {
 		setView(myLibraryByTagView);
-	} else if (ZLStringOption(ZLCategoryKey::LOOK_AND_FEEL, "ToggleButtonGroup", "booksOrder", "").value() == ActionCode::ORGANIZE_BOOKS_BY_AUTHOR) {
-		setView(myLibraryByAuthorView);
 	} else {
-		setView(myLibraryByBookView);
+		setView(myLibraryByAuthorView);
 	}
 }
 
-void FBReader::showLibraryView(const std::string &actionId) {
-	if (ZLStringOption(ZLCategoryKey::LOOK_AND_FEEL, "ToggleButtonGroup", "booksOrder", "").value() != actionId) {
-		setToolbarToggle(actionId);
-	}
-
-	showLibraryView();
-}
-
 void FBReader::setMode(ViewMode mode) {
+	//TODO remove code for old network library view
 	if (mode == myMode) {
 		return;
 	}
@@ -428,9 +404,6 @@ void FBReader::setMode(ViewMode mode) {
 
 	switch (myMode) {
 		case BOOK_TEXT_MODE:
-			if (! EnablePopupMenuOption.value()) {
-				checkFullscreenSetup(true);
-			}
 			setHyperlinkCursor(false);
 			((ZLTextView&)*myBookTextView).forceScrollbarUpdate();
 			setView(myBookTextView);
@@ -444,21 +417,14 @@ void FBReader::setMode(ViewMode mode) {
 			break;
 		case LIBRARY_MODE:
 		{
-			if (! EnablePopupMenuOption.value()) {
-				checkFullscreenSetup(false);
-			}
 			shared_ptr<Book> currentBook = myModel->book();
 			((LibraryView&)*myLibraryByAuthorView).showBook(currentBook);
 			((LibraryView&)*myLibraryByTagView).showBook(currentBook);
-			((LibraryView&)*myLibraryByBookView).showBook(currentBook);
 			showLibraryView();
 			break;
 		}
 		case BOOKMARKS_MODE:
 			break;
-		case NETWORK_LIBRARY_MODE:
-			setView(myNetworkLibraryView);
-			break;
 		case UNDEFINED_MODE:
 		case ALL_MODES:
 			break;
@@ -493,9 +459,9 @@ std::string FBReader::helpFileName(const std::string &language) const {
 	return ZLibrary::ApplicationDirectory() + ZLibrary::FileNameDelimiter + "help" + ZLibrary::FileNameDelimiter + "MiniHelp." + language + ".fb2";
 }
 
-void FBReader::openFile(const std::string &filePath) {
+void FBReader::openFile(const ZLFile &file) {
 	shared_ptr<Book> book;
-	createBook(filePath, book);
+	createBook(file, book);
 	if (!book.isNull()) {
 		openBook(book);
 		refreshWindow();
@@ -520,12 +486,12 @@ void FBReader::dragFiles(const std::vector<std::string> &filePaths) {
 		case FOOTNOTE_MODE:
 		case CONTENTS_MODE:
 			if (filePaths.size() > 0) {
-				openFile(filePaths[0]);
+				openFile(ZLFile(filePaths[0]));
 			}
 			break;
 		case LIBRARY_MODE:
 			if (filePaths.size() > 0) {
-				openFile(filePaths[0]);
+				openFile(ZLFile(filePaths[0]));
 			}
 			break;
 		default:
@@ -581,33 +547,12 @@ shared_ptr<Book> FBReader::currentBook() const {
 	return myModel->book();
 }
 
-void FBReader::invalidateNetworkView() {
-	((NetworkView &) *myNetworkLibraryView).invalidate();
+bool FBReader::showAuthDialog(const std::string &siteName, std::string &userName, std::string &password, const ZLResourceKey &errorKey) {
+	std::string message = errorKey.Name.empty() ? std::string() : NetworkErrors::errorMessage(errorKey.Name);
+	return AuthenticationDialog::run(siteName, userName, password, message);
 }
 
-void FBReader::invalidateAccountDependents() {
-	((NetworkView &) *myNetworkLibraryView).invalidateAccountDependents();
-}
-
-void FBReader::saveColorScheme() {
-	const ZLResourceKey dialogKey("saveColorSchemeDialog");
-	FBColorSchemeSaveHandler handler;
-	if (ZLDialogManager::Instance().selectionDialog(dialogKey, handler)) {
-		std::string filename = handler.selected();
-
-		saveConfigGroup("Colors", filename);
-	}
-}
-
-void FBReader::loadColorScheme() {
-	const ZLResourceKey dialogKey("loadColorSchemeDialog");
-	FBColorSchemeOpenHandler handler;
-	if (ZLDialogManager::Instance().selectionDialog(dialogKey, handler)) {
-		std::string filename = handler.selected();
-
-		loadConfigGroup("Colors", filename);
-		FBOptions::Instance().resynchColorOptions();
-
-		refreshWindow();
-	}
+void FBReader::saveUserName(const std::string &siteName, std::string &userName) {
+	UserList userList(siteName);
+	userList.saveUser(userName);
 }
