@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,10 +28,12 @@
 #include <ZLView.h>
 #include <ZLApplication.h>
 #include <ZLKeyBindings.h>
+#include <ZLHyperlinkType.h>
 
 #include "../library/Library.h"
 #include "../external/ProgramCollection.h"
 
+class ZLFile;
 class ZLMessageHandler;
 
 class Book;
@@ -45,7 +47,7 @@ public:
 
 public:
 	// returns true if description was found or error message was shown
-	static bool createBook(const std::string &fileName, shared_ptr<Book> &book);
+	static bool createBook(const ZLFile &bookFile, shared_ptr<Book> &book);
 
 	static const std::string PageIndexParameter;
 
@@ -57,23 +59,24 @@ public:
 		CONTENTS_MODE = 1 << 2,
 		BOOKMARKS_MODE = 1 << 3,
 		LIBRARY_MODE = 1 << 4,
-		NETWORK_LIBRARY_MODE = 1 << 5,
 		ALL_MODES = 0xFF
 	};
 
 public:
 	ZLBooleanOption QuitOnCancelOption;
-	ZLBooleanOption AlwaysStartInLibraryOption;
-	ZLBooleanOption StartFullscreenOption;
 
 	ZLIntegerRangeOption KeyScrollingDelayOption;
 	ZLIntegerRangeOption LinesToScrollOption;
 	ZLIntegerRangeOption LinesToKeepOption;
+	ZLBooleanOption EnableTapScrollingOption;
+	ZLBooleanOption TapScrollingOnFingerOnlyOption;
 
 	ZLBooleanOption UseSeparateBindingsOption;
 
 	ZLBooleanOption EnableSingleClickDictionaryOption;
 
+	ZLStringOption LastOpenedPreferencesDialog;
+
 public:
 	FBReader(const std::string &bookToOpen);
 	~FBReader();
@@ -95,14 +98,13 @@ private:
 	bool closeView();
 	std::string helpFileName(const std::string &language) const;
 
-	void openFile(const std::string &filePath);
+	void openFile(const ZLFile &file);
 	bool canDragFiles(const std::vector<std::string> &filePaths) const;
 	void dragFiles(const std::vector<std::string> &filePaths);
 
 	bool isViewFinal() const;
 
 	void showLibraryView();
-	void showLibraryView(const std::string &actionId);
 
 public:
 	shared_ptr<ZLKeyBindings> keyBindings();
@@ -114,21 +116,18 @@ public:
 	shared_ptr<ProgramCollection> webBrowserCollection() const;
 	void openLinkInBrowser(const std::string &url) const;
 
-	void tryShowFootnoteView(const std::string &id, const std::string &type);
+	void tryShowFootnoteView(const std::string &id, ZLHyperlinkType type);
 	BookTextView &bookTextView() const;
 	void showBookTextView();
-	void openBook(shared_ptr<Book> book, bool forceReload = false);
+	void openBook(shared_ptr<Book> book);
 
-	void invalidateNetworkView();
-	void invalidateAccountDependents();
-
-	void saveColorScheme();
-	void loadColorScheme();
+	bool showAuthDialog(const std::string &siteName, std::string &userName, std::string &password, const ZLResourceKey &errorKey);
+	void saveUserName(const std::string &siteName, std::string &userName);
 
 private:
 	shared_ptr<ProgramCollection> dictionaryCollection() const;
 
-	void openBookInternal(shared_ptr<Book> book, bool forceReload);
+	void openBookInternal(shared_ptr<Book> book);
 	friend class OpenBookRunnable;
 	void rebuildCollectionInternal();
 	friend class RebuildCollectionRunnable;
@@ -141,11 +140,11 @@ private:
 	shared_ptr<ZLView> myFootnoteView;
 	shared_ptr<ZLView> myBookTextView;
 	shared_ptr<ZLView> myContentsView;
-	shared_ptr<ZLView> myNetworkLibraryView;
+
 	shared_ptr<ZLView> myLibraryByAuthorView;
 	shared_ptr<ZLView> myLibraryByTagView;
-	shared_ptr<ZLView> myLibraryByBookView;
 	shared_ptr<ZLPopupData> myRecentBooksPopupData;
+	shared_ptr<ZLPopupData> myPreferencesPopupData;
 
 	ZLTime myLastScrollingTime;
 
@@ -171,6 +170,7 @@ private:
 friend class OpenFileHandler;
 
 friend class OptionsDialog;
+friend class SystemOptionsDialog;
 friend class FBView;
 
 //friend class ShowCollectionAction;
@@ -183,7 +183,6 @@ friend class ShowBookInfoAction;
 //friend class ScrollToStartOfTextAction;
 //friend class ScrollToEndOfTextAction;
 friend class UndoAction;
-friend class BookViewOption;
 //friend class RedoAction;
 friend class SearchAction;
 friend class SearchPatternAction;
@@ -200,8 +199,6 @@ friend class GotoNextTOCSectionAction;
 friend class GotoPreviousTOCSectionAction;
 //friend class GotoPageNumber;
 friend class SelectionAction;
-friend class SearchOnNetworkAction;
-friend class AdvancedSearchOnNetworkAction;
 friend class FBFullscreenAction;
 friend class BooksOrderAction;
 friend class LogOutAction;
