@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2008-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,11 +21,16 @@
 
 const std::string ActionCode::SHOW_READING = "showReading";
 const std::string ActionCode::SHOW_LIBRARY = "showLibrary";
-const std::string ActionCode::SHOW_NETWORK_LIBRARY = "showNetLibrary";
+const std::string ActionCode::SHOW_NETWORK_LIBRARY = "showNetworkLibrary";
 const std::string ActionCode::SHOW_TOC = "toc";
 const std::string ActionCode::SHOW_HELP = "showHelp";
 const std::string ActionCode::SHOW_BOOK_INFO_DIALOG = "bookInfo";
 const std::string ActionCode::SHOW_OPTIONS_DIALOG = "preferences";
+const std::string ActionCode::SHOW_LIBRARY_OPTIONS_DIALOG = "libraryOptions";
+const std::string ActionCode::SHOW_NETWORK_OPTIONS_DIALOG = "networkOptions";
+const std::string ActionCode::SHOW_SYSTEM_OPTIONS_DIALOG = "systemOptions";
+const std::string ActionCode::SHOW_READING_OPTIONS_DIALOG = "readingOptions";
+const std::string ActionCode::SHOW_LOOKANDFEEL_OPTIONS_DIALOG = "lookAndFeelOptions";
 const std::string ActionCode::UNDO = "undo";
 const std::string ActionCode::REDO = "redo";
 const std::string ActionCode::SEARCH = "search";
@@ -60,11 +65,6 @@ const std::string ActionCode::CLEAR_SELECTION = "clearSelection";
 const std::string ActionCode::OPEN_SELECTED_TEXT_IN_DICTIONARY = "openInDictionary";
 const std::string ActionCode::GOTO_PAGE_NUMBER = "gotoPageNumber";
 const std::string ActionCode::GOTO_PAGE_NUMBER_WITH_PARAMETER = "gotoPageNumberWithParameter";
-const std::string ActionCode::SEARCH_ON_NETWORK = "searchOnNetwork";
-const std::string ActionCode::ADVANCED_SEARCH_ON_NETWORK = "advancedSearchOnNetwork";
 const std::string ActionCode::ORGANIZE_BOOKS_BY_AUTHOR = "byAuthor";
 const std::string ActionCode::ORGANIZE_BOOKS_BY_TAG = "byTag";
-const std::string ActionCode::ORGANIZE_BOOKS_BY_NAME = "byName";
 const std::string ActionCode::FILTER_LIBRARY = "filterLibrary";
-const std::string ActionCode::SAVE_COLOR_SCHEME = "saveColorScheme";
-const std::string ActionCode::LOAD_COLOR_SCHEME = "loadColorScheme";
