@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,11 +34,16 @@
 #include "FBReaderActions.h"
 #include "BookTextView.h"
 #include "ContentsView.h"
-#include "BookInfoDialog.h"
+#include "../optionsDialog/bookInfo/BookInfoDialog.h"
+#include "../optionsDialog/library/LibraryOptionsDialog.h"
+#include "../optionsDialog/network/NetworkOptionsDialog.h"
+#include "../optionsDialog/system/SystemOptionsDialog.h"
+#include "../optionsDialog/reading/ReadingOptionsDialog.h"
+#include "../optionsDialog/lookAndFeel/OptionsPage.h"
+#include "../optionsDialog/lookAndFeel/LookAndFeelOptionsDialog.h"
 
 #include "../bookmodel/BookModel.h"
 #include "../options/FBTextStyle.h"
-#include "../optionsDialog/OptionsDialog.h"
 
 #include "../database/booksdb/BooksDBUtil.h"
 #include "../database/booksdb/BooksDB.h"
@@ -49,7 +54,7 @@ ModeDependentAction::ModeDependentAction(int visibleInModes) : myVisibleInModes(
 }
 
 bool ModeDependentAction::isVisible() const {
-	return FBReader::Instance().mode() & myVisibleInModes;
+	return (FBReader::Instance().mode() & myVisibleInModes) != 0;
 }
 
 SetModeAction::SetModeAction(FBReader::ViewMode modeToSet, int visibleInModes) : ModeDependentAction(visibleInModes), myModeToSet(modeToSet) {
@@ -75,7 +80,36 @@ void ShowHelpAction::run() {
 }
 
 void ShowOptionsDialogAction::run() {
-	OptionsDialog().dialog().run();
+	std::string actionId = FBReader::Instance().LastOpenedPreferencesDialog.value();
+	if (actionId.empty()) {
+		return;
+	}
+	FBReader::Instance().doAction(actionId);
+}
+
+void ShowLibraryOptionsDialogAction::run() {
+	FBReader::Instance().LastOpenedPreferencesDialog.setValue(ActionCode::SHOW_LIBRARY_OPTIONS_DIALOG);
+	LibraryOptionsDialog().dialog().run();
+}
+
+void ShowNetworkOptionsDialogAction::run() {
+	FBReader::Instance().LastOpenedPreferencesDialog.setValue(ActionCode::SHOW_NETWORK_OPTIONS_DIALOG);
+	NetworkOptionsDialog().dialog().run();
+}
+
+void ShowSystemOptionsDialogAction::run() {
+	FBReader::Instance().LastOpenedPreferencesDialog.setValue(ActionCode::SHOW_SYSTEM_OPTIONS_DIALOG);
+	SystemOptionsDialog().dialog().run();
+}
+
+void ShowReadingOptionsDialogAction::run() {
+	FBReader::Instance().LastOpenedPreferencesDialog.setValue(ActionCode::SHOW_READING_OPTIONS_DIALOG);
+	ReadingOptionsDialog().dialog().run();
+}
+
+void ShowLookAndFeelOptionsDialogAction::run() {
+	FBReader::Instance().LastOpenedPreferencesDialog.setValue(ActionCode::SHOW_LOOKANDFEEL_OPTIONS_DIALOG);
+	LookAndFeelOptionsDialog().dialog().run();
 }
 
 ShowContentsAction::ShowContentsAction() : SetModeAction(FBReader::CONTENTS_MODE, FBReader::BOOK_TEXT_MODE) {
@@ -135,19 +169,10 @@ ShowBookInfoAction::ShowBookInfoAction() : ModeDependentAction(FBReader::BOOK_TE
 
 void ShowBookInfoAction::run() {
 	FBReader &fbreader = FBReader::Instance();
+	fbreader.LastOpenedPreferencesDialog.setValue(ActionCode::SHOW_BOOK_INFO_DIALOG);
 	shared_ptr<Book> book = fbreader.myModel->book();
-
-	std::string oldLanguage = book->language();
-	std::string oldEncoding = book->encoding();
-
 	if (BookInfoDialog(book).dialog().run()) {
-		bool forceReload = false;
-		if ((book->language() != oldLanguage) ||
-				(book->encoding() != oldEncoding)) {
-			forceReload = true;
-		}
-
-		fbreader.openBook(book, forceReload);
+		fbreader.openBook(book);
 		fbreader.refreshWindow();
 	}
 }
@@ -170,20 +195,6 @@ void UndoAction::run() {
 	}
 }
 
-BookViewOption::BookViewOption() : ModeDependentAction(FBReader::ALL_MODES & ~FBReader::BOOK_TEXT_MODE) {
-}
-
-bool BookViewOption::isEnabled() const {
-	return (FBReader::Instance().mode() != FBReader::BOOK_TEXT_MODE);
-}
-
-void BookViewOption::run() {
-	FBReader &fbreader = FBReader::Instance();
-
-	fbreader.restorePreviousMode();
-	fbreader.showBookTextView();
-}
-
 RedoAction::RedoAction() : ModeDependentAction(FBReader::BOOK_TEXT_MODE) {
 }
 
@@ -313,7 +324,7 @@ bool GotoNextTOCSectionAction::isEnabled() const {
 void GotoNextTOCSectionAction::run() {
 	FBReader &fbreader = FBReader::Instance();
 	ContentsView &contentsView = (ContentsView&)*fbreader.myContentsView;
-	size_t current = contentsView.currentTextViewParagraph();
+	std::size_t current = contentsView.currentTextViewParagraph();
 	const ContentsModel &contentsModel = (const ContentsModel&)*contentsView.textArea().model();
 	int reference = contentsModel.reference(((const ZLTextTreeParagraph*)contentsModel[current + 1]));
 	if (reference != -1) {
@@ -362,7 +373,7 @@ bool GotoPreviousTOCSectionAction::isEnabled() const {
 void GotoPreviousTOCSectionAction::run() {
 	FBReader &fbreader = FBReader::Instance();
 	ContentsView &contentsView = (ContentsView&)*fbreader.myContentsView;
-	size_t current = contentsView.currentTextViewParagraph(false);
+	std::size_t current = contentsView.currentTextViewParagraph(false);
 	const ContentsModel &contentsModel = (const ContentsModel&)*contentsView.textArea().model();
 
 	int reference = contentsModel.reference(((const ZLTextTreeParagraph*)contentsModel[current]));
@@ -409,7 +420,7 @@ void GotoPageNumberAction::run() {
 		if (value.empty()) {
 			return;
 		}
-		pageIndex = atoi(value.c_str());
+		pageIndex = std::atoi(value.c_str());
 	} else {
 		shared_ptr<ZLDialog> gotoPageDialog = ZLDialogManager::Instance().createDialog(ZLResourceKey("gotoPageDialog"));
 
@@ -480,11 +491,3 @@ FilterLibraryAction::FilterLibraryAction() : ModeDependentAction(FBReader::LIBRA
 
 void FilterLibraryAction::run() {
 }
-
-void SaveColorSchemeAction::run() {
-	FBReader::Instance().saveColorScheme();
-}
-
-void LoadColorSchemeAction::run() {
-	FBReader::Instance().loadColorScheme();
-}
