@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,6 +36,11 @@ public:
 	static const std::string SHOW_HELP;
 	static const std::string SHOW_OPTIONS_DIALOG;
 	static const std::string SHOW_BOOK_INFO_DIALOG;
+	static const std::string SHOW_LIBRARY_OPTIONS_DIALOG;
+	static const std::string SHOW_NETWORK_OPTIONS_DIALOG;
+	static const std::string SHOW_SYSTEM_OPTIONS_DIALOG;
+	static const std::string SHOW_READING_OPTIONS_DIALOG;
+	static const std::string SHOW_LOOKANDFEEL_OPTIONS_DIALOG;
 	static const std::string UNDO;
 	static const std::string REDO;
 	static const std::string SEARCH;
@@ -70,14 +75,9 @@ public:
 	static const std::string OPEN_SELECTED_TEXT_IN_DICTIONARY;
 	static const std::string GOTO_PAGE_NUMBER;
 	static const std::string GOTO_PAGE_NUMBER_WITH_PARAMETER;
-	static const std::string SEARCH_ON_NETWORK;
-	static const std::string ADVANCED_SEARCH_ON_NETWORK;
 	static const std::string ORGANIZE_BOOKS_BY_AUTHOR;
 	static const std::string ORGANIZE_BOOKS_BY_TAG;
-	static const std::string ORGANIZE_BOOKS_BY_NAME;
 	static const std::string FILTER_LIBRARY;
-	static const std::string SAVE_COLOR_SCHEME;
-	static const std::string LOAD_COLOR_SCHEME;
 
 private:
 	ActionCode();
@@ -117,6 +117,36 @@ public:
 	void run();
 };
 
+class ShowLibraryOptionsDialogAction : public ZLApplication::Action {
+
+public:
+	void run();
+};
+
+class ShowNetworkOptionsDialogAction : public ZLApplication::Action {
+
+public:
+	void run();
+};
+
+class ShowSystemOptionsDialogAction : public ZLApplication::Action {
+
+public:
+	void run();
+};
+
+class ShowReadingOptionsDialogAction : public ZLApplication::Action {
+
+public:
+	void run();
+};
+
+class ShowLookAndFeelOptionsDialogAction : public ZLApplication::Action {
+
+public:
+	void run();
+};
+
 class ShowContentsAction : public SetModeAction {
 
 public:
@@ -124,15 +154,24 @@ public:
 	bool isVisible() const;
 };
 
-class ShowNetworkLibraryAction : public SetModeAction {
+class ShowNetworkTreeLibraryAction : public ZLApplication::Action {
 
 public:
-	ShowNetworkLibraryAction();
-	bool isVisible() const;
+	ShowNetworkTreeLibraryAction();
+
+protected:
+	void run();
 };
 
 class AddBookAction : public ModeDependentAction {
 
+private:
+	class FileFilter;
+
+private:
+	ZLStringOption DirectoryOption;
+	ZLStringOption FileOption;
+
 public:
 	AddBookAction(int visibleInModes);
 	void run();
@@ -177,14 +216,6 @@ public:
 	void run();
 };
 
-class BookViewOption : public ModeDependentAction {
-
-public:
-	BookViewOption();
-	bool isEnabled() const;
-	void run();
-};
-
 class RedoAction : public ModeDependentAction {
 
 public:
@@ -330,7 +361,7 @@ public:
 	void run();
 };
 
-class SearchOnNetworkAction : public ModeDependentAction {
+class SearchOnNetworkAction : ZLApplication::Action {
 
 public:
 	SearchOnNetworkAction();
@@ -364,11 +395,8 @@ public:
 class BooksOrderAction : public ModeDependentAction {
 
 public:
-	BooksOrderAction(const std::string &actionId);
+	BooksOrderAction();
 	void run();
-
-private:
-	const std::string myActionId;
 };
 
 class FilterLibraryAction : public ModeDependentAction {
@@ -378,16 +406,4 @@ public:
 	void run();
 };
 
-class SaveColorSchemeAction : public ZLApplication::Action {
-
-public:
-	void run();
-};
-
-class LoadColorSchemeAction : public ZLApplication::Action {
-
-public:
-	void run();
-};
-
 #endif /* __FBREADERACTIONS_H__ */
