@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,7 +37,6 @@ FBIndicatorStyle::FBIndicatorStyle() :
 	IsSensitiveOption(ZLCategoryKey::LOOK_AND_FEEL, INDICATOR, "TouchSensitive", true),
 	ShowTextPositionOption(ZLCategoryKey::LOOK_AND_FEEL, INDICATOR, "PositionText", false),
 	ShowTimeOption(ZLCategoryKey::LOOK_AND_FEEL, INDICATOR, "Time", false),
-	ButtonOption(ZLCategoryKey::LOOK_AND_FEEL, INDICATOR, "Button", 0, 2, ZLTextPositionIndicatorInfo::BTN_NONE),
 	ColorOption(ZLCategoryKey::LOOK_AND_FEEL, INDICATOR, "Color", ZLColor(127, 127, 127)),
 	HeightOption(ZLCategoryKey::LOOK_AND_FEEL, INDICATOR, "Height", 1, 100, 16),
 	OffsetOption(ZLCategoryKey::LOOK_AND_FEEL, INDICATOR, "Offset", 0, 100, 3),
@@ -48,10 +47,6 @@ ZLTextPositionIndicatorInfo::Type FBIndicatorStyle::type() const {
 	return (ZLTextPositionIndicatorInfo::Type)TypeOption.value();
 }
 
-ZLTextPositionIndicatorInfo::Button FBIndicatorStyle::button() const {
-	return (ZLTextPositionIndicatorInfo::Button)ButtonOption.value();
-}
-
 bool FBIndicatorStyle::isSensitive() const {
 	return IsSensitiveOption.value();
 }
@@ -64,10 +59,6 @@ bool FBIndicatorStyle::isTimeShown() const {
 	return ShowTimeOption.value();
 }
 
-bool FBIndicatorStyle::isButtonShown() const {
-	return ButtonOption.value() != ZLTextPositionIndicatorInfo::BTN_NONE;
-}
-
 ZLColor FBIndicatorStyle::color() const {
 	return ColorOption.value();
 }
@@ -112,14 +103,6 @@ void FBView::doTapScrolling(int y) {
 	}
 }
 
-void FBView::doLineScrolling(bool forward) {
-	if (forward) {
-		FBReader::Instance().doAction(ActionCode::LINE_SCROLL_FORWARD);
-	} else {
-		FBReader::Instance().doAction(ActionCode::LINE_SCROLL_BACKWARD);
-	}
-}
-
 bool FBView::onFingerTap(int, int y) {
 	doTapScrolling(y);
 	return true;
@@ -137,20 +120,21 @@ void FBView::setCaption(const std::string &caption) {
 }
 
 bool FBView::onStylusPress(int x, int y) {
-	ZLView::onStylusPress(x, y);
-
 	if (!myTapScroller.isNull()) {
 		ZLTimeManager::Instance().removeTask(myTapScroller);
 		myTapScroller.reset();
 	}
 
-	setPressProcessed(false);
+	myPressedX = x;
+	myPressedY = y;
+	myIsReleasedWithoutMotion = false;
 
 	if (ZLTextView::onStylusPress(x, y)) {
-		setPressProcessed(true);
 		return true;
 	}
 
+	myIsReleasedWithoutMotion = true;
+	
 	if (_onStylusPress(x, y)) {
 		return true;
 	}
@@ -183,8 +167,6 @@ void FBView::TapScroller::run() {
 }
 
 bool FBView::onStylusRelease(int x, int y) {
-	ZLView::onStylusRelease(x, y);
-
 	const bool hadSelection = !selectionModel().isEmpty();
 
 	if (!myTapScroller.isNull()) {
@@ -200,17 +182,13 @@ bool FBView::onStylusRelease(int x, int y) {
 		return true;
 	}
 
-	// Do scrolling by dragging
-	if (isShortVerticalSwipe()) {
-		doLineScrolling(y<pressedY());
-		return true;
-	} else if (isLongVerticalSwipe()) {
-		doTapScrolling(y>pressedY()? 0:context().height());
-		return true;
-	}
-
-	// Do scrolling by tapping
-	if ((!hadSelection) && isTap()) {
+	FBReader &fbreader = FBReader::Instance();
+	myIsReleasedWithoutMotion =
+		myIsReleasedWithoutMotion && std::abs(x - pressedX()) <= 5 && std::abs(y - pressedY()) <= 5;
+	if (!hadSelection && isReleasedWithoutMotion() &&
+			fbreader.EnableTapScrollingOption.value() &&
+			(!ZLBooleanOption(ZLCategoryKey::EMPTY, ZLOption::PLATFORM_GROUP, ZLOption::FINGER_TAP_DETECTABLE, false).value() ||
+			 !fbreader.TapScrollingOnFingerOnlyOption.value())) {
 		myTapScroller = new TapScroller(*this, y);
 		ZLTimeManager::Instance().addAutoRemovableTask(myTapScroller, doubleClickDelay());
 		return true;
@@ -240,21 +218,11 @@ bool FBView::_onStylusMove(int, int) {
 }
 
 bool FBView::onStylusMovePressed(int x, int y) {
-	ZLView::onStylusMovePressed(x, y);
-
- 	if (isReleasedWithoutMotion()) {
- 		if (!isPressProcessed() && isLongPress() &&
- 				FBReader::Instance().showPopupMenu()) {
- 			setPressProcessed(true);
- 			return true;
- 		}
- 
- 		return false;
- 	}
- 
-	if (isSelectionEnabled() && !isPressProcessed()) {
-		setPressProcessed(true);
-		activateSelection(pressedX(), pressedY());
+	if (myIsReleasedWithoutMotion) {
+		if (std::abs(x - pressedX()) > 5 || std::abs(y - pressedY()) > 5) {
+			myIsReleasedWithoutMotion = false;
+			activateSelection(pressedX(), pressedY());
+		}
 	}
 
 	if (ZLTextView::onStylusMovePressed(x, y)) {
