@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2008-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,13 +29,13 @@ public:
 	void updateId();
 
 private:
-	size_t id() const;
-	size_t count() const;
-	const std::string text(size_t index);
-	void run(size_t index);
+	std::size_t id() const;
+	std::size_t count() const;
+	const std::string text(std::size_t index);
+	void run(std::size_t index);
 
 private:
-	size_t myId;
+	std::size_t myId;
 };
 
 #endif /* __RECENTBOOKSPOPUPDATA_H__ */
