@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2008-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@
  */
 
 #include <ZLStringUtil.h>
+#include <ZLUnicodeUtil.h>
 #include <ZLDialogManager.h>
 #include <ZLDialog.h>
 #include <ZLNetworkManager.h>
@@ -31,41 +32,41 @@
 #include "../network/SearchResult.h"
 #include "../network/authentication/NetworkAuthenticationManager.h"
 #include "../networkActions/NetworkOperationRunnable.h"
+#include "../network/tree/NetworkLibrary.h"
 
 static const std::string SEARCH_PARAMETER_ID = "networkSearchPattern";
 
-ShowNetworkLibraryAction::ShowNetworkLibraryAction() : SetModeAction(FBReader::NETWORK_LIBRARY_MODE, FBReader::BOOK_TEXT_MODE|FBReader::LIBRARY_MODE) {
+ShowNetworkTreeLibraryAction::ShowNetworkTreeLibraryAction()  { }
+
+void ShowNetworkTreeLibraryAction::run() {
+	NetworkLibrary::Instance().showDialog();
 }
 
-bool ShowNetworkLibraryAction::isVisible() const {
-	return SetModeAction::isVisible() && NetworkLinkCollection::Instance().numberOfEnabledLinks() > 0;
-}
-
-SearchOnNetworkAction::SearchOnNetworkAction() : ModeDependentAction(FBReader::NETWORK_LIBRARY_MODE) {
+SearchOnNetworkAction::SearchOnNetworkAction() {
 }
 
 void SearchOnNetworkAction::run() {
-	NetworkLinkCollection &collection = NetworkLinkCollection::Instance();
-	for (size_t i = 0; i < collection.size(); ++i) {
-		NetworkLink &link = collection.link(i);
-		if (link.OnOption.value()) {
-			shared_ptr<NetworkAuthenticationManager> mgr = link.authenticationManager();
-			if (!mgr.isNull()) {
-				IsAuthorisedRunnable checker(*mgr);
-				checker.executeWithUI();
-				if (checker.result() == B3_TRUE && mgr->needsInitialization()) {
-					InitializeAuthenticationManagerRunnable initializer(*mgr);
-					initializer.executeWithUI();
-					if (initializer.hasErrors()) {
-						LogOutRunnable logout(*mgr);
-						logout.executeWithUI();
-					}
-				}
-			}
-		}
-	}
+//	NetworkLinkCollection &collection = NetworkLinkCollection::Instance();
+//	for (std::size_t i = 0; i < collection.size(); ++i) {
+//		NetworkLink &link = collection.link(i);
+//		if (link.isEnabled()) {
+//			shared_ptr<NetworkAuthenticationManager> mgr = link.authenticationManager();
+//			if (!mgr.isNull()) {
+//				IsAuthorisedRunnable checker(*mgr);
+//				checker.executeWithUI();
+//				if (checker.result() == B3_TRUE && mgr->needsInitialization()) {
+//					InitializeAuthenticationManagerRunnable initializer(*mgr);
+//					initializer.executeWithUI();
+//					if (initializer.hasErrors()) {
+//						LogOutRunnable logout(*mgr);
+//						logout.executeWithUI();
+//					}
+//				}
+//			}
+//		}
+//	}
 
-	doSearch();
+//	doSearch();
 }
 
 
@@ -90,7 +91,6 @@ void SimpleSearchOnNetworkAction::doSearch() {
 		SearchResult::setLastSearchResult(summary, result);
 	}
 
-	fbreader.invalidateNetworkView();
 	fbreader.refreshWindow();
 }
 
@@ -114,15 +114,15 @@ void AdvancedSearchOnNetworkAction::doSearch() {
 		searchDialog->acceptValues();
 		searchDialog.reset();
 		std::string titleAndSeriesPattern = titleAndSeriesOption.value();
-		ZLStringUtil::stripWhiteSpaces(titleAndSeriesPattern);
+		ZLUnicodeUtil::utf8Trim(titleAndSeriesPattern);
 		std::string authorPattern = authorOption.value();
-		ZLStringUtil::stripWhiteSpaces(authorPattern);
+		ZLUnicodeUtil::utf8Trim(authorPattern);
 		//std::string seriesPattern = seriesOption.value();
-		//ZLStringUtil::stripWhiteSpaces(seriesPattern);
+		//ZLUnicodeUtil::utf8Trim(seriesPattern);
 		std::string categoryPattern = categoryOption.value();
-		ZLStringUtil::stripWhiteSpaces(categoryPattern);
+		ZLUnicodeUtil::utf8Trim(categoryPattern);
 		std::string descriptionPattern = descriptionOption.value();
-		ZLStringUtil::stripWhiteSpaces(descriptionPattern);
+		ZLUnicodeUtil::utf8Trim(descriptionPattern);
 
 		if (!titleAndSeriesPattern.empty() ||
 				!authorPattern.empty() ||
@@ -144,7 +144,6 @@ void AdvancedSearchOnNetworkAction::doSearch() {
 				SearchResult::setLastSearchResult(summary, result);
 			}
 
-			FBReader::Instance().invalidateNetworkView();
 			FBReader::Instance().refreshWindow();
 		}
 	}
