@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 EncodedTextReader::EncodedTextReader(const std::string &encoding) {
 	ZLEncodingCollection &collection = ZLEncodingCollection::Instance();
 	ZLEncodingConverterInfoPtr info = collection.info(encoding);
-	myConverter = (!info.isNull()) ? info->createConverter() : collection.defaultConverter();
+	myConverter = !info.isNull() ? info->createConverter() : collection.defaultConverter();
 }
 
 EncodedTextReader::~EncodedTextReader() {
