@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,13 +25,15 @@
 
 #include "../library/Book.h"
 
-void FormatPlugin::detectEncodingAndLanguage(Book &book, ZLInputStream &stream) {
+bool FormatPlugin::detectEncodingAndLanguage(Book &book, ZLInputStream &stream, bool force) {
 	std::string language = book.language();
 	std::string encoding = book.encoding();
-	if (!encoding.empty() && !language.empty()) {
-		return;
+	if (!force && !encoding.empty() && !language.empty()) {
+		return true;
 	}
 
+	bool detected = false;
+
 	PluginCollection &collection = PluginCollection::Instance();
 	if (language.empty()) {
 		language = collection.DefaultLanguageOption.value();
@@ -42,31 +44,35 @@ void FormatPlugin::detectEncodingAndLanguage(Book &book, ZLInputStream &stream)
 	if (collection.LanguageAutoDetectOption.value() && stream.open()) {
 		static const int BUFSIZE = 65536;
 		char *buffer = new char[BUFSIZE];
-		const size_t size = stream.read(buffer, BUFSIZE);
+		const std::size_t size = stream.read(buffer, BUFSIZE);
 		stream.close();
 		shared_ptr<ZLLanguageDetector::LanguageInfo> info =
 			ZLLanguageDetector().findInfo(buffer, size);
 		delete[] buffer;
 		if (!info.isNull()) {
+			detected = true;
 			if (!info->Language.empty()) {
 				language = info->Language;
 			}
 			encoding = info->Encoding;
-			if ((encoding == "US-ASCII") || (encoding == "ISO-8859-1")) {
+			if (encoding == "US-ASCII" || encoding == "ISO-8859-1") {
 				encoding = "windows-1252";
 			}
 		}
 	}
 	book.setEncoding(encoding);
 	book.setLanguage(language);
+	return detected;
 }
 
-void FormatPlugin::detectLanguage(Book &book, ZLInputStream &stream) {
+bool FormatPlugin::detectLanguage(Book &book, ZLInputStream &stream, const std::string &encoding, bool force) {
 	std::string language = book.language();
-	if (!language.empty()) {
-		return;
+	if (!force && !language.empty()) {
+		return true;
 	}
 
+	bool detected	= false;
+
 	PluginCollection &collection = PluginCollection::Instance();
 	if (language.empty()) {
 		language = collection.DefaultLanguageOption.value();
@@ -74,25 +80,27 @@ void FormatPlugin::detectLanguage(Book &book, ZLInputStream &stream) {
 	if (collection.LanguageAutoDetectOption.value() && stream.open()) {
 		static const int BUFSIZE = 65536;
 		char *buffer = new char[BUFSIZE];
-		const size_t size = stream.read(buffer, BUFSIZE);
+		const std::size_t size = stream.read(buffer, BUFSIZE);
 		stream.close();
 		shared_ptr<ZLLanguageDetector::LanguageInfo> info =
-			ZLLanguageDetector().findInfo(buffer, size);
+			ZLLanguageDetector().findInfoForEncoding(encoding, buffer, size, -20000);
 		delete[] buffer;
 		if (!info.isNull()) {
 			if (!info->Language.empty()) {
+				detected = true;
 				language = info->Language;
 			}
 		}
 	}
 	book.setLanguage(language);
+	return detected;
 }
 
-const std::string &FormatPlugin::tryOpen(const std::string&) const {
+const std::string &FormatPlugin::tryOpen(const ZLFile&) const {
 	static const std::string EMPTY = "";
 	return EMPTY;
 }
 
-shared_ptr<ZLImage> FormatPlugin::coverImage(const Book &book) const {
+shared_ptr<const ZLImage> FormatPlugin::coverImage(const ZLFile &file) const {
 	return 0;
 }
