@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -53,17 +53,17 @@ public:
 
 	virtual bool providesMetaInfo() const = 0;
 	virtual bool acceptsFile(const ZLFile &file) const = 0;
-	virtual const std::string &iconName() const = 0;
-	virtual FormatInfoPage *createInfoPage(ZLOptionsDialog &dialog, const std::string &path);
+	virtual FormatInfoPage *createInfoPage(ZLOptionsDialog &dialog, const ZLFile &file);
 
-	virtual const std::string &tryOpen(const std::string &path) const;
+	virtual const std::string &tryOpen(const ZLFile &file) const;
 	virtual bool readMetaInfo(Book &book) const = 0;
+	virtual bool readLanguageAndEncoding(Book &book) const = 0;
 	virtual bool readModel(BookModel &model) const = 0;
-	virtual shared_ptr<ZLImage> coverImage(const Book &book) const;
+	virtual shared_ptr<const ZLImage> coverImage(const ZLFile &file) const;
 
 protected:
-	static void detectEncodingAndLanguage(Book &book, ZLInputStream &stream);
-	static void detectLanguage(Book &book, ZLInputStream &stream);
+	static bool detectEncodingAndLanguage(Book &book, ZLInputStream &stream, bool force = false);
+	static bool detectLanguage(Book &book, ZLInputStream &stream, const std::string &encoding, bool force = false);
 };
 
 class PluginCollection {
@@ -94,6 +94,6 @@ inline FormatInfoPage::FormatInfoPage() {}
 inline FormatInfoPage::~FormatInfoPage() {}
 inline FormatPlugin::FormatPlugin() {}
 inline FormatPlugin::~FormatPlugin() {}
-inline FormatInfoPage *FormatPlugin::createInfoPage(ZLOptionsDialog&, const std::string&) { return 0; }
+inline FormatInfoPage *FormatPlugin::createInfoPage(ZLOptionsDialog&, const ZLFile&) { return 0; }
 
 #endif /* __FORMATPLUGIN_H__ */
