@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,6 +34,7 @@
 #include "chm/CHMPlugin.h"
 #include "rtf/RtfPlugin.h"
 #include "openreader/OpenReaderPlugin.h"
+#include "doc/DocPlugin.h"
 //#include "pdf/PdfPlugin.h"
 
 PluginCollection *PluginCollection::ourInstance = 0;
@@ -55,6 +56,7 @@ PluginCollection &PluginCollection::Instance() {
 		ourInstance->myPlugins.push_back(new OEBPlugin());
 		ourInstance->myPlugins.push_back(new RtfPlugin());
 		ourInstance->myPlugins.push_back(new OpenReaderPlugin());
+		ourInstance->myPlugins.push_back(new DocPlugin());
 		//ourInstance->myPlugins.push_back(new PdfPlugin());
 	}
 	return *ourInstance;
@@ -74,7 +76,7 @@ PluginCollection::PluginCollection() :
 }
 
 shared_ptr<FormatPlugin> PluginCollection::plugin(const Book &book) {
-	return plugin(ZLFile(book.filePath()), false);
+	return plugin(book.file(), false);
 }
 
 shared_ptr<FormatPlugin> PluginCollection::plugin(const ZLFile &file, bool strong) {
