@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@ bool BitStream::getBytesDirect(unsigned char *buffer, unsigned int length) {
 	if (myByteStream + length > myByteStreamEnd) {
 		return false;
 	}
-	memcpy(buffer, myByteStream, length);
+	std::memcpy(buffer, myByteStream, length);
 	myByteStream += length;
 	return true;
 }
