@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,11 +21,11 @@
 
 #include "CHMFileImage.h"
 
-CHMFileImage::CHMFileImage(shared_ptr<CHMFileInfo> info, const std::string &entry) : ZLStreamImage("image/auto", 0, 0), myInfo(info), myEntry(entry) {
+CHMFileImage::CHMFileImage(shared_ptr<CHMFileInfo> info, const std::string &entry) : ZLStreamImage(ZLMimeType::IMAGE_AUTO, 0, 0), myInfo(info), myEntry(entry) {
 }
 
 shared_ptr<ZLInputStream> CHMFileImage::inputStream() const {
-	shared_ptr<ZLInputStream> baseStream = ZLFile(myInfo->fileName()).inputStream();
+	shared_ptr<ZLInputStream> baseStream = ZLFile(myInfo->filePath()).inputStream();
 	if (baseStream.isNull() || !baseStream->open()) {
 		return 0;
 	}
