@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -53,7 +53,7 @@ private:
 	CHMFileInfo &myCHMFile;
 	shared_ptr<ZLInputStream> myBase;
 	std::vector<std::string> myEntryNames;
-	size_t myIndex;
+	std::size_t myIndex;
 };
 
 CHMTextStream::CHMTextStream(CHMFileInfo &chmFile, shared_ptr<ZLInputStream> base) : myCHMFile(chmFile), myBase(base) {
@@ -98,13 +98,13 @@ shared_ptr<ZLInputStream> CHMTextStream::nextStream() {
 }
 
 bool CHMPlugin::readMetaInfo(Book &book) const {
-	ZLFile file(book.filePath());
+	const ZLFile &file = book.file();
 	shared_ptr<ZLInputStream> stream = file.inputStream();
 	if (stream.isNull() || !stream->open()) {
 		return false;
 	}
 
-	CHMFileInfo chmFile(book.filePath());
+	CHMFileInfo chmFile(file);
 	if (!chmFile.init(*stream)) {
 		return false;
 	}
@@ -141,6 +141,11 @@ bool CHMPlugin::readMetaInfo(Book &book) const {
 	return true;
 }
 
+bool CHMPlugin::readLanguageAndEncoding(Book &book) const {
+	(void)book;
+	return true;
+}
+
 class CHMHyperlinkMatcher : public BookModel::HyperlinkMatcher {
 
 public:
@@ -152,7 +157,7 @@ BookModel::Label CHMHyperlinkMatcher::match(const std::map<std::string,BookModel
 	if (it != lMap.end()) {
 		return it->second;
 	}
-	size_t index = id.find('#');
+	std::size_t index = id.find('#');
 	if (index != std::string::npos) {
 		it = lMap.find(id.substr(0, index));
 	}
@@ -163,14 +168,14 @@ bool CHMPlugin::readModel(BookModel &model) const {
 	model.setHyperlinkMatcher(new CHMHyperlinkMatcher());
 
 	const Book &book = *model.book();
-	const std::string &filePath = book.filePath();
+	const ZLFile &file = book.file();
 
-	shared_ptr<ZLInputStream> stream = ZLFile(filePath).inputStream();
+	shared_ptr<ZLInputStream> stream = file.inputStream();
 	if (stream.isNull() || !stream->open()) {
 		return false;
 	}
 
-	shared_ptr<CHMFileInfo> info = new CHMFileInfo(filePath);
+	shared_ptr<CHMFileInfo> info = new CHMFileInfo(file);
 	if (!info->init(*stream)) {
 		return false;
 	}
@@ -184,7 +189,7 @@ bool CHMPlugin::readModel(BookModel &model) const {
 
 	referenceCollection.addReference(names.Start, false);
 	referenceCollection.addReference(names.Home, false);
-	
+
 	const std::string &encoding = book.encoding();
 
 	shared_ptr<ZLInputStream> tocStream = info->entryStream(stream, names.TOC);
@@ -204,12 +209,12 @@ bool CHMPlugin::readModel(BookModel &model) const {
 	*/
 
 	int contentCounter = 0;
-	PlainTextFormat format(filePath);
+	PlainTextFormat format(file);
 	HtmlSectionReader reader(model, format, encoding, info, referenceCollection);
 	while (referenceCollection.containsNonProcessedReferences()) {
 		const std::string fileName = referenceCollection.nextReference();
 		if (ZLStringUtil::stringEndsWith(fileName, ".jpg") ||
-		    ZLStringUtil::stringEndsWith(fileName, ".gif")) {
+			ZLStringUtil::stringEndsWith(fileName, ".gif")) {
 			std::string lowerCasedFileName = ZLUnicodeUtil::toLower(fileName);
 			BookReader bookReader(model);
 			bookReader.setMainTextModel();
@@ -245,8 +250,3 @@ bool CHMPlugin::readModel(BookModel &model) const {
 
 	return true;
 }
-
-const std::string &CHMPlugin::iconName() const {
-	static const std::string ICON_NAME = "html";
-	return ICON_NAME;
-}
