@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -96,12 +96,12 @@ bool HHCReader::tagHandler(const HtmlTag &tag) {
 	return true;
 }
 
-bool HHCReader::characterDataHandler(const char*, size_t, bool) {
+bool HHCReader::characterDataHandler(const char*, std::size_t, bool) {
 	return true;
 }
 
 void HHCReader::setReferences() {
-	for (size_t i = 0; i < myReferenceVector.size(); ++i) {
+	for (std::size_t i = 0; i < myReferenceVector.size(); ++i) {
 		myBookReader.setReference(i, myBookReader.model().label(myReferenceVector[i]).ParagraphNumber);
 	}
 }
