@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,25 +22,58 @@
 
 #include <ZLStringUtil.h>
 #include <ZLInputStream.h>
+#include <ZLLogger.h>
 
 #include "StyleSheetParser.h"
 
 StyleSheetTableParser::StyleSheetTableParser(StyleSheetTable &table) : myTable(table) {
+	//ZLLogger::Instance().registerClass("CSS");
 }
 
-void StyleSheetTableParser::storeData(const std::string &tagName, const std::string &className, const StyleSheetTable::AttributeMap &map) {
-	myTable.addMap(tagName, className, map);
+void StyleSheetTableParser::storeData(const std::string &selector, const StyleSheetTable::AttributeMap &map) {
+	std::string s = selector;
+	ZLStringUtil::stripWhiteSpaces(s);
+
+	if (s.empty()) {
+		return;
+	}
+
+	if (s[0] == '@') {
+		processAtRule(s, map);
+		return;
+	}
+
+	const std::vector<std::string> ids = ZLStringUtil::split(s, ",");
+	for (std::vector<std::string>::const_iterator it = ids.begin(); it != ids.end(); ++it) {
+		std::string id = *it;
+		ZLStringUtil::stripWhiteSpaces(id);
+		if (!id.empty()) {
+			const std::size_t index = id.find('.');
+			if (index == std::string::npos) {
+				myTable.addMap(id, std::string(), map);
+			} else {
+				myTable.addMap(id.substr(0, index), id.substr(index + 1), map);
+			}
+		}
+	}
+}
+
+void StyleSheetTableParser::processAtRule(const std::string &name, const StyleSheetTable::AttributeMap &map) {
+	(void)map;
+	if (name == "@font-face") {
+	}
 }
 
 shared_ptr<ZLTextStyleEntry> StyleSheetSingleStyleParser::parseString(const char *text) {
-	myReadState = ATTRIBUTE_NAME;
-	parse(text, strlen(text), true);
+	myReadState = WAITING_FOR_ATTRIBUTE;
+	parse(text, std::strlen(text), true);
 	shared_ptr<ZLTextStyleEntry> control = StyleSheetTable::createControl(myMap);
 	reset();
 	return control;
 }
 
-StyleSheetParser::StyleSheetParser() : myReadState(TAG_NAME), myInsideComment(false) {
+StyleSheetParser::StyleSheetParser() {
+	reset();
 }
 
 StyleSheetParser::~StyleSheetParser() {
@@ -49,15 +82,13 @@ StyleSheetParser::~StyleSheetParser() {
 void StyleSheetParser::reset() {
 	myWord.erase();
 	myAttributeName.erase();
-	myReadState = TAG_NAME;
+	myReadState = WAITING_FOR_SELECTOR;
 	myInsideComment = false;
-	myTagName.erase();
-	myClassName.erase();
+	mySelectorString.erase();
 	myMap.clear();
 }
 
 void StyleSheetParser::parse(ZLInputStream &stream) {
-	parse("body { text-align: justify }", 28);
 	if (stream.open()) {
 		char *buffer = new char[1024];
 		while (true) {
@@ -76,7 +107,7 @@ void StyleSheetParser::parse(const char *text, int len, bool final) {
 	const char *start = text;
 	const char *end = text + len;
 	for (const char *ptr = start; ptr != end; ++ptr) {
-		if (isspace(*ptr)) {
+		if (std::isspace(*ptr)) {
 			if (start != ptr) {
 				myWord.append(start, ptr - start);
 			}
@@ -103,41 +134,64 @@ void StyleSheetParser::parse(const char *text, int len, bool final) {
 }
 
 bool StyleSheetParser::isControlSymbol(const char symbol) {
-	switch (symbol) {
-		case '{':
-		case '}':
-		case ';':
-		case ':':
-			return true;
+	switch (myReadState) {
 		default:
+		case WAITING_FOR_SELECTOR:
 			return false;
+		case SELECTOR:
+			return symbol == '{' || symbol == ';';
+		case WAITING_FOR_ATTRIBUTE:
+			return symbol == '}' || symbol == ':';
+		case ATTRIBUTE_NAME:
+			return symbol == ':';
+		case ATTRIBUTE_VALUE:
+			return symbol == '}' || symbol == ';';
 	}
 }
 
-void StyleSheetParser::storeData(const std::string&, const std::string&, const StyleSheetTable::AttributeMap&) {
+void StyleSheetParser::storeData(const std::string&, const StyleSheetTable::AttributeMap&) {
+}
+
+void StyleSheetParser::processAtRule(const std::string&, const StyleSheetTable::AttributeMap&) {
 }
 
 void StyleSheetParser::processControl(const char control) {
-	switch (control) {
-		case '{':
-			myReadState = (myReadState == TAG_NAME) ? ATTRIBUTE_NAME : BROKEN;
+	switch (myReadState) {
+		case WAITING_FOR_SELECTOR:
 			break;
-		case '}':
-			if (myReadState != BROKEN) {
-				storeData(myTagName, myClassName, myMap);
+		case SELECTOR:
+			switch (control) {
+				case '{':
+					myReadState = WAITING_FOR_ATTRIBUTE;
+					break;
+				case ';':
+					myReadState = WAITING_FOR_SELECTOR;
+					mySelectorString.erase();
+					break;
 			}
-			myReadState = TAG_NAME;
-			myTagName.erase();
-			myClassName.erase();
-			myMap.clear();
 			break;
-		case ';':
-			myReadState =
-				((myReadState == ATTRIBUTE_VALUE) ||
-				 (myReadState == ATTRIBUTE_NAME)) ? ATTRIBUTE_NAME : BROKEN;
+		case WAITING_FOR_ATTRIBUTE:
+			if (control == '}') {
+				myReadState = WAITING_FOR_SELECTOR;
+				storeData(mySelectorString, myMap);
+				mySelectorString.erase();
+				myMap.clear();
+			}
 			break;
-		case ':':
-			myReadState = (myReadState == ATTRIBUTE_NAME) ? ATTRIBUTE_VALUE : BROKEN;
+		case ATTRIBUTE_NAME:
+			if (control == ':') {
+				myReadState = ATTRIBUTE_VALUE;
+			}
+			break;
+		case ATTRIBUTE_VALUE:
+			if (control == ';') {
+				myReadState = WAITING_FOR_ATTRIBUTE;
+			} else if (control == '}') {
+				myReadState = WAITING_FOR_SELECTOR;
+				storeData(mySelectorString, myMap);
+				mySelectorString.erase();
+				myMap.clear();
+			}
 			break;
 	}
 }
@@ -159,38 +213,32 @@ void StyleSheetParser::processWord(std::string &word) {
 		word.erase(0, index + 2);
 	}
 }
-	
-void StyleSheetParser::processWordWithoutComments(const std::string &word) {	
+
+void StyleSheetParser::processWordWithoutComments(const std::string &word) {
 	switch (myReadState) {
-		case TAG_NAME:
-		{
-			int index = word.find('.');
-			if (index == -1) {
-				if (myTagName.empty()) {
-					myTagName = word;
-				} else {
-					myTagName += ' ' + word;
-				}
-			} else {
-				if (myTagName.empty()) {
-					myTagName = word.substr(0, index);
-					myClassName = word.substr(index + 1);
-				} else {
-					myTagName += ' ' + word.substr(0, index);
-					myClassName += ' ' + word.substr(index + 1);
-				}
-			}
-			myMap.clear();
+		case WAITING_FOR_SELECTOR:
+			myReadState = SELECTOR;
+			mySelectorString = word;
 			break;
-		}
+		case SELECTOR:
+			mySelectorString += ' ' + word;
+			break;
+		case WAITING_FOR_ATTRIBUTE:
+			myReadState = ATTRIBUTE_NAME;
+			// go through
 		case ATTRIBUTE_NAME:
 			myAttributeName = word;
 			myMap[myAttributeName].clear();
 			break;
 		case ATTRIBUTE_VALUE:
-			myMap[myAttributeName].push_back(word);
-			break;
-		case BROKEN:
+		{
+			const std::size_t l = word.length();
+			if (l >= 2 && (word[0] == '"' || word[0] == '\'') && word[0] == word[l - 1]) {
+				myMap[myAttributeName].push_back(word.substr(1, l - 2));
+			} else {
+				myMap[myAttributeName].push_back(word);
+			}
 			break;
+		}
 	}
 }
