@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,11 +33,11 @@ bool DocBookPlugin::readMetaInfo(Book &book) const {
 	return DocBookDescriptionReader(book).readMetaInfo(ZLFile(path).inputStream());
 }
 
+bool DocBookPlugin::readLanguageAndEncoding(Book &book) const {
+	(void)book;
+	return true;
+}
+
 bool DocBookPlugin::readModel(BookModel &model) const {
 	return DocBookBookReader(model).readDocument(ZLFile(book.fileName()).inputStream());
 }
-
-const std::string &DocBookPlugin::iconName() const {
-	static const std::string ICON_NAME = "unknown";
-	return ICON_NAME;
-}
