@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,8 +30,8 @@ public:
 	bool providesMetaInfo() const;
 	bool acceptsFile(const std::string &extension) const;
 	bool readMetaInfo(Book &book) const;
+	bool readLanguageAndEncoding(Book &book) const;
 	bool readModel(BookModel &model) const;
-	const std::string &iconName() const;
 };
 
 inline DocBookPlugin::DocBookPlugin() {}
