@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@ DummyMetaInfoReader::DummyMetaInfoReader(Book &book) : myBook(book) {
 }
 
 /*
-void DummyMetaInfoReader::characterDataHandler(const char *text, size_t len) {
+void DummyMetaInfoReader::characterDataHandler(const char *text, std::size_t len) {
 }
 
 void DummyMetaInfoReader::startElementHandler(int tag, const char **) {
