@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -43,15 +43,15 @@ bool DummyPlugin::readMetaInfo(Book &book) const {
 	return DummyMetaInfoReader(book).readMetaInfo(ZLFile(path).inputStream());
 }
 
+bool DummyPlugin::readLanguageAndEncoding(Book &book) const {
+	(void)book;
+	return true;
+}
+
 bool DummyPlugin::readModel(BookModel &model) const {
 	return DummyBookReader(model).readBook(ZLFile(book.fileName()).inputStream());
 }
 
-shared_ptr<ZLImage> DummyPlugin::coverImage(const Book &book) const {
-	return DummyCoverReader(book).readCover();
-}
-
-const std::string &DummyPlugin::iconName() const {
-	static const std::string ICON_NAME = "unknown";
-	return ICON_NAME;
+shared_ptr<const ZLImage> DummyPlugin::coverImage(const ZLFile &file) const {
+	return DummyCoverReader(file).readCover();
 }
