@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,9 +30,9 @@ public:
 	bool providesMetaInfo() const;
 	bool acceptsFile(const ZLFile &file) const;
 	bool readMetaInfo(Book &book) const;
+	bool readLanguageAndEncoding(Book &book) const;
 	bool readModel(BookModel &model) const;
-	const std::string &iconName() const;
-	shared_ptr<ZLImage> coverImage(const Book &book) const;
+	shared_ptr<const ZLImage> coverImage(const ZLFile &file) const;
 };
 
 #endif /* __DUMMYPLUGIN_H__ */
