@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,11 +20,12 @@
 #ifndef __FB2BOOKREADER_H__
 #define __FB2BOOKREADER_H__
 
+#include <ZLMimeType.h>
+
 #include "FB2Reader.h"
 #include "../../bookmodel/BookReader.h"
 
 class BookModel;
-class ZLBase64EncodedImage;
 
 class FB2BookReader : public FB2Reader {
 
@@ -32,23 +33,24 @@ public:
 	FB2BookReader(BookModel &model);
 	bool readBook();
 
+	bool processNamespaces() const;
 	void startElementHandler(int tag, const char **attributes);
 	void endElementHandler(int tag);
-	void characterDataHandler(const char *text, size_t len);
+	void characterDataHandler(const char *text, std::size_t len);
 
 private:
 	int mySectionDepth;
 	int myBodyCounter;
 	bool myReadMainText;
 	bool myInsideCoverpage;
-	size_t myParagraphsBeforeBodyNumber;
+	std::size_t myParagraphsBeforeBodyNumber;
 	std::string myCoverImageReference;
 	bool myInsidePoem;
 	BookReader myModelReader;
 
-	ZLBase64EncodedImage *myCurrentImage;
-	bool myProcessingImage;
-	std::vector<std::string> myImageBuffer;
+	int myCurrentImageStart;
+	std::string myCurrentImageId;
+	shared_ptr<ZLMimeType> myCurrentContentType;
 
 	bool mySectionStarted;
 	bool myInsideTitle;
