@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,28 +20,30 @@
 #ifndef __FB2COVERREADER_H__
 #define __FB2COVERREADER_H__
 
-#include "FB2Reader.h"
+#include <ZLFile.h>
+#include <ZLImage.h>
 
-class Book;
-class ZLImage;
+#include "FB2Reader.h"
 
 class FB2CoverReader : public FB2Reader {
 
 public:
-	FB2CoverReader(const Book &book);
-	shared_ptr<ZLImage> readCover();
+	FB2CoverReader(const ZLFile &file);
+	shared_ptr<const ZLImage> readCover();
 
 private:
+	bool processNamespaces() const;
 	void startElementHandler(int tag, const char **attributes);
 	void endElementHandler(int tag);
-	void characterDataHandler(const char *text, size_t len);
+	void characterDataHandler(const char *text, std::size_t len);
 
 private:
-	const std::string myFilePath;
+	const ZLFile myFile;
 	bool myReadCoverPage;
-	std::string myImageReference;
-	shared_ptr<ZLImage> myImage;
-	std::vector<std::string> myImageBuffer;
+	bool myLookForImage;
+	std::string myImageId;
+	int myImageStart;
+	shared_ptr<const ZLImage> myImage;
 };
 
 #endif /* __FB2COVERREADER_H__ */
