@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -174,12 +174,10 @@ void HtmlImageTagAction::run(const HtmlReader::HtmlTag &tag) {
 		for (unsigned int i = 0; i < tag.Attributes.size(); ++i) {
 			if (tag.Attributes[i].Name == "SRC") {
 				const std::string fileName = MiscUtil::decodeHtmlURL(tag.Attributes[i].Value);
-				const std::string filePath = myReader.myBaseDirPath + fileName;
-				if (ZLFile(filePath).exists()) {
+				const ZLFile file(myReader.myBaseDirPath + fileName);
+				if (file.exists()) {
 					bookReader().addImageReference(fileName);
-					bookReader().addImage(fileName,
-						new ZLFileImage("image/auto", filePath, 0)
-					);
+					bookReader().addImage(fileName, new ZLFileImage(file, 0));
 				}
 				break;
 			}
@@ -403,10 +401,10 @@ HtmlBookReader::HtmlBookReader(const std::string &baseDirectoryPath, BookModel &
 HtmlBookReader::~HtmlBookReader() {
 }
 
-void HtmlBookReader::addConvertedDataToBuffer(const char *text, size_t len, bool convert) {
+void HtmlBookReader::addConvertedDataToBuffer(const char *text, std::size_t len, bool convert) {
 	if (len > 0) {
 		if (myDontBreakParagraph) {
-			while ((len > 0) && isspace(*text)) {
+			while (len > 0 && std::isspace(*text)) {
 				--len;
 				++text;
 			}
@@ -435,7 +433,7 @@ bool HtmlBookReader::tagHandler(const HtmlTag &tag) {
 		if (tag.Attributes[i].Name == "ID") {
 			myBookReader.addHyperlinkLabel(tag.Attributes[i].Value);
 			break;
-		}	
+		}
 	}
 	shared_ptr<HtmlTagAction> action = myActionMap[tag.Name];
 	if (action.isNull()) {
@@ -447,7 +445,7 @@ bool HtmlBookReader::tagHandler(const HtmlTag &tag) {
 	return true;
 }
 
-void HtmlBookReader::preformattedCharacterDataHandler(const char *text, size_t len, bool convert) {
+void HtmlBookReader::preformattedCharacterDataHandler(const char *text, std::size_t len, bool convert) {
 	const char *start = text;
 	const char *end = text + len;
 
@@ -466,7 +464,7 @@ void HtmlBookReader::preformattedCharacterDataHandler(const char *text, size_t l
 				myBookReader.beginParagraph();
 				start = ptr + 1;
 			} else if (mySpaceCounter >= 0) {
-				if (isspace((unsigned char)*ptr)) {
+				if (std::isspace((unsigned char)*ptr)) {
 					++mySpaceCounter;
 				} else {
 					myBookReader.addFixedHSpace(mySpaceCounter);
@@ -477,7 +475,7 @@ void HtmlBookReader::preformattedCharacterDataHandler(const char *text, size_t l
 		addConvertedDataToBuffer(start, end - start, convert);
 	} else if (breakType & PlainTextFormat::BREAK_PARAGRAPH_AT_LINE_WITH_INDENT) {
 		for (const char *ptr = text; ptr != end; ++ptr) {
-			if (isspace((unsigned char)*ptr)) {
+			if (std::isspace((unsigned char)*ptr)) {
 				if (*ptr == '\n') {
 					mySpaceCounter = 0;
 				} else if (mySpaceCounter >= 0) {
@@ -501,7 +499,7 @@ void HtmlBookReader::preformattedCharacterDataHandler(const char *text, size_t l
 		}
 	} else if (breakType & PlainTextFormat::BREAK_PARAGRAPH_AT_EMPTY_LINE) {
 		for (const char *ptr = start; ptr != end; ++ptr) {
-			if (isspace((unsigned char)*ptr)) {
+			if (std::isspace((unsigned char)*ptr)) {
 				if (*ptr == '\n') {
 					++myBreakCounter;
 				}
@@ -519,7 +517,7 @@ void HtmlBookReader::preformattedCharacterDataHandler(const char *text, size_t l
 	}
 }
 
-bool HtmlBookReader::characterDataHandler(const char *text, size_t len, bool convert) {
+bool HtmlBookReader::characterDataHandler(const char *text, std::size_t len, bool convert) {
 	if (!myStyleSheetParser.isNull()) {
 		myStyleSheetParser->parse(text, len);
 		return true;
@@ -538,7 +536,7 @@ bool HtmlBookReader::characterDataHandler(const char *text, size_t len, bool con
 	const char *end = text + len;
 	if (!myIsStarted) {
 		for (; ptr != end; ++ptr) {
-			if (!isspace((unsigned char)*ptr)) {
+			if (!std::isspace((unsigned char)*ptr)) {
 				myIsStarted = true;
 				break;
 			}
