@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,8 +36,7 @@ bool HtmlPlugin::acceptsFile(const ZLFile &file) const {
 }
 
 bool HtmlPlugin::readMetaInfo(Book &book) const {
-	ZLFile file(book.filePath());
-	shared_ptr<ZLInputStream> stream = file.inputStream();
+	shared_ptr<ZLInputStream> stream = book.file().inputStream();
 	if (stream.isNull()) {
 		return false;
 	}
@@ -54,31 +53,31 @@ bool HtmlPlugin::readMetaInfo(Book &book) const {
 
 bool HtmlPlugin::readModel(BookModel &model) const {
 	const Book& book = *model.book();
-	const std::string filePath = book.filePath();
-	shared_ptr<ZLInputStream> stream = ZLFile(filePath).inputStream();
+	const ZLFile &file = book.file();
+	shared_ptr<ZLInputStream> stream = file.inputStream();
 	if (stream.isNull()) {
 		return false;
 	}
 
-	PlainTextFormat format(filePath);
+	PlainTextFormat format(file);
 	if (!format.initialized()) {
 		PlainTextFormatDetector detector;
 		detector.detect(*stream, format);
 	}
 
-	std::string directoryPrefix = MiscUtil::htmlDirectoryPrefix(filePath);
+	std::string directoryPrefix = MiscUtil::htmlDirectoryPrefix(file.path());
 	HtmlBookReader reader(directoryPrefix, model, format, book.encoding());
-	reader.setFileName(MiscUtil::htmlFileName(filePath));
+	reader.setFileName(MiscUtil::htmlFileName(file.path()));
 	reader.readDocument(*stream);
 
 	return true;
 }
 
-const std::string &HtmlPlugin::iconName() const {
-	static const std::string ICON_NAME = "html";
-	return ICON_NAME;
+FormatInfoPage *HtmlPlugin::createInfoPage(ZLOptionsDialog &dialog, const ZLFile &file) {
+	return new PlainTextInfoPage(dialog, file, ZLResourceKey("<PRE>"), false);
 }
 
-FormatInfoPage *HtmlPlugin::createInfoPage(ZLOptionsDialog &dialog, const std::string &filePath) {
-	return new PlainTextInfoPage(dialog, filePath, ZLResourceKey("<PRE>"), false);
+bool HtmlPlugin::readLanguageAndEncoding(Book &book) const {
+	(void)book;
+	return true;
 }
