@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2008-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,23 +26,23 @@
 class HtmlReaderStream : public ZLInputStream {
 
 public:
-	HtmlReaderStream(shared_ptr<ZLInputStream> base, size_t maxSize);
+	HtmlReaderStream(shared_ptr<ZLInputStream> base, std::size_t maxSize);
 	~HtmlReaderStream();
 
 private:
 	bool open();
-	size_t read(char *buffer, size_t maxSize);
+	std::size_t read(char *buffer, std::size_t maxSize);
 	void close();
 
 	void seek(int offset, bool absoluteOffset);
-	size_t offset() const;
-	size_t sizeOfOpened();
+	std::size_t offset() const;
+	std::size_t sizeOfOpened();
 
 private:
 	shared_ptr<ZLInputStream> myBase;
 	char *myBuffer;
-	size_t mySize;
-	size_t myOffset;
+	std::size_t mySize;
+	std::size_t myOffset;
 };
 
 #endif /* __HTMLREADERSTREAM_H__ */
