@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,20 +28,22 @@
 
 #include "../../bookmodel/BookReader.h"
 
+class XHTMLReader;
+
 class OEBBookReader : public ZLXMLReader {
 
 public:
 	OEBBookReader(BookModel &model);
-	bool readBook(const std::string &fileName);
+	bool readBook(const ZLFile &file);
 
 private:
 	void startElementHandler(const char *tag, const char **attributes);
 	void endElementHandler(const char *tag);
 	bool processNamespaces() const;
-	void namespaceListChangedHandler();
+	bool isOPFTag(const std::string &expected, const std::string &tag) const;
 	const std::vector<std::string> &externalDTDs() const;
 
-	void generateTOC();
+	void generateTOC(const XHTMLReader &xhtmlReader);
 
 private:
 	enum ReaderState {
@@ -55,12 +57,12 @@ private:
 	BookReader myModelReader;
 	ReaderState myState;
 
-	std::string myOPFSchemePrefix;
-
 	std::string myFilePrefix;
 	std::map<std::string,std::string> myIdToHref;
+	std::map<std::string,std::string> myHrefToMediatype;
 	std::vector<std::string> myHtmlFileNames;
 	std::string myNCXTOCFileName;
+	std::string myCoverFileName;
 	std::vector<std::pair<std::string,std::string> > myTourTOC;
 	std::vector<std::pair<std::string,std::string> > myGuideTOC;
 };
