@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2009-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,18 +31,26 @@ class OEBCoverReader : public ZLXMLReader {
 
 public:
 	OEBCoverReader();
-	shared_ptr<ZLImage> readCover(const std::string &filePath);
-
-	void startElementHandler(const char *tag, const char **attributes);
-	void endElementHandler(const char *tag);
+	shared_ptr<const ZLImage> readCover(const ZLFile &file);
 
 private:
-	shared_ptr<ZLImage> myImage;
+	void startElementHandler(const char *tag, const char **attributes);
+	void endElementHandler(const char *tag);
+	bool processNamespaces() const;
+
+	void createImage(const char *href);
+
+private:
+	shared_ptr<const ZLImage> myImage;
 	std::string myPathPrefix;
 	std::string myCoverXHTML;
-	bool myReadGuide;
-
-friend class XHTMLImageFinder;
+	std::string myCoverId;
+	enum {
+		READ_NOTHING,
+		READ_METADATA,
+		READ_MANIFEST,
+		READ_GUIDE
+	} myReadState;
 };
 
 #endif /* __OEBCOVERREADER_H__ */
