@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,17 +25,16 @@
 class OEBPlugin : public FormatPlugin {
 
 public:
-	static std::string opfFileName(const std::string &oebFileName);
+	static ZLFile opfFile(const ZLFile &oebFile);
 
 public:
 	~OEBPlugin();
 	bool providesMetaInfo() const;
 	bool acceptsFile(const ZLFile &file) const;
 	bool readMetaInfo(Book &book) const;
+	bool readLanguageAndEncoding(Book &book) const;
 	bool readModel(BookModel &model) const;
-	shared_ptr<ZLImage> coverImage(const Book &book) const;
-
-	const std::string &iconName() const;
+	shared_ptr<const ZLImage> coverImage(const ZLFile &file) const;
 };
 
 #endif /* __OEBPLUGIN_H__ */
