@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2008-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -83,9 +83,9 @@ void XHTMLFilesCollector::endElementHandler(const char *tag) {
 	}
 }
 
-OEBTextStream::OEBTextStream(const std::string &opfFileName) {
-	myFilePrefix = MiscUtil::htmlDirectoryPrefix(opfFileName);
-	XHTMLFilesCollector(myXHTMLFileNames).readDocument(opfFileName);
+OEBTextStream::OEBTextStream(const ZLFile &opfFile) {
+	myFilePrefix = MiscUtil::htmlDirectoryPrefix(opfFile.path());
+	XHTMLFilesCollector(myXHTMLFileNames).readDocument(opfFile);
 }
 
 void OEBTextStream::resetToStart() {
