@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@ public:
 
 	void startElementHandler(const char *tag, const char **attributes);
 	void endElementHandler(const char *tag);
-	void characterDataHandler(const char *text, size_t len);
+	void characterDataHandler(const char *text, std::size_t len);
 
 private:
 	enum ReaderState {
@@ -56,7 +56,7 @@ private:
 	std::map<std::string,std::string> myResources;
 	std::string myCoverReference;
 	std::set<std::string> myHtmlFileIDs;
-	std::map<std::string,std::string> myImageIDs;
+	std::map<std::string,shared_ptr<ZLMimeType> > myImageIDs;
 	std::vector<std::string> myHtmlFilesOrder;
 
 	struct TOCItem {
