@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 #include <ZLFile.h>
 #include <ZLInputStream.h>
 #include <ZLEncodingConverter.h>
-#include <ZLStringUtil.h>
+#include <ZLUnicodeUtil.h>
 #include <ZLLanguageUtil.h>
 #include <ZLImage.h>
 #include <ZLFileImage.h>
@@ -35,17 +35,12 @@ bool MobipocketPlugin::acceptsFile(const ZLFile &file) const {
 	return PdbPlugin::fileType(file) == "BOOKMOBI";
 }
 
-void MobipocketPlugin::readDocumentInternal(const std::string &fileName, BookModel &model, const PlainTextFormat &format, const std::string &encoding, ZLInputStream &stream) const {
-	MobipocketHtmlBookReader(fileName, model, format, encoding).readDocument(stream);
-}
-
-const std::string &MobipocketPlugin::iconName() const {
-	static const std::string ICON_NAME = "mobipocket";
-	return ICON_NAME;
+void MobipocketPlugin::readDocumentInternal(const ZLFile &file, BookModel &model, const PlainTextFormat &format, const std::string &encoding, ZLInputStream &stream) const {
+	MobipocketHtmlBookReader(file, model, format, encoding).readDocument(stream);
 }
 
 bool MobipocketPlugin::readMetaInfo(Book &book) const {
-	shared_ptr<ZLInputStream> stream = ZLFile(book.filePath()).inputStream();
+	shared_ptr<ZLInputStream> stream = book.file().inputStream();
 	if (stream.isNull() || ! stream->open()) {
 		return false;
 	}
@@ -115,11 +110,11 @@ bool MobipocketPlugin::readMetaInfo(Book &book) const {
 							if (index != -1) {
 								std::string part0 = value.substr(0, index);
 								std::string part1 = value.substr(index + 1);
-								ZLStringUtil::stripWhiteSpaces(part0);
-								ZLStringUtil::stripWhiteSpaces(part1);
+								ZLUnicodeUtil::utf8Trim(part0);
+								ZLUnicodeUtil::utf8Trim(part1);
 								value = part1 + ' ' + part0;
 							} else {
-								ZLStringUtil::stripWhiteSpaces(value);
+								ZLUnicodeUtil::utf8Trim(value);
 							}
 							book.addAuthor(value);
 							break;
@@ -142,8 +137,8 @@ bool MobipocketPlugin::readMetaInfo(Book &book) const {
 	return PalmDocLikePlugin::readMetaInfo(book);
 }
 
-shared_ptr<ZLImage> MobipocketPlugin::coverImage(const Book &book) const {
-	shared_ptr<ZLInputStream> stream = ZLFile(book.filePath()).inputStream();
+shared_ptr<const ZLImage> MobipocketPlugin::coverImage(const ZLFile &file) const {
+	shared_ptr<ZLInputStream> stream = file.inputStream();
 	if (stream.isNull() || ! stream->open()) {
 		return 0;
 	}
@@ -215,18 +210,16 @@ shared_ptr<ZLImage> MobipocketPlugin::coverImage(const Book &book) const {
 		coverIndex = thumbIndex;
 	}
 
-	ZLFile file(book.filePath());
 	PalmDocStream pbStream(file);
 	if (!pbStream.open()) {
 		return 0;
 	}
-	int index = pbStream.firstImageLocationIndex(book.filePath());
+	int index = pbStream.firstImageLocationIndex(file.path());
 	if (index >= 0) {
 		std::pair<int,int> imageLocation = pbStream.imageLocation(pbStream.header(), index + coverIndex);
 		if ((imageLocation.first > 0) && (imageLocation.second > 0)) {
 			return new ZLFileImage(
-				"image/auto",
-				book.filePath(),
+				file,
 				imageLocation.first,
 				imageLocation.second
 			);
