@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@ class ZLFile;
 class PalmDocLikeStream : public PdbStream {
 
 public:
-	PalmDocLikeStream(ZLFile &file);
+	PalmDocLikeStream(const ZLFile &file);
 	~PalmDocLikeStream();
 	bool open();
 	
@@ -44,8 +44,8 @@ private:
 
 protected: 
 	unsigned short myMaxRecordSize;
-	size_t myRecordIndex;
-	size_t myMaxRecordIndex;
+	std::size_t myRecordIndex;
+	std::size_t myMaxRecordIndex;
 
 	enum {
 		ERROR_NONE,
