@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@ class HuffDecompressor;
 class PalmDocStream : public PalmDocLikeStream {
 
 public:
-	PalmDocStream(ZLFile &file);
+	PalmDocStream(const ZLFile &file);
 	~PalmDocStream();
 	
 	std::pair<int,int> imageLocation(const PdbHeader &header, int index) const;
