@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -62,3 +62,8 @@ std::string PdbPlugin::fileType(const ZLFile &file) {
 	}
 	return palmType;
 }
+
+bool PdbPlugin::readLanguageAndEncoding(Book &book) const {
+	(void)book;
+	return true;
+}
