@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,6 +28,7 @@ class PdbPlugin : public FormatPlugin {
 
 public:
 	static std::string fileType(const ZLFile &file);
+	bool readLanguageAndEncoding(Book &book) const;
 
 protected:
 	PdbPlugin();
@@ -43,7 +44,6 @@ public:
 	bool acceptsFile(const ZLFile &file) const;
 	bool readMetaInfo(Book &book) const;
 	bool readModel(BookModel &model) const;
-	const std::string &iconName() const;
 };
 
 class SimplePdbPlugin : public PdbPlugin {
@@ -53,41 +53,39 @@ public:
 	bool readModel(BookModel &model) const;
 
 protected:
-	virtual shared_ptr<ZLInputStream> createStream(ZLFile &file) const = 0;
-	virtual void readDocumentInternal(const std::string &fileName, BookModel &model, const class PlainTextFormat &format, const std::string &encoding, ZLInputStream &stream) const;
+	virtual shared_ptr<ZLInputStream> createStream(const ZLFile &file) const = 0;
+	virtual void readDocumentInternal(const ZLFile &file, BookModel &model, const class PlainTextFormat &format, const std::string &encoding, ZLInputStream &stream) const;
 };
 
 class PalmDocLikePlugin : public SimplePdbPlugin {
 
 public:
 	bool providesMetaInfo() const;
-	const std::string &tryOpen(const std::string &path) const;
+	const std::string &tryOpen(const ZLFile &file) const;
 
 protected:
-	shared_ptr<ZLInputStream> createStream(ZLFile &file) const;
+	shared_ptr<ZLInputStream> createStream(const ZLFile &file) const;
 };
 
 class PalmDocPlugin : public PalmDocLikePlugin {
 
 public:
 	bool acceptsFile(const ZLFile &file) const;
-	const std::string &iconName() const;
 
-	void readDocumentInternal(const std::string &fileName, BookModel &model, const class PlainTextFormat &format, const std::string &encoding, ZLInputStream &stream) const;
+	void readDocumentInternal(const ZLFile &file, BookModel &model, const class PlainTextFormat &format, const std::string &encoding, ZLInputStream &stream) const;
 
 private:
-	FormatInfoPage *createInfoPage(ZLOptionsDialog &dialog, const std::string &fileName);
+	FormatInfoPage *createInfoPage(ZLOptionsDialog &dialog, const ZLFile &file);
 };
 
 class MobipocketPlugin : public PalmDocLikePlugin {
 
 private:
 	bool acceptsFile(const ZLFile &file) const;
-	const std::string &iconName() const;
 	bool readMetaInfo(Book &book) const;
 
-	void readDocumentInternal(const std::string &fileName, BookModel &model, const class PlainTextFormat &format, const std::string &encoding, ZLInputStream &stream) const;
-	shared_ptr<ZLImage> coverImage(const Book &book) const;
+	void readDocumentInternal(const ZLFile &file, BookModel &model, const class PlainTextFormat &format, const std::string &encoding, ZLInputStream &stream) const;
+	shared_ptr<const ZLImage> coverImage(const ZLFile &file) const;
 };
 
 class EReaderPlugin : public SimplePdbPlugin {
@@ -95,13 +93,12 @@ class EReaderPlugin : public SimplePdbPlugin {
 public:
 	bool providesMetaInfo() const;
 	bool acceptsFile(const ZLFile &file) const;
-	const std::string &iconName() const;
 	bool readMetaInfo(Book &book) const;
-	const std::string &tryOpen(const std::string &path) const;
+	const std::string &tryOpen(const ZLFile &file) const;
 
-	void readDocumentInternal(const std::string &fileName, BookModel &model, const class PlainTextFormat &format, const std::string &encoding, ZLInputStream &stream) const;
+	void readDocumentInternal(const ZLFile &file, BookModel &model, const class PlainTextFormat &format, const std::string &encoding, ZLInputStream &stream) const;
 protected:
-	shared_ptr<ZLInputStream> createStream(ZLFile &file) const;
+	shared_ptr<ZLInputStream> createStream(const ZLFile &file) const;
 };
 
 class ZTXTPlugin : public SimplePdbPlugin {
@@ -109,13 +106,12 @@ class ZTXTPlugin : public SimplePdbPlugin {
 public:
 	bool providesMetaInfo() const;
 	bool acceptsFile(const ZLFile &file) const;
-	const std::string &iconName() const;
 
 protected:
-	shared_ptr<ZLInputStream> createStream(ZLFile &file) const;
+	shared_ptr<ZLInputStream> createStream(const ZLFile &file) const;
 
 private:
-	FormatInfoPage *createInfoPage(ZLOptionsDialog &dialog, const std::string &fileName);
+	FormatInfoPage *createInfoPage(ZLOptionsDialog &dialog, const ZLFile &file);
 };
 
 inline PdbPlugin::PdbPlugin() {}
