@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -46,7 +46,7 @@ void PdbUtil::readUnsignedLongLE(ZLInputStream &stream, unsigned long &N) {
 }
 
 bool PdbHeader::read(shared_ptr<ZLInputStream> stream) {
-	const size_t startOffset = stream->offset();
+	const std::size_t startOffset = stream->offset();
 	DocName.erase();
 	DocName.append(32, '\0');
 	stream->read((char*)DocName.data(), 32); 			// stream offset: +32
@@ -75,7 +75,7 @@ bool PdbHeader::read(shared_ptr<ZLInputStream> stream) {
 }
 
 /*bool PdbRecord0::read(shared_ptr<ZLInputStream> stream) {
-	size_t startOffset = stream->offset();
+	std::size_t startOffset = stream->offset();
 	
 	PdbUtil::readUnsignedShort(*stream, CompressionType);    
 	PdbUtil::readUnsignedShort(*stream, Spare);          
