@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,6 +27,7 @@
 #include <ZLImage.h>
 #include <ZLFileImage.h>
 #include <ZLFile.h>
+#include <ZLTextStyleEntry.h>
 
 #include "PdbReader.h"
 #include "PluckerBookReader.h"
@@ -35,7 +36,7 @@
 #include "../../bookmodel/BookModel.h"
 #include "../../library/Book.h"
 
-PluckerBookReader::PluckerBookReader(BookModel &model) : BookReader(model), EncodedTextReader(model.book()->encoding()), myFilePath(model.book()->filePath()), myFont(FT_REGULAR) {
+PluckerBookReader::PluckerBookReader(BookModel &model) : BookReader(model), EncodedTextReader(model.book()->encoding()), myFile(model.book()->file()), myFont(FT_REGULAR) {
 	myCharBuffer = new char[65535];
 	myForcedEntry = 0;
 }
@@ -48,7 +49,7 @@ void PluckerBookReader::safeAddControl(FBTextKind kind, bool start) {
 	if (myParagraphStarted) {
 		addControl(kind, start);
 	} else {
-		myDelayedControls.push_back(std::pair<FBTextKind,bool>(kind, start));
+		myDelayedControls.push_back(std::make_pair(kind, start));
 	}
 }
 
@@ -73,7 +74,7 @@ void PluckerBookReader::safeBeginParagraph() {
 			addControl(it->first, it->second);
 		}
 		if (myForcedEntry != 0) {
-			addControl(*myForcedEntry);
+			addStyleEntry(*myForcedEntry);
 		} else {
 			addControl(REGULAR, true);
 		}
@@ -169,16 +170,16 @@ void PluckerBookReader::changeFont(FontType font) {
 /*
 static void listParameters(char *ptr) {
 	int argc = ((unsigned char)*ptr) % 8;
-	std::cerr << (int)(unsigned char)*ptr << "(";	
+	std::cerr << (int)(unsigned char)*ptr << "(";
 	for (int i = 0; i < argc - 1; ++i) {
 		++ptr;
-		std::cerr << (int)*ptr << ", ";	
+		std::cerr << (int)*ptr << ", ";
 	}
 	if (argc > 0) {
 		++ptr;
-		std::cerr << (int)*ptr;	
+		std::cerr << (int)*ptr;
 	}
-	std::cerr << ")\n";	
+	std::cerr << ")\n";
 }
 */
 
@@ -209,7 +210,7 @@ void PluckerBookReader::processTextFunction(char *ptr) {
 			int sectionNum = twoBytes(ptr + 1);
 			int paragraphNum = twoBytes(ptr + 3);
 			safeAddHyperlinkControl(fromNumber(sectionNum) + '#' + fromNumber(paragraphNum));
-			myReferencedParagraphs.insert(std::pair<int,int>(sectionNum, paragraphNum));
+			myReferencedParagraphs.insert(std::make_pair(sectionNum, paragraphNum));
 			break;
 		}
 		case 0x11:
@@ -222,7 +223,7 @@ void PluckerBookReader::processTextFunction(char *ptr) {
 		case 0x22:
 			if (!myParagraphStarted) {
 				if (myForcedEntry == 0) {
-					myForcedEntry = new ZLTextStyleEntry();
+					myForcedEntry = new ZLTextStyleEntry(ZLTextStyleEntry::STYLE_OTHER_ENTRY);
 				}
 				myForcedEntry->setLength(
 					ZLTextStyleEntry::LENGTH_LEFT_INDENT,
@@ -237,7 +238,7 @@ void PluckerBookReader::processTextFunction(char *ptr) {
 		case 0x29:
 			if (!myParagraphStarted) {
 				if (myForcedEntry == 0) {
-					myForcedEntry = new ZLTextStyleEntry();
+					myForcedEntry = new ZLTextStyleEntry(ZLTextStyleEntry::STYLE_OTHER_ENTRY);
 				}
 				switch (*(ptr + 1)) {
 					case 0: myForcedEntry->setAlignmentType(ALIGN_LEFT); break;
@@ -253,7 +254,7 @@ void PluckerBookReader::processTextFunction(char *ptr) {
 		case 0x38:
 			safeEndParagraph();
 			break;
-		case 0x40: 
+		case 0x40:
 			safeAddControl(EMPHASIS, true);
 			break;
 		case 0x48:
@@ -272,7 +273,7 @@ void PluckerBookReader::processTextFunction(char *ptr) {
 			break;
 		case 0x78: // strike-through text is ignored
 			break;
-		case 0x83: 
+		case 0x83:
 		case 0x85:
 		{
 			ZLUnicodeUtil::Ucs4Char symbol =
@@ -337,7 +338,7 @@ void PluckerBookReader::processTextParagraph(char *start, char *end) {
 			if ((unsigned char)*ptr == 0xA0) {
 				*ptr = 0x20;
 			}
-			if (!myParagraphStarted && (textStart == ptr) && isspace((unsigned char)*ptr)) {
+			if (!myParagraphStarted && textStart == ptr && std::isspace((unsigned char)*ptr)) {
 				++textStart;
 			}
 		}
@@ -357,7 +358,7 @@ void PluckerBookReader::processTextParagraph(char *start, char *end) {
 	myDelayedControls.clear();
 }
 
-void PluckerBookReader::processTextRecord(size_t size, const std::vector<int> &pars) {
+void PluckerBookReader::processTextRecord(std::size_t size, const std::vector<int> &pars) {
 	char *start = myCharBuffer;
 	char *end = myCharBuffer;
 
@@ -375,7 +376,7 @@ void PluckerBookReader::processTextRecord(size_t size, const std::vector<int> &p
 	}
 }
 
-void PluckerBookReader::readRecord(size_t recordSize) {
+void PluckerBookReader::readRecord(std::size_t recordSize) {
 	unsigned short uid;
 	PdbUtil::readUnsignedShort(*myStream, uid);
 	if (uid == 1) {
@@ -430,14 +431,14 @@ void PluckerBookReader::readRecord(size_t recordSize) {
 			case 2: // image
 			case 3: // compressed image
 			{
-				static const std::string mime = "image/palm";
 				ZLImage *image = 0;
+				const ZLFile imageFile(myFile.path(), ZLMimeType::IMAGE_PALM);
 				if (type == 2) {
-					image = new ZLFileImage(mime, myFilePath, myStream->offset(), recordSize - 8);
+					image = new ZLFileImage(imageFile, myStream->offset(), recordSize - 8);
 				} else if (myCompressionVersion == 1) {
-					image = new DocCompressedFileImage(mime, myFilePath, myStream->offset(), recordSize - 8);
+					image = new DocCompressedFileImage(imageFile, myStream->offset(), recordSize - 8);
 				} else if (myCompressionVersion == 2) {
-					image = new ZCompressedFileImage(mime, myFilePath, myStream->offset() + 2, recordSize - 10);
+					image = new ZCompressedFileImage(imageFile, myStream->offset() + 2, recordSize - 10);
 				}
 				if (image != 0) {
 					addImage(fromNumber(uid), image);
@@ -482,7 +483,7 @@ void PluckerBookReader::readRecord(size_t recordSize) {
 }
 
 bool PluckerBookReader::readDocument() {
-	myStream = ZLFile(myFilePath).inputStream();
+	myStream = myFile.inputStream();
 	if (myStream.isNull() || !myStream->open()) {
 		return false;
 	}
@@ -497,7 +498,7 @@ bool PluckerBookReader::readDocument() {
 	myFont = FT_REGULAR;
 
 	for (std::vector<unsigned long>::const_iterator it = header.Offsets.begin(); it != header.Offsets.end(); ++it) {
-		size_t currentOffset = myStream->offset();
+		std::size_t currentOffset = myStream->offset();
 		if (currentOffset > *it) {
 			break;
 		}
@@ -505,7 +506,7 @@ bool PluckerBookReader::readDocument() {
 		if (myStream->offset() != *it) {
 			break;
 		}
-		size_t recordSize = ((it != header.Offsets.end() - 1) ? *(it + 1) : myStream->sizeOfOpened()) - *it;
+		std::size_t recordSize = ((it != header.Offsets.end() - 1) ? *(it + 1) : myStream->sizeOfOpened()) - *it;
 		readRecord(recordSize);
 	}
 	myStream->close();
