@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -52,8 +52,8 @@ private:
 		FT_SUP = 11
 	};
 
-	void readRecord(size_t recordSize);
-	void processTextRecord(size_t size, const std::vector<int> &pars);
+	void readRecord(std::size_t recordSize);
+	void processTextRecord(std::size_t size, const std::vector<int> &pars);
 	void processTextParagraph(char *start, char *end);
 	void processTextFunction(char *ptr);
 	void setFont(FontType font, bool start);
@@ -67,7 +67,7 @@ private:
 	void processHeader(FontType font, bool start);
 
 private:
-	std::string myFilePath;
+	const ZLFile myFile;
 	shared_ptr<ZLInputStream> myStream;
 	FontType myFont;
 	char *myCharBuffer;
