@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@ class ZLFile;
 class PluckerTextStream : public PdbStream {
 
 public:
-	PluckerTextStream(ZLFile &file);
+	PluckerTextStream(const ZLFile &file);
 	~PluckerTextStream();
 	bool open();
 	void close();
@@ -36,13 +36,13 @@ private:
 	bool fillBuffer();
 
 private:
-	void processRecord(size_t recordSize);
+	void processRecord(std::size_t recordSize);
 	void processTextParagraph(char *start, char *end);
 
 private:
 	unsigned short myCompressionVersion;
 	char *myFullBuffer;
-	size_t myRecordIndex;
+	std::size_t myRecordIndex;
 };
 
 #endif /* __PLUCKERTEXTSTREAM_H__ */
