@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
 #include "../../library/Book.h"
 
 bool SimplePdbPlugin::readMetaInfo(Book &book) const {
-	ZLFile file(book.filePath());
+	const ZLFile &file = book.file();
 	shared_ptr<ZLInputStream> stream = createStream(file);
 	detectEncodingAndLanguage(book, *stream);
 	if (book.encoding().empty()) {
@@ -54,20 +54,19 @@ bool SimplePdbPlugin::readMetaInfo(Book &book) const {
 
 bool SimplePdbPlugin::readModel(BookModel &model) const {
 	const Book &book = *model.book();
-	const std::string &filePath = book.filePath();
-	ZLFile file(filePath);
+	const ZLFile &file = book.file();
 	shared_ptr<ZLInputStream> stream = createStream(file);
 
-	PlainTextFormat format(filePath);
+	PlainTextFormat format(file);
 	if (!format.initialized()) {
 		PlainTextFormatDetector detector;
 		detector.detect(*stream, format);
 	}
-	readDocumentInternal(filePath, model, format, book.encoding(), *stream);
+	readDocumentInternal(file, model, format, book.encoding(), *stream);
 	return true;
 }
 
-void SimplePdbPlugin::readDocumentInternal(const std::string&, BookModel &model, const PlainTextFormat &format, const std::string &encoding, ZLInputStream &stream) const {
+void SimplePdbPlugin::readDocumentInternal(const ZLFile&, BookModel &model, const PlainTextFormat &format, const std::string &encoding, ZLInputStream &stream) const {
 	if (TextFormatDetector().isHtml(stream)) {
 		HtmlBookReader("", model, format, encoding).readDocument(stream);
 	} else {
