@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@ class ZLFile;
 class ZTXTStream : public PdbStream {
 
 public:
-	ZTXTStream(ZLFile &file);
+	ZTXTStream(const ZLFile &file);
 	~ZTXTStream();
 	bool open();
 
@@ -37,9 +37,9 @@ private:
 	bool fillBuffer();
 
 private:
-	size_t myMaxRecordIndex;
+	std::size_t myMaxRecordIndex;
 	unsigned short myMaxRecordSize;
-	size_t myRecordIndex;
+	std::size_t myRecordIndex;
 };
 
 #endif /* __ZTXTSTREAM_H__ */
