@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,11 +33,10 @@ bool PdfPlugin::readMetaInfo(Book &book) const {
 	return PdfDescriptionReader(book).readMetaInfo(ZLFile(path).inputStream());
 }
 
+bool PdfPlugin::readLanguageAndEncoding(Book &book) const {
+	return true;
+}
+
 bool PdfPlugin::readModel(BookModel &model) const {
 	return PdfBookReader(model).readBook(ZLFile(book.fileName()).inputStream());
 }
-
-const std::string &PdfPlugin::iconName() const {
-	static const std::string ICON_NAME = "unknown";
-	return ICON_NAME;
-}
