@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,13 +27,13 @@
 class RtfTextOnlyReader : public RtfReader {
 
 public:
-	RtfTextOnlyReader(char *buffer, size_t maxSize);
+	RtfTextOnlyReader(char *buffer, std::size_t maxSize);
 	~RtfTextOnlyReader();
-	size_t readSize() const;
+	std::size_t readSize() const;
 
 protected:
-	void addCharData(const char *data, size_t len, bool convert);
-	void insertImage(const std::string &mimeType, const std::string &fileName, size_t startOffset, size_t size);
+	void addCharData(const char *data, std::size_t len, bool convert);
+	void insertImage(shared_ptr<ZLMimeType> mimeType, const std::string &fileName, std::size_t startOffset, std::size_t size);
 	void setEncoding(int code);
 	void switchDestination(DestinationType destination, bool on);
 	void setAlignment();
@@ -51,25 +51,25 @@ private:
 
 private:
 	char* myBuffer;
-	const size_t myMaxSize;
-	size_t myFilledSize;
+	const std::size_t myMaxSize;
+	std::size_t myFilledSize;
 };
 
-RtfTextOnlyReader::RtfTextOnlyReader(char *buffer, size_t maxSize) : RtfReader(std::string()), myBuffer(buffer), myMaxSize(maxSize), myFilledSize(0) {
+RtfTextOnlyReader::RtfTextOnlyReader(char *buffer, std::size_t maxSize) : RtfReader(std::string()), myBuffer(buffer), myMaxSize(maxSize), myFilledSize(0) {
 	myCurrentState.ReadText = true;
 }
 
 RtfTextOnlyReader::~RtfTextOnlyReader() {
 }
 
-void RtfTextOnlyReader::addCharData(const char *data, size_t len, bool) {
+void RtfTextOnlyReader::addCharData(const char *data, std::size_t len, bool) {
 	if (myBuffer == 0) {
 		return;
 	}
 	if (myCurrentState.ReadText) {
 		if (myFilledSize < myMaxSize) {
-			len = std::min((size_t)len, myMaxSize - myFilledSize);
-			memcpy(myBuffer + myFilledSize, data, len);
+			len = std::min((std::size_t)len, myMaxSize - myFilledSize);
+			std::memcpy(myBuffer + myFilledSize, data, len);
 			myFilledSize += len;
 		}
 		if (myFilledSize < myMaxSize) {
@@ -80,11 +80,11 @@ void RtfTextOnlyReader::addCharData(const char *data, size_t len, bool) {
 	}
 }
 
-size_t RtfTextOnlyReader::readSize() const {
+std::size_t RtfTextOnlyReader::readSize() const {
 	return myFilledSize;
 }
 
-void RtfTextOnlyReader::insertImage(const std::string&, const std::string&, size_t, size_t) {
+void RtfTextOnlyReader::insertImage(shared_ptr<ZLMimeType>, const std::string&, std::size_t, std::size_t) {
 }
 
 void RtfTextOnlyReader::setEncoding(int) {
@@ -124,7 +124,7 @@ void RtfTextOnlyReader::newParagraph() {
 void RtfTextOnlyReader::interrupt() {
 }
 
-RtfReaderStream::RtfReaderStream(const std::string& fileName, size_t maxSize) : myFileName(fileName), myBuffer(0), mySize(maxSize) {
+RtfReaderStream::RtfReaderStream(const ZLFile& file, std::size_t maxSize) : myFile(file), myBuffer(0), mySize(maxSize) {
 }
 
 RtfReaderStream::~RtfReaderStream() {
@@ -136,16 +136,16 @@ bool RtfReaderStream::open() {
 		myBuffer = new char[mySize];
 	}
 	RtfTextOnlyReader reader(myBuffer, mySize);
-	reader.readDocument(myFileName);
+	reader.readDocument(myFile);
 	mySize = reader.readSize();
 	myOffset = 0;
 	return true;
 }
 
-size_t RtfReaderStream::read(char *buffer, size_t maxSize) {
+std::size_t RtfReaderStream::read(char *buffer, std::size_t maxSize) {
 	maxSize = std::min(maxSize, mySize - myOffset);
 	if ((buffer != 0) && (myBuffer !=0)) {
-		memcpy(buffer, myBuffer + myOffset, maxSize);
+		std::memcpy(buffer, myBuffer + myOffset, maxSize);
 	}
 	myOffset += maxSize;
 	return maxSize;
@@ -162,14 +162,14 @@ void RtfReaderStream::seek(int offset, bool absoluteOffset) {
 	if (!absoluteOffset) {
 		offset += myOffset;
 	}
-	myOffset = std::min(mySize, (size_t)std::max(0, offset));
+	myOffset = std::min(mySize, (std::size_t)std::max(0, offset));
 }
 
-size_t RtfReaderStream::offset() const {
+std::size_t RtfReaderStream::offset() const {
 	return myOffset;
 }
 
-size_t RtfReaderStream::sizeOfOpened() {
+std::size_t RtfReaderStream::sizeOfOpened() {
 	return mySize;
 }
 
