@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,9 +31,9 @@ public:
 	bool providesMetaInfo() const;
 	bool acceptsFile(const ZLFile &file) const;
 	bool readMetaInfo(Book &book) const;
+	bool readLanguageAndEncoding(Book &book) const;
 	bool readModel(BookModel &model) const;
-	const std::string &iconName() const;
-	FormatInfoPage *createInfoPage(ZLOptionsDialog &dialog, const std::string &fileName);
+	FormatInfoPage *createInfoPage(ZLOptionsDialog &dialog, const ZLFile &file);
 };
 
 inline TcrPlugin::TcrPlugin() {}
