@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,21 +27,21 @@ class ZLFile;
 class TcrStream : public ZLInputStream {
 
 public:
-	TcrStream(ZLFile &file);
+	TcrStream(const ZLFile &file);
 	virtual ~TcrStream();
 	bool open();
 	virtual void close();
 
-	size_t read(char *buffer, size_t maxSize);
+	std::size_t read(char *buffer, std::size_t maxSize);
 	void seek(int offset, bool absoluteOffset);
-	size_t offset() const;
-	size_t sizeOfOpened();
+	std::size_t offset() const;
+	std::size_t sizeOfOpened();
 
 protected:
 	std::string myDictionary[256];
 	std::string myBuffer;
 	shared_ptr<ZLInputStream> myBase;
-	size_t myOffset;
+	std::size_t myOffset;
 };
 
 #endif /* __TCRSTREAM_H__ */
