@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,12 +18,16 @@
  */
 
 #include <cstring>
+#include <cctype>
 
 #include <ZLFile.h>
 #include <ZLFileUtil.h>
 #include <ZLFileImage.h>
 #include <ZLUnicodeUtil.h>
 #include <ZLStringUtil.h>
+#include <ZLXMLNamespace.h>
+#include <ZLInputStream.h>
+#include <ZLLogger.h>
 
 #include "XHTMLReader.h"
 #include "../util/EntityFilesCollector.h"
@@ -33,10 +37,6 @@
 #include "../../bookmodel/BookReader.h"
 #include "../../bookmodel/BookModel.h"
 
-#include "../../constants/XMLNamespace.h"
-
-static const bool USE_CSS = false;
-
 std::map<std::string,XHTMLTagAction*> XHTMLReader::ourTagActions;
 
 XHTMLTagAction::~XHTMLTagAction() {
@@ -188,6 +188,7 @@ void XHTMLTagStyleAction::doAtStart(XHTMLReader &reader, const char **xmlattribu
 	if (reader.myReadState == XHTMLReader::READ_NOTHING) {
 		reader.myReadState = XHTMLReader::READ_STYLE;
 		reader.myTableParser = new StyleSheetTableParser(reader.myStyleSheetTable);
+		ZLLogger::Instance().println("CSS", "parsing style tag content");
 	}
 }
 
@@ -216,10 +217,12 @@ void XHTMLTagLinkAction::doAtStart(XHTMLReader &reader, const char **xmlattribut
 		return;
 	}
 
+	ZLLogger::Instance().println("CSS", "style file: " + reader.myPathPrefix + MiscUtil::decodeHtmlURL(href));
 	shared_ptr<ZLInputStream> cssStream = ZLFile(reader.myPathPrefix + MiscUtil::decodeHtmlURL(href)).inputStream();
 	if (cssStream.isNull()) {
 		return;
 	}
+	ZLLogger::Instance().println("CSS", "parsing file");
 	StyleSheetTableParser parser(reader.myStyleSheetTable);
 	parser.parse(*cssStream);
 	//reader.myStyleSheetTable.dump();
@@ -287,7 +290,8 @@ void XHTMLTagImageAction::doAtStart(XHTMLReader &reader, const char **xmlattribu
 	}
 
 	const std::string fullfileName = pathPrefix(reader) + MiscUtil::decodeHtmlURL(fileName);
-	if (!ZLFile(fullfileName).exists()) {
+	ZLFile imageFile(fullfileName);
+	if (!imageFile.exists()) {
 		return;
 	}
 
@@ -295,11 +299,11 @@ void XHTMLTagImageAction::doAtStart(XHTMLReader &reader, const char **xmlattribu
 	if (flag) {
 		endParagraph(reader);
 	}
-	if ((strlen(fileName) > 2) && strncmp(fileName, "./", 2) == 0) {
+	if (std::strlen(fileName) > 2 && std::strncmp(fileName, "./", 2) == 0) {
 		fileName +=2;
 	}
 	bookReader(reader).addImageReference(fullfileName);
-	bookReader(reader).addImage(fullfileName, new ZLFileImage("image/auto", fullfileName, 0));
+	bookReader(reader).addImage(fullfileName, new ZLFileImage(ZLFile(fullfileName), 0));
 	if (flag) {
 		beginParagraph(reader);
 	}
@@ -316,7 +320,7 @@ void XHTMLTagSvgAction::doAtEnd(XHTMLReader&) {
 	myPredicate.myIsEnabled = false;
 }
 
-XHTMLSvgImageAttributeNamePredicate::XHTMLSvgImageAttributeNamePredicate() : ZLXMLReader::NamespaceAttributeNamePredicate(XMLNamespace::XLink, "href"), myIsEnabled(false) {
+XHTMLSvgImageAttributeNamePredicate::XHTMLSvgImageAttributeNamePredicate() : ZLXMLReader::NamespaceAttributeNamePredicate(ZLXMLNamespace::XLink, "href"), myIsEnabled(false) {
 }
 
 bool XHTMLSvgImageAttributeNamePredicate::accepts(const ZLXMLReader &reader, const char *name) const {
@@ -345,10 +349,11 @@ void XHTMLTagHyperlinkAction::doAtStart(XHTMLReader &reader, const char **xmlatt
 		const FBTextKind hyperlinkType = MiscUtil::referenceType(href);
 		std::string link = MiscUtil::decodeHtmlURL(href);
 		if (hyperlinkType == INTERNAL_HYPERLINK) {
-			link = (link[0] == '#') ?
-				reader.myReferenceName + link :
-				reader.myReferenceDirName + link;
-			link = ZLFileUtil::normalizeUnixPath(link);
+			if (link[0] == '#') {
+				link = reader.myReferenceAlias + link;
+			} else {
+				link = reader.normalizedReference(reader.myReferenceDirName + link);
+			}
 		}
 		myHyperlinkStack.push(hyperlinkType);
 		bookReader(reader).addHyperlinkControl(hyperlinkType, link);
@@ -358,7 +363,7 @@ void XHTMLTagHyperlinkAction::doAtStart(XHTMLReader &reader, const char **xmlatt
 	const char *name = reader.attributeValue(xmlattributes, "name");
 	if (name != 0) {
 		bookReader(reader).addHyperlinkLabel(
-			reader.myReferenceName + "#" + MiscUtil::decodeHtmlURL(name)
+			reader.myReferenceAlias + "#" + MiscUtil::decodeHtmlURL(name)
 		);
 	}
 }
@@ -375,7 +380,7 @@ XHTMLTagParagraphWithControlAction::XHTMLTagParagraphWithControlAction(FBTextKin
 }
 
 void XHTMLTagParagraphWithControlAction::doAtStart(XHTMLReader &reader, const char**) {
-	if ((myControl == TITLE) && (bookReader(reader).model().bookTextModel()->paragraphsNumber() > 1)) {
+	if (myControl == TITLE && bookReader(reader).model().bookTextModel()->paragraphsNumber() > 1) {
 		bookReader(reader).insertEndOfSectionParagraph();
 	}
 	bookReader(reader).pushKind(myControl);
@@ -390,11 +395,10 @@ void XHTMLTagParagraphWithControlAction::doAtEnd(XHTMLReader &reader) {
 void XHTMLTagPreAction::doAtStart(XHTMLReader &reader, const char**) {
 	reader.myPreformatted = true;
 	beginParagraph(reader);
-	bookReader(reader).addControl(CODE, true);
+	bookReader(reader).addControl(PREFORMATTED, true);
 }
 
 void XHTMLTagPreAction::doAtEnd(XHTMLReader &reader) {
-	bookReader(reader).addControl(CODE, false);
 	endParagraph(reader);
 	reader.myPreformatted = false;
 }
@@ -405,22 +409,8 @@ XHTMLTagAction *XHTMLReader::addAction(const std::string &tag, XHTMLTagAction *a
 	return old;
 }
 
-void XHTMLReader::freeTagTable() {
-	if (!ourTagActions.empty()) {
-		for (std::map<std::string,XHTMLTagAction*>::iterator it = ourTagActions.begin(); it != ourTagActions.end(); it++) {
-			XHTMLTagAction *old = it->second;
-			it->second = 0;
-			delete old;
-		}
-
-		ourTagActions.clear();
-	}
-}
-
 void XHTMLReader::fillTagTable() {
 	if (ourTagActions.empty()) {
-		atexit(freeTagTable);
-
 		//addAction("html",	new XHTMLTagAction());
 		addAction("body",	new XHTMLTagBodyAction());
 		//addAction("title",	new XHTMLTagAction());
@@ -500,40 +490,48 @@ void XHTMLReader::fillTagTable() {
 XHTMLReader::XHTMLReader(BookReader &modelReader) : myModelReader(modelReader) {
 }
 
-bool XHTMLReader::readFile(const std::string &filePath, const std::string &referenceName) {
-	myModelReader.addHyperlinkLabel(referenceName);
-
+bool XHTMLReader::readFile(const ZLFile &file, const std::string &referenceName) {
 	fillTagTable();
 
-	myPathPrefix = MiscUtil::htmlDirectoryPrefix(filePath);
-	myReferenceName = referenceName;
+	myPathPrefix = MiscUtil::htmlDirectoryPrefix(file.path());
+	myReferenceAlias = fileAlias(referenceName);
+	myModelReader.addHyperlinkLabel(myReferenceAlias);
+
 	const int index = referenceName.rfind('/', referenceName.length() - 1);
 	myReferenceDirName = referenceName.substr(0, index + 1);
 
 	myPreformatted = false;
 	myNewParagraphInProgress = false;
 	myReadState = READ_NOTHING;
+	myCurrentParagraphIsEmpty = true;
 
+	myStyleSheetTable.clear();
 	myCSSStack.clear();
 	myStyleEntryStack.clear();
 	myStylesToRemove = 0;
 
-	return readDocument(filePath);
+	myDoPageBreakAfterStack.clear();
+	myStyleParser = new StyleSheetSingleStyleParser();
+	myTableParser.reset();
+
+	return readDocument(file);
 }
 
-void XHTMLReader::addStyleEntry(const std::string tag, const std::string aClass) {
+bool XHTMLReader::addStyleEntry(const std::string tag, const std::string aClass) {
 	shared_ptr<ZLTextStyleEntry> entry = myStyleSheetTable.control(tag, aClass);
 	if (!entry.isNull()) {
-		myModelReader.addControl(*entry);
+		myModelReader.addStyleEntry(*entry);
 		myStyleEntryStack.push_back(entry);
+		return true;
 	}
+	return false;
 }
 
 void XHTMLReader::startElementHandler(const char *tag, const char **attributes) {
 	static const std::string HASH = "#";
 	const char *id = attributeValue(attributes, "id");
 	if (id != 0) {
-		myModelReader.addHyperlinkLabel(myReferenceName + HASH + id);
+		myModelReader.addHyperlinkLabel(myReferenceAlias + HASH + id);
 	}
 
 	const std::string sTag = ZLUnicodeUtil::toLower(tag);
@@ -557,16 +555,18 @@ void XHTMLReader::startElementHandler(const char *tag, const char **attributes)
 	addStyleEntry(sTag, sClass);
 	const char *style = attributeValue(attributes, "style");
 	if (style != 0) {
-		shared_ptr<ZLTextStyleEntry> entry = myStyleParser.parseString(style);
-		myModelReader.addControl(*entry);
+		ZLLogger::Instance().println("CSS", std::string("parsing style attribute: ") + style);
+		shared_ptr<ZLTextStyleEntry> entry = myStyleParser->parseString(style);
+		myModelReader.addStyleEntry(*entry);
 		myStyleEntryStack.push_back(entry);
+	} else {
 	}
 	myCSSStack.push_back(myStyleEntryStack.size() - sizeBefore);
 }
 
 void XHTMLReader::endElementHandler(const char *tag) {
 	for (int i = myCSSStack.back(); i > 0; --i) {
-		myModelReader.addControl(REGULAR, false);
+		myModelReader.addStyleCloseEntry();
 	}
 	myStylesToRemove = myCSSStack.back();
 	myCSSStack.pop_back();
@@ -592,26 +592,20 @@ void XHTMLReader::beginParagraph() {
 	myModelReader.beginParagraph();
 	bool doBlockSpaceBefore = false;
 	for (std::vector<shared_ptr<ZLTextStyleEntry> >::const_iterator it = myStyleEntryStack.begin(); it != myStyleEntryStack.end(); ++it) {
-		myModelReader.addControl(**it);
+		myModelReader.addStyleEntry(**it);
 		doBlockSpaceBefore =
 			doBlockSpaceBefore ||
-			(*it)->lengthSupported(ZLTextStyleEntry::LENGTH_MARGIN_BEFORE) ||
-			(*it)->lengthSupported(ZLTextStyleEntry::LENGTH_PADDING_BEFORE);
+			(*it)->isFeatureSupported(ZLTextStyleEntry::LENGTH_SPACE_BEFORE);
 	}
 
 	if (doBlockSpaceBefore) {
-		ZLTextStyleEntry blockingEntry;
+		ZLTextStyleEntry blockingEntry(ZLTextStyleEntry::STYLE_OTHER_ENTRY);
 		blockingEntry.setLength(
-			ZLTextStyleEntry::LENGTH_MARGIN_BEFORE,
+			ZLTextStyleEntry::LENGTH_SPACE_BEFORE,
 			0,
 			ZLTextStyleEntry::SIZE_UNIT_PIXEL
 		);
-		blockingEntry.setLength(
-			ZLTextStyleEntry::LENGTH_PADDING_BEFORE,
-			0,
-			ZLTextStyleEntry::SIZE_UNIT_PIXEL
-		);
-		myModelReader.addControl(blockingEntry);
+		myModelReader.addStyleEntry(blockingEntry);
 	}
 }
 
@@ -620,31 +614,25 @@ void XHTMLReader::endParagraph() {
 	for (std::vector<shared_ptr<ZLTextStyleEntry> >::const_iterator it = myStyleEntryStack.begin(); it != myStyleEntryStack.end() - myStylesToRemove; ++it) {
 		doBlockSpaceAfter =
 			doBlockSpaceAfter ||
-			(*it)->lengthSupported(ZLTextStyleEntry::LENGTH_MARGIN_AFTER) ||
-			(*it)->lengthSupported(ZLTextStyleEntry::LENGTH_PADDING_AFTER);
+			(*it)->isFeatureSupported(ZLTextStyleEntry::LENGTH_SPACE_AFTER);
 	}
 	if (doBlockSpaceAfter) {
-		ZLTextStyleEntry blockingEntry;
+		ZLTextStyleEntry blockingEntry(ZLTextStyleEntry::STYLE_OTHER_ENTRY);
 		blockingEntry.setLength(
-			ZLTextStyleEntry::LENGTH_MARGIN_AFTER,
+			ZLTextStyleEntry::LENGTH_SPACE_AFTER,
 			0,
 			ZLTextStyleEntry::SIZE_UNIT_PIXEL
 		);
-		blockingEntry.setLength(
-			ZLTextStyleEntry::LENGTH_PADDING_AFTER,
-			0,
-			ZLTextStyleEntry::SIZE_UNIT_PIXEL
-		);
-		myModelReader.addControl(blockingEntry);
+		myModelReader.addStyleEntry(blockingEntry);
 	}
 	for (; myStylesToRemove > 0; --myStylesToRemove) {
-		myModelReader.addControl(*myStyleEntryStack.back());
+		myModelReader.addStyleEntry(*myStyleEntryStack.back());
 		myStyleEntryStack.pop_back();
 	}
 	myModelReader.endParagraph();
 }
 
-void XHTMLReader::characterDataHandler(const char *text, size_t len) {
+void XHTMLReader::characterDataHandler(const char *text, std::size_t len) {
 	switch (myReadState) {
 		case READ_NOTHING:
 			break;
@@ -655,21 +643,22 @@ void XHTMLReader::characterDataHandler(const char *text, size_t len) {
 			break;
 		case READ_BODY:
 			if (myPreformatted) {
-				if ((*text == '\r') || (*text == '\n')) {
-					myModelReader.addControl(CODE, false);
+				if (*text == '\r' || *text == '\n') {
 					endParagraph();
+					text += 1;
+					len -= 1;
 					beginParagraph();
-					myModelReader.addControl(CODE, true);
+					myModelReader.addControl(PREFORMATTED, true);
 				}
-				size_t spaceCounter = 0;
-				while ((spaceCounter < len) && isspace((unsigned char)*(text + spaceCounter))) {
+				std::size_t spaceCounter = 0;
+				while (spaceCounter < len && std::isspace((unsigned char)*(text + spaceCounter))) {
 					++spaceCounter;
 				}
 				myModelReader.addFixedHSpace(spaceCounter);
 				text += spaceCounter;
 				len -= spaceCounter;
-			} else if ((myNewParagraphInProgress) || !myModelReader.paragraphIsOpen()) {
-				while (isspace((unsigned char)*text)) {
+			} else if (myNewParagraphInProgress || !myModelReader.paragraphIsOpen()) {
+				while (std::isspace((unsigned char)*text)) {
 					++text;
 					if (--len == 0) {
 						break;
@@ -695,3 +684,32 @@ const std::vector<std::string> &XHTMLReader::externalDTDs() const {
 bool XHTMLReader::processNamespaces() const {
 	return true;
 }
+
+const std::string XHTMLReader::normalizedReference(const std::string &reference) const {
+	const std::size_t index = reference.find('#');
+	if (index == std::string::npos) {
+		return fileAlias(reference);
+	} else {
+		return fileAlias(reference.substr(0, index)) + reference.substr(index);
+	}
+}
+
+const std::string &XHTMLReader::fileAlias(const std::string &fileName) const {
+	std::map<std::string,std::string>::const_iterator it = myFileNumbers.find(fileName);
+	if (it != myFileNumbers.end()) {
+		return it->second;
+	}
+
+	const std::string correctedFileName =
+		ZLFileUtil::normalizeUnixPath(MiscUtil::decodeHtmlURL(fileName));
+	it = myFileNumbers.find(correctedFileName);
+	if (it != myFileNumbers.end()) {
+		return it->second;
+	}
+
+	std::string num;
+	ZLStringUtil::appendNumber(num, myFileNumbers.size());
+	myFileNumbers.insert(std::make_pair(correctedFileName, num));
+	it = myFileNumbers.find(correctedFileName);
+	return it->second;
+}
