@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,6 +29,8 @@
 #include "../css/StyleSheetTable.h"
 #include "../css/StyleSheetParser.h"
 
+class ZLFile;
+
 class BookReader;
 class XHTMLReader;
 
@@ -53,20 +55,19 @@ public:
 	static XHTMLTagAction *addAction(const std::string &tag, XHTMLTagAction *action);
 	static void fillTagTable();
 
-private:
-	static void freeTagTable();
-
 private:
 	static std::map<std::string,XHTMLTagAction*> ourTagActions;
 
 public:
 	XHTMLReader(BookReader &modelReader);
-	bool readFile(const std::string &filePath, const std::string &referenceName);
+	bool readFile(const ZLFile &file, const std::string &referenceName);
+	const std::string &fileAlias(const std::string &fileName) const;
+	const std::string normalizedReference(const std::string &reference) const;
 
 private:
 	void startElementHandler(const char *tag, const char **attributes);
 	void endElementHandler(const char *tag);
-	void characterDataHandler(const char *text, size_t len);
+	void characterDataHandler(const char *text, std::size_t len);
 
 	const std::vector<std::string> &externalDTDs() const;
 
@@ -74,12 +75,14 @@ private:
 
 	void beginParagraph();
 	void endParagraph();
-	void addStyleEntry(const std::string tag, const std::string aClass);
+	bool addStyleEntry(const std::string tag, const std::string aClass);
 
 private:
+	mutable std::map<std::string,std::string> myFileNumbers;
+
 	BookReader &myModelReader;
 	std::string myPathPrefix;
-	std::string myReferenceName;
+	std::string myReferenceAlias;
 	std::string myReferenceDirName;
 	bool myPreformatted;
 	bool myNewParagraphInProgress;
@@ -89,7 +92,7 @@ private:
 	int myStylesToRemove;
 	std::vector<bool> myDoPageBreakAfterStack;
 	bool myCurrentParagraphIsEmpty;
-	StyleSheetSingleStyleParser myStyleParser;
+	shared_ptr<StyleSheetSingleStyleParser> myStyleParser;
 	shared_ptr<StyleSheetTableParser> myTableParser;
 	enum {
 		READ_NOTHING,
