@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,9 +37,9 @@
 #include "../database/booksdb/BooksDB.h"
 
 shared_ptr<Library> Library::ourInstance;
-const size_t Library::MaxRecentListSize = 10;
+const std::size_t Library::MaxRecentListSize = 10;
 
-Library::Library &Library::Instance() {
+Library &Library::Instance() {
 	if (ourInstance.isNull()) {
 		ourInstance = new Library();
 	}
@@ -50,14 +50,10 @@ static const std::string OPTIONS = "Options";
 
 Library::Library() :
 	PathOption(ZLCategoryKey::CONFIG, OPTIONS, "BookPath", ""),
-	ScanSubdirsOption(ZLCategoryKey::CONFIG, OPTIONS, "ScanSubdirs", false),
+	ScanSubdirsOption(ZLCategoryKey::CONFIG, OPTIONS, "ScanSubdirs", true),
 	CollectAllBooksOption(ZLCategoryKey::CONFIG, OPTIONS, "CollectAllBooks", false),
-	BasicLibraryViewOption(ZLCategoryKey::CONFIG, OPTIONS, "BasicLibraryView", false),
-	EnableLibraryScrollbarOption(ZLCategoryKey::CONFIG, OPTIONS, "EnableLibraryScrollbar", true),
 	myBuildMode(BUILD_ALL),
 	myRevision(0) {
-	myScanSubdirs = false;
-	myPath = "";
 	BooksDBUtil::getRecentBooks(myRecentBooks);
 }
 
@@ -68,7 +64,7 @@ void Library::collectBookFileNames(std::set<std::string> &bookFileNames) const {
 	while (!dirs.empty()) {
 		std::string dirname = *dirs.begin();
 		dirs.erase(dirs.begin());
-		
+
 		ZLFile dirfile(dirname);
 		std::vector<std::string> files;
 		bool inZip = false;
@@ -78,7 +74,7 @@ void Library::collectBookFileNames(std::set<std::string> &bookFileNames) const {
 			continue;
 		}
 
-		if (dirfile.extension() == "zip") {
+		if (dirfile.isArchive()) {
 			ZLFile phys(dirfile.physicalFilePath());
 			if (!BooksDBUtil::checkInfo(phys)) {
 				BooksDBUtil::resetZipInfo(phys);
@@ -96,8 +92,7 @@ void Library::collectBookFileNames(std::set<std::string> &bookFileNames) const {
 				ZLFile file(fileName);
 				if (PluginCollection::Instance().plugin(file, !collectBookWithoutMetaInfo) != 0) {
 					bookFileNames.insert(fileName);
-				// TODO: zip -> any archive
-				} else if (file.extension() == "zip") {
+				} else if (file.isArchive()) {
 					if (myScanSubdirs || !inZip) {
 						dirs.insert(fileName);
 					}
@@ -110,7 +105,7 @@ void Library::collectBookFileNames(std::set<std::string> &bookFileNames) const {
 void Library::rebuildBookSet() const {
 	myBooks.clear();
 	myExternalBooks.clear();
-	
+
 	std::map<std::string, shared_ptr<Book> > booksMap;
 	BooksDBUtil::getBooks(booksMap);
 
@@ -140,7 +135,7 @@ void Library::rebuildBookSet() const {
 	}
 }
 
-size_t Library::revision() const {
+std::size_t Library::revision() const {
 	if (myBuildMode == BUILD_NOTHING &&
 			(myScanSubdirs != ScanSubdirsOption.value() ||
 			 myPath != PathOption.value())) {
@@ -152,32 +147,42 @@ size_t Library::revision() const {
 	return (myBuildMode == BUILD_NOTHING) ? myRevision : myRevision + 1;
 }
 
-class LibrarySynchronizer : public ZLRunnable {
+class LibrarySynchronizer : public DBRunnable {
 
 public:
-	LibrarySynchronizer(Library::BuildMode mode);
+	LibrarySynchronizer(Library::BuildMode mode) : myBuildMode(mode) { }
 
 private:
-	void run();
+	bool run() {
+		Library &library = Library::Instance();
+
+		if (myBuildMode & Library::BUILD_COLLECT_FILES_INFO) {
+			library.rebuildBookSet();
+		}
+
+		if (myBuildMode & Library::BUILD_UPDATE_BOOKS_INFO) {
+			library.rebuildMaps();
+		}
+		return true;
+	}
 
 private:
 	const Library::BuildMode myBuildMode;
 };
 
-LibrarySynchronizer::LibrarySynchronizer(Library::BuildMode mode) : myBuildMode(mode) {
-}
+class LibrarySynchronizerWrapper : public ZLRunnable {
 
-void LibrarySynchronizer::run() {
-	Library &library = Library::Instance();
+public:
+	LibrarySynchronizerWrapper(Library::BuildMode mode) : myRunnable(mode) { }
 
-	if (myBuildMode & Library::BUILD_COLLECT_FILES_INFO) {
-		library.rebuildBookSet();
+private:
+	void run() {
+		BooksDB::Instance().executeAsTransaction(myRunnable);
 	}
 
-	if (myBuildMode & Library::BUILD_UPDATE_BOOKS_INFO) {
-		library.rebuildMaps();
-	}
-}
+private:
+	LibrarySynchronizer myRunnable;
+};
 
 void Library::synchronize() const {
 	if (myScanSubdirs != ScanSubdirsOption.value() ||
@@ -191,7 +196,7 @@ void Library::synchronize() const {
 		return;
 	}
 
-	LibrarySynchronizer synchronizer(myBuildMode);
+	LibrarySynchronizerWrapper synchronizer(myBuildMode);
 	myBuildMode = BUILD_NOTHING;
 	ZLDialogManager::Instance().wait(ZLResourceKey("loadingBookList"), synchronizer);
 
@@ -297,7 +302,7 @@ void Library::removeBook(shared_ptr<Book> book) {
 		BooksDB::Instance().deleteFromBookList(*book);
 		bool recentListChanged = false;
 		for (BookList::iterator it = myRecentBooks.begin(); it != myRecentBooks.end();) {
-			if ((*it)->filePath() == book->filePath()) {
+			if ((*it)->file() == book->file()) {
 				it = myRecentBooks.erase(it);
 				recentListChanged = true;
 			} else {
@@ -330,11 +335,6 @@ const BookList &Library::books(shared_ptr<Tag> tag) const {
 	return myBooksByTag[tag];
 }
 
-const BookSet &Library::books() const {
-	synchronize();
-	return myBooks;
-}
-
 void Library::collectSeriesTitles(shared_ptr<Author> author, std::set<std::string> &titles) const {
 	const BookList &bookList = books(author);
 	for (BookList::const_iterator it = bookList.begin(); it != bookList.end(); ++it) {
@@ -376,8 +376,7 @@ void Library::cloneTag(shared_ptr<Tag> from, shared_ptr<Tag> to, bool includeSub
 
 bool Library::hasBooks(shared_ptr<Tag> tag) const {
 	synchronize();
-	const std::map<shared_ptr<Tag>,BookList>::const_iterator it =
-		myBooksByTag.find(tag);
+	const BooksByTag::const_iterator it = myBooksByTag.find(tag);
 	return it != myBooksByTag.end() && !it->second.empty();
 }
 
@@ -404,7 +403,7 @@ Library::RemoveType Library::canRemove(shared_ptr<Book> book) const {
 	return (RemoveType)(
 		(myExternalBooks.find(book) != myExternalBooks.end() ?
 			REMOVE_FROM_LIBRARY : REMOVE_DONT_REMOVE) |
-		(BooksDBUtil::canRemoveFile(book->filePath()) ?
+		(BooksDBUtil::canRemoveFile(book->file().path()) ?
 			REMOVE_FROM_DISK : REMOVE_DONT_REMOVE)
 	);
 }
@@ -424,7 +423,7 @@ void Library::addBookToRecentList(shared_ptr<Book> book) {
 		return;
 	}
 	for (BookList::iterator it = myRecentBooks.begin(); it != myRecentBooks.end(); ++it) {
-		if ((*it)->filePath() == book->filePath()) {
+		if ((*it)->file() == book->file()) {
 			if (it == myRecentBooks.begin()) {
 				return;
 			}
