@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,8 +29,10 @@
 
 #include <ZLOptions.h>
 
+#include "Book.h"
+#include "Author.h"
+#include "Tag.h"
 #include "Lists.h"
-#include "Comparators.h"
 
 class Library {
 
@@ -39,14 +41,12 @@ public:
 
 private:
 	static shared_ptr<Library> ourInstance;
-	static const size_t MaxRecentListSize;
+	static const std::size_t MaxRecentListSize;
 
 public:
 	ZLStringOption PathOption;
 	ZLBooleanOption ScanSubdirsOption;
 	ZLBooleanOption CollectAllBooksOption;
-	ZLBooleanOption BasicLibraryViewOption;
-	ZLBooleanOption EnableLibraryScrollbarOption;
 
 private:
 	Library();
@@ -56,7 +56,6 @@ public:
 	const TagList &tags() const;
 	const BookList &books(shared_ptr<Author> author) const;
 	const BookList &books(shared_ptr<Tag> tag) const;
-	const BookSet &books() const;
 	const BookList &recentBooks() const;
 
 	enum RemoveType {
@@ -65,12 +64,12 @@ public:
 		REMOVE_FROM_DISK = 2,
 		REMOVE_FROM_LIBRARY_AND_DISK = REMOVE_FROM_LIBRARY | REMOVE_FROM_DISK
 	};
-		
+
 	RemoveType canRemove(shared_ptr<Book> book) const;
 
 	void collectSeriesTitles(shared_ptr<Author> author, std::set<std::string> &titles) const;
 
-	size_t revision() const;
+	std::size_t revision() const;
 
 	void addBook(shared_ptr<Book> book);
 	void removeBook(shared_ptr<Book> book);
@@ -118,9 +117,10 @@ private:
 		BUILD_ALL = 0x03
 	};
 	mutable BuildMode myBuildMode;
-	mutable size_t myRevision;
+	mutable std::size_t myRevision;
 
 friend class LibrarySynchronizer;
+friend class LibrarySynchronizerWrapper;
 };
 
 #endif /* __LIBRARY_H__ */
