@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2009-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -46,10 +46,7 @@ BookNode::BookNode(AuthorNode *parent, shared_ptr<Book> book) : FBReaderNode(par
 BookNode::BookNode(SeriesNode *parent, shared_ptr<Book> book) : FBReaderNode(parent), myBook(book) {
 }
 
-BookNode::BookNode(ZLBlockTreeView::RootNode *parent, shared_ptr<Book> book) : FBReaderNode(parent), myBook(book) {
-}
-
-BookNode::BookNode(TagNode *parent, size_t atPosition, shared_ptr<Book> book) : FBReaderNode(parent, atPosition), myBook(book) {
+BookNode::BookNode(TagNode *parent, std::size_t atPosition, shared_ptr<Book> book) : FBReaderNode(parent, atPosition), myBook(book) {
 }
 
 void BookNode::init() {
@@ -69,8 +66,7 @@ std::string BookNode::title() const {
 std::string BookNode::summary() const {
 	FBReaderNode *parent = (FBReaderNode*)this->parent();
 	while (!parent->isInstanceOf(AuthorNode::TYPE_ID) &&
-				 !parent->isInstanceOf(TagNode::TYPE_ID) &&
-				 !parent->isInstanceOf(ZLBlockTreeView::RootNode::TYPE_ID)) {
+				 !parent->isInstanceOf(TagNode::TYPE_ID)) {
 		parent = (FBReaderNode*)parent->parent();
 	}
 	if (parent->isInstanceOf(AuthorNode::TYPE_ID)) {
@@ -105,13 +101,13 @@ std::string BookNode::summary() const {
 }
 
 bool BookNode::highlighted() const {
-	return myBook->filePath() == FBReader::Instance().currentBook()->filePath();
+	return myBook->file() == FBReader::Instance().currentBook()->file();
 }
 
-shared_ptr<ZLImage> BookNode::extractCoverImage() const {
+shared_ptr<const ZLImage> BookNode::extractCoverImage() const {
 	shared_ptr<FormatPlugin> plugin = PluginCollection::Instance().plugin(*myBook);
 	if (!plugin.isNull()) {
-		shared_ptr<ZLImage> cover = plugin->coverImage(*myBook);
+		shared_ptr<const ZLImage> cover = plugin->coverImage(myBook->file());
 		if (!cover.isNull()) {
 			return cover;
 		}
