@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2009-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@ public:
 	static const ZLTypeId TYPE_ID;
 
 public:
-	AuthorNode(ZLBlockTreeView::RootNode *parent, size_t atPosition, shared_ptr<Author> author);
+	AuthorNode(ZLBlockTreeView::RootNode *parent, std::size_t atPosition, shared_ptr<Author> author);
 	void init();
 
 	shared_ptr<Author> author() const;
@@ -42,7 +42,7 @@ public:
 private:
 	const ZLResource &resource() const;
 	const ZLTypeId &typeId() const;
-	shared_ptr<ZLImage> extractCoverImage() const;
+	shared_ptr<const ZLImage> extractCoverImage() const;
 	std::string title() const;
 
 private:
@@ -63,7 +63,7 @@ public:
 private:
 	const ZLResource &resource() const;
 	const ZLTypeId &typeId() const;
-	shared_ptr<ZLImage> extractCoverImage() const;
+	shared_ptr<const ZLImage> extractCoverImage() const;
 	std::string title() const;
 };
 
@@ -73,7 +73,7 @@ public:
 	static const ZLTypeId TYPE_ID;
 
 private:
-	static size_t positionToInsert(ZLBlockTreeNode *parent, shared_ptr<Tag> tag);
+	static std::size_t positionToInsert(ZLBlockTreeNode *parent, shared_ptr<Tag> tag);
 
 public:
 	TagNode(ZLBlockTreeView::RootNode *parent, shared_ptr<Tag> tag);
@@ -85,7 +85,7 @@ public:
 private:
 	const ZLResource &resource() const;
 	const ZLTypeId &typeId() const;
-	shared_ptr<ZLImage> extractCoverImage() const;
+	shared_ptr<const ZLImage> extractCoverImage() const;
 	std::string title() const;
 
 private:
@@ -100,8 +100,7 @@ public:
 public:
 	BookNode(AuthorNode *parent, shared_ptr<Book> book);
 	BookNode(SeriesNode *parent, shared_ptr<Book> book);
-	BookNode(TagNode *parent, size_t atPosition, shared_ptr<Book> book);
-	BookNode(ZLBlockTreeView::RootNode *parent, shared_ptr<Book> book);
+	BookNode(TagNode *parent, std::size_t atPosition, shared_ptr<Book> book);
 
 	shared_ptr<Book> book() const;
 
@@ -110,7 +109,7 @@ private:
 	bool highlighted() const;
 	const ZLResource &resource() const;
 	const ZLTypeId &typeId() const;
-	shared_ptr<ZLImage> extractCoverImage() const;
+	shared_ptr<const ZLImage> extractCoverImage() const;
 	std::string title() const;
 	std::string summary() const;
 
