@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,32 +17,27 @@
  * 02110-1301, USA.
  */
 
-#include <ZLStringUtil.h>
 #include <ZLUnicodeUtil.h>
+#include <ZLXMLNamespace.h>
 
 #include "OEBMigrationReader.h"
-#include "../constants/XMLNamespace.h"
 
 OEBMigrationReader::OEBMigrationReader(BookInfo &info) : myInfo(info) {
 }
 
 static const std::string METADATA = "metadata";
 static const std::string DC_METADATA = "dc-metadata";
-static const std::string SUBJECT_TAG = ":subject";
 
-void OEBMigrationReader::characterDataHandler(const char *text, size_t len) {
+void OEBMigrationReader::characterDataHandler(const char *text, std::size_t len) {
 	if (myReadSubject) {
 		myBuffer.append(text, len);
 	}
 }
 
-bool OEBMigrationReader::isDublinCoreNamespace(const std::string &nsId) const {
-	const std::map<std::string,std::string> &namespaceMap = namespaces();
-	std::map<std::string,std::string>::const_iterator iter = namespaceMap.find(nsId);
+bool OEBMigrationReader::testDCTag(const std::string &name, const std::string &tag) const {
 	return
-		((iter != namespaceMap.end()) &&
-		 (ZLStringUtil::stringStartsWith(iter->second, XMLNamespace::DublinCorePrefix) ||
-		  ZLStringUtil::stringStartsWith(iter->second, XMLNamespace::DublinCoreLegacyPrefix)));
+		testTag(ZLXMLNamespace::DublinCore, name, tag) ||
+		testTag(ZLXMLNamespace::DublinCoreLegacy, name, tag);
 }
 
 void OEBMigrationReader::startElementHandler(const char *tag, const char**) {
@@ -51,10 +46,8 @@ void OEBMigrationReader::startElementHandler(const char *tag, const char**) {
 		myDCMetadataTag = tagString;
 		myReadMetaData = true;
 	} else if (myReadMetaData) {
-		if (ZLStringUtil::stringEndsWith(tagString, SUBJECT_TAG)) {
-			if (isDublinCoreNamespace(tagString.substr(0, tagString.length() - SUBJECT_TAG.length()))) {
+		if (testDCTag("subject", tagString)) {
 				myReadSubject = true;
-			}
 		}
 	}
 }
@@ -64,7 +57,7 @@ void OEBMigrationReader::endElementHandler(const char *tag) {
 	if (myDCMetadataTag == tagString) {
 		interrupt();
 	} else if (myReadSubject) {
-		ZLStringUtil::stripWhiteSpaces(myBuffer);
+		ZLUnicodeUtil::utf8Trim(myBuffer);
 		if (!myBuffer.empty()) {
 			if (!myTagList.empty()) {
 				myTagList += ',';
@@ -80,9 +73,9 @@ bool OEBMigrationReader::processNamespaces() const {
 	return true;
 }
 
-void OEBMigrationReader::doRead(const std::string &fileName) {
+void OEBMigrationReader::doRead(const ZLFile &file) {
 	myReadMetaData = false;
 	myReadSubject = false;
-	readDocument(fileName);
+	readDocument(file);
 	myInfo.TagsOption.setValue(myTagList);
 }
