@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2008-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,60 +28,78 @@
 #include <ZLOptions.h>
 
 #include "NetworkItems.h"
+#include "atom/ATOMMetadata.h"
 
-class ZLExecutionData;
+class ZLNetworkRequest;
 
-struct NetworkOperationData;
+class NetworkOperationData;
 class NetworkAuthenticationManager;
 
 class NetworkLink {
 
-public:
-	static std::string NetworkDataDirectory();
-	static std::string CertificatesPathPrefix();
-
 public:
 	static const std::string URL_MAIN;
 	static const std::string URL_SEARCH;
 	static const std::string URL_SIGN_IN;
 	static const std::string URL_SIGN_OUT;
 	static const std::string URL_SIGN_UP;
-	static const std::string URL_REFILL_ACCOUNT;
+	static const std::string URL_TOPUP;
 	static const std::string URL_RECOVER_PASSWORD;
 
 protected:
 	NetworkLink(
-		const std::string &siteName,
-		const std::string &title,
-		const std::string &summary,
-		const std::string &icon,
-		const std::map<std::string,std::string> &links
+		const std::string &siteName
 	);
 
 public:
 	virtual ~NetworkLink();
 	std::string url(const std::string &urlId) const;
 
+	void setTitle(const std::string& title);
+	void setSummary(const std::string& summary);
+	void setLanguage(const std::string& language);
+	void setIcon(const std::string& icon);
+	void setLinks(const std::map<std::string,std::string>& links);
+	void setPredefinedId(const std::string& id);
+	void setEnabled(bool enabled);
+	void setUpdated(shared_ptr<ATOMUpdated> u);
+
+	std::string getSiteName() const;
+	std::string getTitle() const;
+	std::string getSummary() const;
+	std::string getLanguage() const;
+	std::string getIcon() const;
+	const std::map<std::string,std::string>& getLinks() const;
+	std::string getPredefinedId() const;
+	bool isEnabled() const;
+	shared_ptr<ATOMUpdated> getUpdated() const;
+
+	bool isPredefined() const;
+
+	void loadFrom(const NetworkLink & link);
+	void loadLinksFrom(const NetworkLink & link);
+	void loadSummaryFrom(const NetworkLink & link);
+
 public:
-	virtual shared_ptr<ZLExecutionData> simpleSearchData(NetworkOperationData &data, const std::string &pattern) const = 0;
-	virtual shared_ptr<ZLExecutionData> advancedSearchData(NetworkOperationData &data, const std::string &titleAndSeries, const std::string &author, const std::string &tag, const std::string &annotation) const = 0;
-	virtual shared_ptr<ZLExecutionData> resume(NetworkOperationData &data) const;
+	virtual shared_ptr<ZLNetworkRequest> simpleSearchData(NetworkOperationData &data, const std::string &pattern) const = 0;
+	virtual shared_ptr<ZLNetworkRequest> advancedSearchData(NetworkOperationData &data, const std::string &titleAndSeries, const std::string &author, const std::string &tag, const std::string &annotation) const = 0;
+	virtual shared_ptr<ZLNetworkRequest> resume(NetworkOperationData &data) const;
 
 	virtual shared_ptr<NetworkAuthenticationManager> authenticationManager() const = 0;
 	virtual shared_ptr<NetworkItem> libraryItem() const = 0;
 
 	virtual void rewriteUrl(std::string &url, bool isUrlExternal = false) const = 0;
 
-public:
-	const std::string SiteName;
-	const std::string Title;
-	const std::string Summary;
-	const std::string Icon;
-	ZLBooleanOption OnOption;
-
 private:
-protected:
-	/*const*/ std::map<std::string,std::string> myLinks;
+	const std::string mySiteName;
+	std::string myTitle;
+	std::string myIcon;
+	std::string mySummary;
+	std::string myLanguage;
+	std::map<std::string,std::string> myLinks;
+	std::string myPredefinedId;
+	bool myEnabled;
+	shared_ptr<ATOMUpdated> myUpdated;
 
 private: // disable copying
 	NetworkLink(const NetworkLink &);
