@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2009-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,12 +17,12 @@
  * 02110-1301, USA.
  */
 
-#include <ZLExecutionData.h>
+#include <ZLNetworkRequest.h>
 
 #include "NetworkLink.h"
 #include "NetworkOperationData.h"
 
-NetworkOperationData::NetworkOperationData(const NetworkLink &link) : Link(link), myResumeCount(0) {
+NetworkOperationData::NetworkOperationData(const NetworkLink &link) : Link(link) {
 }
 
 void NetworkOperationData::clear() {
@@ -30,9 +30,8 @@ void NetworkOperationData::clear() {
 	ResumeURI.clear();
 }
 
-shared_ptr<ZLExecutionData> NetworkOperationData::resume() {
-	if (++myResumeCount >= 10) {
-		return 0;
-	}
-	return Link.resume(*this);
+shared_ptr<ZLNetworkRequest> NetworkOperationData::resume() {
+	shared_ptr<ZLNetworkRequest> request = Link.resume(*this);
+	clear();
+	return request;
 }
