@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2009-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -46,9 +46,7 @@ public:
 	void processFeedEnd();
 
 private:
-	shared_ptr<NetworkItem> readBookItem(OPDSEntry &entry);
 	shared_ptr<NetworkItem> readCatalogItem(OPDSEntry &entry);
-	bool isType(const std::string type, const std::string test);
 
 private:
 	const OPDSLink &myLink;
