@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2009-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +20,10 @@
 #ifndef __OPDSCATALOGITEM_H__
 #define __OPDSCATALOGITEM_H__
 
+#include <ZLExecutionUtil.h>
+
 #include "../NetworkItems.h"
+#include "../NetworkOperationData.h"
 
 class OPDSLink;
 
@@ -31,13 +34,18 @@ public:
 		const OPDSLink &link,
 		const std::string &title,
 		const std::string &summary,
-		const std::map<URLType,std::string> &urlByType,
-		VisibilityType visibility = Always,
-		CatalogType catalogType = OTHER
+		const UrlInfoCollection &urlByType,
+		AccessibilityType accessibility = ALWAYS,
+		int flags = FLAGS_DEFAULT
 	);
 
+public:
+	std::string loadChildren(NetworkItem::List &children, shared_ptr<ZLNetworkRequest::Listener> listener = 0);
+	bool supportsResumeLoading();
+	std::string resumeLoading(List &children, shared_ptr<ZLNetworkRequest::Listener> listener = 0);
+
 private:
-	std::string loadChildren(NetworkItem::List &children);
+	NetworkOperationData myLoadingState;
 };
 
 #endif /* __OPDSCATALOGITEM_H__ */
