@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2009-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,10 +19,10 @@
 
 #include <cstdlib>
 
-#include <ZLStringUtil.h>
+#include <ZLUnicodeUtil.h>
+#include <ZLXMLNamespace.h>
 
 #include "OPDSXMLParser.h"
-#include "../../constants/XMLNamespace.h"
 
 static const std::string TAG_FEED = "feed";
 static const std::string TAG_ENTRY = "entry";
@@ -40,6 +40,7 @@ static const std::string TAG_SUBTITLE = "subtitle";
 static const std::string TAG_TITLE = "title";
 static const std::string TAG_UPDATED = "updated";
 static const std::string TAG_PRICE = "price";
+static const std::string TAG_ICON = "icon";
 
 static const std::string TAG_HACK_SPAN = "span";
 
@@ -59,62 +60,24 @@ const std::string OPDSXMLParser::KEY_PRICE = "price";
 const std::string OPDSXMLParser::KEY_CURRENCY = "currency";
 const std::string OPDSXMLParser::KEY_FORMAT = "format";
 
-OPDSXMLParser::OPDSXMLParser(shared_ptr<OPDSFeedReader> feedReader) :myFeedReader(feedReader) {
-	myState = START;
+static const std::string TAG_SEARCH_DESCRIPTION = "fbreader:advancedSearch";
+static const std::string TAG_AUTHENTICATION = "fbreader:authentication";
+static const std::string TAG_URL_REWRITING_RULES = "fbreader:urlRewritingRule";
+static const std::string TAG_RELATION_ALIASES = "fbreader:relationAlias";
+
+OPDSXMLParser::OPDSXMLParser(shared_ptr<OPDSFeedReader> feedReader, bool readEntryNotFeed) : myFeedReader(feedReader) {
+	myState = readEntryNotFeed ? FEED : START;
 }
 
 bool OPDSXMLParser::processNamespaces() const {
 	return true;
 }
 
-void OPDSXMLParser::namespaceListChangedHandler() {
-	myDublinCoreNamespaceId.erase();
-	myAtomNamespaceId.erase();
-	myOpenSearchNamespaceId.erase();
-	myCalibreNamespaceId.erase();
-	myOpdsNamespaceId.erase();
-
-	const std::map<std::string,std::string> &nsMap = namespaces();
-	for (std::map<std::string,std::string>::const_iterator it = nsMap.begin(); it != nsMap.end(); ++it) {
-		if (it->first.empty()) {
-			continue;
-		}
-		if (it->second == XMLNamespace::DublinCoreTerms) {
-			myDublinCoreNamespaceId = it->first;
-		} else if (it->second == XMLNamespace::Atom) {
-			myAtomNamespaceId = it->first;
-		} else if (it->second == XMLNamespace::OpenSearch) {
-			myOpenSearchNamespaceId = it->first;
-		} else if (it->second == XMLNamespace::CalibreMetadata) {
-			myCalibreNamespaceId = it->first;
-		} else if (it->second == XMLNamespace::Opds) {
-			myOpdsNamespaceId = it->first;
-		}
-	}
-}
-
 void OPDSXMLParser::startElementHandler(const char *tag, const char **attributes) {
-	std::map<std::string,std::string> attributeMap;
-	while (*attributes != 0) {
-		std::string name(*attributes++);
-		if (*attributes == 0) {
-			break;
-		}
-		std::string value(*attributes++);
-		attributeMap.insert(std::make_pair(name, value));
-	}
-
-	std::string tagPrefix;
-	std::string tagName = tag;
-	const int index = tagName.find(':');
-	if (index != -1) {
-		tagPrefix = tagName.substr(0, index);
-		tagName.erase(0, index + 1);
-	}
-		
+	std::map<std::string,std::string> attributeMap = getAttributesMap(attributes);
 	switch (myState) {
 		case START:
-			if (tagPrefix == myAtomNamespaceId && tagName == TAG_FEED) {
+			if (testTag(ZLXMLNamespace::Atom, TAG_FEED, tag)) {
 				myFeedReader->processFeedStart();
 				myFeed = new OPDSFeedMetadata();
 				myFeed->readAttributes(attributeMap);
@@ -122,140 +85,138 @@ void OPDSXMLParser::startElementHandler(const char *tag, const char **attributes
 			}
 			break;
 		case FEED:
-			if (tagPrefix == myAtomNamespaceId) {
-				if (tagName == TAG_AUTHOR) {
-					myAuthor = new ATOMAuthor();
-					myAuthor->readAttributes(attributeMap);
-					myState = F_AUTHOR;
-				} else if (tagName == TAG_ID) {
-					myId = new ATOMId();
-					myId->readAttributes(attributeMap);
-					myState = F_ID;
-				} else if (tagName == TAG_LINK) {
-					myLink = new ATOMLink();
-					myLink->readAttributes(attributeMap);
-					myState = F_LINK;
-				} else if (tagName == TAG_CATEGORY) {
-					myCategory = new ATOMCategory();
-					myCategory->readAttributes(attributeMap);
-					myState = F_CATEGORY;
-				} else if (tagName == TAG_TITLE) {
-					//myTitle = new ATOMTitle(); // TODO:implement ATOMTextConstruct & ATOMTitle
-					//myTitle->readAttributes(attributeMap);
-					myState = F_TITLE;
-				} else if (tagName == TAG_UPDATED) {
-					myUpdated = new ATOMUpdated();
-					myUpdated->readAttributes(attributeMap);
-					myState = F_UPDATED;
-				} else if (tagName == TAG_ENTRY) {
-					myEntry = new OPDSEntry();
-					myEntry->readAttributes(attributeMap);
-					mySummaryTagFound = false;
-					myState = F_ENTRY;
-				} 
-			} else if (tagPrefix == myOpenSearchNamespaceId) {
-				if (tagName == OPENSEARCH_TAG_TOTALRESULTS) {
-					myState = OPENSEARCH_TOTALRESULTS;
-				} else if (tagName == OPENSEARCH_TAG_ITEMSPERPAGE) {
-					myState = OPENSEARCH_ITEMSPERPAGE;
-				} else if (tagName == OPENSEARCH_TAG_STARTINDEX) {
-					myState = OPENSEARCH_STARTINDEX;
-				} 
-			} 
+			if (testTag(ZLXMLNamespace::Atom, TAG_AUTHOR, tag)) {
+				myAuthor = new ATOMAuthor();
+				myAuthor->readAttributes(attributeMap);
+				myState = F_AUTHOR;
+			} else if (testTag(ZLXMLNamespace::Atom, TAG_ID, tag)) {
+				myId = new ATOMId();
+				myId->readAttributes(attributeMap);
+				myState = F_ID;
+			} else if (testTag(ZLXMLNamespace::Atom, TAG_ICON, tag)) {
+				myIcon = new ATOMIcon();
+				myIcon->readAttributes(attributeMap);
+				myState = F_ICON;
+			} else if (testTag(ZLXMLNamespace::Atom, TAG_LINK, tag)) {
+				myLink = new ATOMLink();
+				myLink->readAttributes(attributeMap);
+				myState = F_LINK;
+			} else if (testTag(ZLXMLNamespace::Atom, TAG_CATEGORY, tag)) {
+				myCategory = new ATOMCategory();
+				myCategory->readAttributes(attributeMap);
+				myState = F_CATEGORY;
+			} else if (testTag(ZLXMLNamespace::Atom, TAG_TITLE, tag)) {
+				//myTitle = new ATOMTitle(); // TODO:implement ATOMTextConstruct & ATOMTitle
+				//myTitle->readAttributes(attributeMap);
+				myState = F_TITLE;
+			} else if (testTag(ZLXMLNamespace::Atom, TAG_SUBTITLE, tag)) {
+				myState = F_SUBTITLE;
+			} else if (testTag(ZLXMLNamespace::Atom, TAG_SUMMARY, tag)) {
+				myState = F_SUMMARY;
+			} else if (testTag(ZLXMLNamespace::Atom, TAG_UPDATED, tag)) {
+				myUpdated = new ATOMUpdated();
+				myUpdated->readAttributes(attributeMap);
+				myState = F_UPDATED;
+			} else if (testTag(ZLXMLNamespace::Atom, TAG_ENTRY, tag)) {
+				myEntry = new OPDSEntry();
+				myEntry->readAttributes(attributeMap);
+				mySummaryTagFound = false;
+				myState = F_ENTRY;
+			} else if (testTag(ZLXMLNamespace::OpenSearch, OPENSEARCH_TAG_TOTALRESULTS, tag)) {
+				myState = OPENSEARCH_TOTALRESULTS;
+			} else if (testTag(ZLXMLNamespace::OpenSearch, OPENSEARCH_TAG_ITEMSPERPAGE, tag)) {
+				myState = OPENSEARCH_ITEMSPERPAGE;
+			} else if (testTag(ZLXMLNamespace::OpenSearch, OPENSEARCH_TAG_STARTINDEX, tag)) {
+				myState = OPENSEARCH_STARTINDEX;
+			}
 			break;
 		case F_ENTRY:
-			if (tagPrefix == myAtomNamespaceId) {
-				if (tagName == TAG_AUTHOR) {
-					myAuthor = new ATOMAuthor();
-					myAuthor->readAttributes(attributeMap);
-					myState = FE_AUTHOR;
-				} else if (tagName == TAG_ID) {
-					myId = new ATOMId();
-					myId->readAttributes(attributeMap);
-					myState = FE_ID;
-				} else if (tagName == TAG_CATEGORY) {
-					myCategory = new ATOMCategory();
-					myCategory->readAttributes(attributeMap);
-					myState = FE_CATEGORY;
-				} else if (tagName == TAG_LINK) {
-					myLink = new ATOMLink();
-					myLink->readAttributes(attributeMap);
-					myState = FE_LINK;
-				} else if (tagName == TAG_PUBLISHED) {
-					myPublished = new ATOMPublished();
-					myPublished->readAttributes(attributeMap);
-					myState = FE_PUBLISHED;
-				} else if (tagName == TAG_SUMMARY) {
-					//mySummary = new ATOMSummary(); // TODO:implement ATOMTextConstruct & ATOMSummary
-					//mySummary->readAttributes(attributeMap);
-					myState = FE_SUMMARY;
-				} else if (tagName == TAG_CONTENT) {
-					// ???
-					myState = FE_CONTENT;
-				} else if (tagName == TAG_SUBTITLE) {
-					// ???
-					myState = FE_SUBTITLE;
-				} else if (tagName == TAG_TITLE) {
-					//myTitle = new ATOMTitle(); // TODO:implement ATOMTextConstruct & ATOMTitle
-					//myTitle->readAttributes(attributeMap);
-					myState = FE_TITLE;
-				} else if (tagName == TAG_UPDATED) {
-					myUpdated = new ATOMUpdated();
-					myUpdated->readAttributes(attributeMap);
-					myState = FE_UPDATED;
-				}
-			} else if (tagPrefix == myDublinCoreNamespaceId) {
-				if (tagName == DC_TAG_LANGUAGE) {
+			if (testTag(ZLXMLNamespace::Atom, TAG_AUTHOR, tag)) {
+				myAuthor = new ATOMAuthor();
+				myAuthor->readAttributes(attributeMap);
+				myState = FE_AUTHOR;
+			} else if (testTag(ZLXMLNamespace::Atom, TAG_ID, tag)) {
+				myId = new ATOMId();
+				myId->readAttributes(attributeMap);
+				myState = FE_ID;
+			} else if (testTag(ZLXMLNamespace::Atom, TAG_CATEGORY, tag)) {
+				myCategory = new ATOMCategory();
+				myCategory->readAttributes(attributeMap);
+				myState = FE_CATEGORY;
+			} else if (testTag(ZLXMLNamespace::Atom, TAG_ICON, tag)) {
+				myIcon = new ATOMIcon();
+				myIcon->readAttributes(attributeMap);
+				myState = FE_ICON;
+			} else if (testTag(ZLXMLNamespace::Atom, TAG_LINK, tag)) {
+				myLink = new ATOMLink();
+				myLink->readAttributes(attributeMap);
+				myState = FE_LINK;
+			} else if (testTag(ZLXMLNamespace::Atom, TAG_PUBLISHED, tag)) {
+				myPublished = new ATOMPublished();
+				myPublished->readAttributes(attributeMap);
+				myState = FE_PUBLISHED;
+			} else if (testTag(ZLXMLNamespace::Atom, TAG_SUMMARY, tag)) {
+				//mySummary = new ATOMSummary(); // TODO:implement ATOMTextConstruct & ATOMSummary
+				//mySummary->readAttributes(attributeMap);
+				myState = FE_SUMMARY;
+			} else if (testTag(ZLXMLNamespace::Atom, TAG_CONTENT, tag)) {
+				// ???
+				myState = FE_CONTENT;
+			} else if (testTag(ZLXMLNamespace::Atom, TAG_SUBTITLE, tag)) {
+				// ???
+				myState = FE_SUBTITLE;
+			} else if (testTag(ZLXMLNamespace::Atom, TAG_TITLE, tag)) {
+				//myTitle = new ATOMTitle(); // TODO:implement ATOMTextConstruct & ATOMTitle
+				//myTitle->readAttributes(attributeMap);
+				myState = FE_TITLE;
+			} else if (testTag(ZLXMLNamespace::Atom, TAG_UPDATED, tag)) {
+				myUpdated = new ATOMUpdated();
+				myUpdated->readAttributes(attributeMap);
+				myState = FE_UPDATED;
+			} else if (testTag(ZLXMLNamespace::DublinCoreTerms, DC_TAG_LANGUAGE, tag)) {
 					myState = FE_DC_LANGUAGE;
-				} else if (tagName == DC_TAG_ISSUED) {
-					myState = FE_DC_ISSUED;
-				} else if (tagName == DC_TAG_PUBLISHER) {
-					myState = FE_DC_PUBLISHER;
-				} 
-			} else if (tagPrefix == myCalibreNamespaceId) {
-				if (tagName == CALIBRE_TAG_SERIES) {
-					myState = FE_CALIBRE_SERIES;
-				} else if (tagName == CALIBRE_TAG_SERIES_INDEX) {
-					myState = FE_CALIBRE_SERIES_INDEX;
-				}
+			} else if (testTag(ZLXMLNamespace::DublinCoreTerms, DC_TAG_ISSUED, tag)) {
+				myState = FE_DC_ISSUED;
+			} else if (testTag(ZLXMLNamespace::DublinCoreTerms, DC_TAG_PUBLISHER, tag)) {
+				myState = FE_DC_PUBLISHER;
+			} else if (testTag(ZLXMLNamespace::CalibreMetadata, CALIBRE_TAG_SERIES, tag)) {
+				myState = FE_CALIBRE_SERIES;
+			} else if (testTag(ZLXMLNamespace::CalibreMetadata, CALIBRE_TAG_SERIES_INDEX, tag)) {
+				myState = FE_CALIBRE_SERIES_INDEX;
 			}
 			break;
 		case F_AUTHOR:
-			if (tagPrefix == myAtomNamespaceId) {
-				if (tagName == TAG_NAME) {
-					myState = FA_NAME;
-				} else if (tagName == TAG_URI) {
-					myState = FA_URI;
-				} else if (tagName == TAG_EMAIL) {
-					myState = FA_EMAIL;
-				} 
-			} 
+			if (testTag(ZLXMLNamespace::Atom, TAG_NAME, tag)) {
+				myState = FA_NAME;
+			} else if (testTag(ZLXMLNamespace::Atom, TAG_URI, tag)) {
+				myState = FA_URI;
+			} else if (testTag(ZLXMLNamespace::Atom, TAG_EMAIL, tag)) {
+				myState = FA_EMAIL;
+			}
 			break;
 		case FE_TITLE:
 			// TODO: remove this temporary code
 			// DON'T clear myBuffer
 			return;
 		case FE_LINK:
-			if (tagPrefix == myOpdsNamespaceId && tagName == TAG_PRICE) {
+			if (testTag(ZLXMLNamespace::Opds, TAG_PRICE, tag)) {
 				myLink->setUserData(KEY_CURRENCY, attributeMap["currencycode"]);
 				myState = FEL_PRICE;
-			} if (tagPrefix == myDublinCoreNamespaceId && tagName == DC_TAG_FORMAT) {
+			} if (testTag(ZLXMLNamespace::DublinCoreTerms, DC_TAG_FORMAT, tag)) {
 				myState = FEL_FORMAT;
 			}
 			break;
 		case FE_AUTHOR:
-			if (tagPrefix == myAtomNamespaceId) {
-				if (tagName == TAG_NAME) {
-					myState = FEA_NAME;
-				} else if (tagName == TAG_URI) {
-					myState = FEA_URI;
-				} else if (tagName == TAG_EMAIL) {
-					myState = FEA_EMAIL;
-				} 
+			if (testTag(ZLXMLNamespace::Atom, TAG_NAME, tag)) {
+				myState = FEA_NAME;
+			} else if (testTag(ZLXMLNamespace::Atom, TAG_URI, tag)) {
+				myState = FEA_URI;
+			} else if (testTag(ZLXMLNamespace::Atom, TAG_EMAIL, tag)) {
+				myState = FEA_EMAIL;
 			}
 			break;
 		case FE_CONTENT:
-			if (tagName == TAG_HACK_SPAN || attributeMap["class"] == "price") {
+			if (TAG_HACK_SPAN == tag || attributeMap["class"] == "price") {
 				myState = FEC_HACK_SPAN;
 			}
 			break;
@@ -267,35 +228,28 @@ void OPDSXMLParser::startElementHandler(const char *tag, const char **attributes
 }
 
 void OPDSXMLParser::endElementHandler(const char *tag) {
-	std::string tagPrefix;
-	std::string tagName = tag;
-	const int index = tagName.find(':');
-	if (index != -1) {
-		tagPrefix = tagName.substr(0, index);
-		tagName.erase(0, index + 1);
-	}
-	ZLStringUtil::stripWhiteSpaces(myBuffer);
+	ZLUnicodeUtil::utf8Trim(myBuffer);
 
 	switch (myState) {
 		case START:
 			break;
 		case FEED:
-			if (tagPrefix == myAtomNamespaceId && tagName == TAG_FEED) {
+			if (testTag(ZLXMLNamespace::Atom, TAG_FEED, tag)) {
 				myFeedReader->processFeedMetadata(myFeed);
 				myFeed.reset();
 				myFeedReader->processFeedEnd();
 				myState = START;
-			} 
+			}
 			break;
 		case F_ENTRY:
-			if (tagPrefix == myAtomNamespaceId && tagName == TAG_ENTRY) {
+			if (testTag(ZLXMLNamespace::Atom, TAG_ENTRY, tag)) {
 				myFeedReader->processFeedEntry(myEntry);
 				myEntry.reset();
 				myState = FEED;
 			}
 			break;
 		case F_ID:
-			if (tagPrefix == myAtomNamespaceId && tagName == TAG_ID) {
+			if (testTag(ZLXMLNamespace::Atom, TAG_ID, tag)) {
 				// FIXME:uri can be lost:buffer will be truncated, if there are extension tags inside the <id> tag
 				myId->setUri(myBuffer);
 				if (!myFeed.isNull()) {
@@ -303,38 +257,64 @@ void OPDSXMLParser::endElementHandler(const char *tag) {
 				}
 				myId.reset();
 				myState = FEED;
-			} 
+			}
+			break;
+		case F_ICON:
+			if (testTag(ZLXMLNamespace::Atom, TAG_ICON, tag)) {
+				myIcon->setUri(myBuffer);
+				if (!myFeed.isNull()) {
+					myFeed->setIcon(myIcon);
+				}
+				myIcon.reset();
+				myState = FEED;
+			}
 			break;
 		case F_LINK:
-			if (tagPrefix == myAtomNamespaceId && tagName == TAG_LINK) {
+			if (testTag(ZLXMLNamespace::Atom, TAG_LINK, tag)) {
 				if (!myFeed.isNull()) {
 					myFeed->links().push_back(myLink);
 				}
 				myLink.reset();
 				myState = FEED;
-			} 
+			}
 			break;
 		case F_CATEGORY:
-			if (tagPrefix == myAtomNamespaceId && tagName == TAG_CATEGORY) {
+			if (testTag(ZLXMLNamespace::Atom, TAG_CATEGORY, tag)) {
 				if (!myFeed.isNull()) {
 					myFeed->categories().push_back(myCategory);
 				}
 				myCategory.reset();
 				myState = FEED;
-			} 
+			}
 			break;
 		case F_TITLE:
-			if (tagPrefix == myAtomNamespaceId && tagName == TAG_TITLE) {
+			if (testTag(ZLXMLNamespace::Atom, TAG_TITLE, tag)) {
 				// FIXME:title can be lost:buffer will be truncated, if there are extension tags inside the <title> tag
 				// TODO:implement ATOMTextConstruct & ATOMTitle
 				if (!myFeed.isNull()) {
 					myFeed->setTitle(myBuffer);
 				}
 				myState = FEED;
-			} 
+			}
+			break;
+		case F_SUBTITLE:
+			if (testTag(ZLXMLNamespace::Atom, TAG_SUBTITLE, tag)) {
+				if (!myFeed.isNull()) {
+					myFeed->setSubtitle(myBuffer);
+				}
+				myState = FEED;
+			}
+			break;
+		case F_SUMMARY:
+			if (testTag(ZLXMLNamespace::Atom, TAG_SUMMARY, tag)) {
+				if (!myFeed.isNull()) {
+					myFeed->setSummary(myBuffer);
+				}
+				myState = FEED;
+			}
 			break;
 		case F_UPDATED:
-			if (tagPrefix == myAtomNamespaceId && tagName == TAG_UPDATED) {
+			if (testTag(ZLXMLNamespace::Atom, TAG_UPDATED, tag)) {
 				// FIXME:uri can be lost:buffer will be truncated, if there are extension tags inside the <id> tag
 				ATOMDateConstruct::parse(myBuffer, *myUpdated);
 				if (!myFeed.isNull()) {
@@ -342,74 +322,84 @@ void OPDSXMLParser::endElementHandler(const char *tag) {
 				}
 				myUpdated.reset();
 				myState = FEED;
-			} 
+			}
 			break;
 		case F_AUTHOR:
-			if (tagPrefix == myAtomNamespaceId && tagName == TAG_AUTHOR) {
+			if (testTag(ZLXMLNamespace::Atom, TAG_AUTHOR, tag)) {
 				if (!myFeed.isNull()) {
 					myFeed->authors().push_back(myAuthor);
 				}
 				myAuthor.reset();
 				myState = FEED;
-			} 
+			}
 			break;
 		case FA_NAME:
-			if (tagPrefix == myAtomNamespaceId && tagName == TAG_NAME) {
+			if (testTag(ZLXMLNamespace::Atom, TAG_NAME, tag)) {
 				myAuthor->setName(myBuffer);
 				myState = F_AUTHOR;
 			}
 			break;
 		case FEA_NAME:
-			if (tagPrefix == myAtomNamespaceId && tagName == TAG_NAME) {
+			if (testTag(ZLXMLNamespace::Atom, TAG_NAME, tag)) {
 				myAuthor->setName(myBuffer);
 				myState = FE_AUTHOR;
 			}
 			break;
 		case FEL_PRICE:
-			if (tagPrefix == myOpdsNamespaceId && tagName == TAG_PRICE) {
+			if (testTag(ZLXMLNamespace::Opds, TAG_PRICE, tag)) {
 				myLink->setUserData(KEY_PRICE, myBuffer);
 				myState = FE_LINK;
 			}
 			break;
 		case FEL_FORMAT:
-			if (tagPrefix == myDublinCoreNamespaceId && tagName == DC_TAG_FORMAT) {
+			if (testTag(ZLXMLNamespace::DublinCoreTerms, DC_TAG_FORMAT, tag)) {
 				myLink->setUserData(KEY_FORMAT, myBuffer);
 				myState = FE_LINK;
 			}
 			break;
 		case FA_URI:
-			if (tagPrefix == myAtomNamespaceId && tagName == TAG_URI) {
+			if (testTag(ZLXMLNamespace::Atom, TAG_URI, tag)) {
 				myAuthor->setUri(myBuffer);
 				myState = F_AUTHOR;
 			}
 			break;
 		case FEA_URI:
-			if (tagPrefix == myAtomNamespaceId && tagName == TAG_URI) {
+			if (testTag(ZLXMLNamespace::Atom, TAG_URI, tag)) {
 				myAuthor->setUri(myBuffer);
 				myState = FE_AUTHOR;
 			}
 			break;
 		case FA_EMAIL:
-			if (tagPrefix == myAtomNamespaceId && tagName == TAG_EMAIL) {
+			if (testTag(ZLXMLNamespace::Atom, TAG_EMAIL, tag)) {
 				myAuthor->setEmail(myBuffer);
 				myState = F_AUTHOR;
 			}
 			break;
 		case FEA_EMAIL:
-			if (tagPrefix == myAtomNamespaceId && tagName == TAG_EMAIL) {
+			if (testTag(ZLXMLNamespace::Atom, TAG_EMAIL, tag)) {
 				myAuthor->setEmail(myBuffer);
 				myState = FE_AUTHOR;
 			}
 			break;
 		case FE_AUTHOR:
-			if (tagPrefix == myAtomNamespaceId && tagName == TAG_AUTHOR) {
+			if (testTag(ZLXMLNamespace::Atom, TAG_AUTHOR, tag)) {
 				myEntry->authors().push_back(myAuthor);
 				myAuthor.reset();
 				myState = F_ENTRY;
-			} 
+			}
+			break;
+		case FE_ICON:
+			if (testTag(ZLXMLNamespace::Atom, TAG_ICON, tag)) {
+				myIcon->setUri(myBuffer);
+				if (!myEntry.isNull()) {
+					myEntry->setIcon(myIcon);
+				}
+				myIcon.reset();
+				myState = F_ENTRY;
+			}
 			break;
 		case FE_ID:
-			if (tagPrefix == myAtomNamespaceId && tagName == TAG_ID) {
+			if (testTag(ZLXMLNamespace::Atom, TAG_ID, tag)) {
 				// FIXME:uri can be lost:buffer will be truncated, if there are extension tags inside the <id> tag
 				myId->setUri(myBuffer);
 				myEntry->setId(myId);
@@ -418,21 +408,21 @@ void OPDSXMLParser::endElementHandler(const char *tag) {
 			}
 			break;
 		case FE_CATEGORY:
-			if (tagPrefix == myAtomNamespaceId && tagName == TAG_CATEGORY) {
+			if (testTag(ZLXMLNamespace::Atom, TAG_CATEGORY, tag)) {
 				myEntry->categories().push_back(myCategory);
 				myCategory.reset();
 				myState = F_ENTRY;
 			}
 			break;
 		case FE_LINK:
-			if (tagPrefix == myAtomNamespaceId && tagName == TAG_LINK) {
+			if (testTag(ZLXMLNamespace::Atom, TAG_LINK, tag)) {
 				myEntry->links().push_back(myLink);
 				myLink.reset();
 				myState = F_ENTRY;
 			}
 			break;
 		case FE_PUBLISHED:
-			if (tagPrefix == myAtomNamespaceId && tagName == TAG_PUBLISHED) {
+			if (testTag(ZLXMLNamespace::Atom, TAG_PUBLISHED, tag)) {
 				// FIXME:uri can be lost:buffer will be truncated, if there are extension tags inside the <id> tag
 				ATOMDateConstruct::parse(myBuffer, *myPublished);
 				myEntry->setPublished(myPublished);
@@ -441,7 +431,7 @@ void OPDSXMLParser::endElementHandler(const char *tag) {
 			}
 			break;
 		case FE_SUMMARY:
-			if (tagPrefix == myAtomNamespaceId && tagName == TAG_SUMMARY) {
+			if (testTag(ZLXMLNamespace::Atom, TAG_SUMMARY, tag)) {
 				// FIXME:summary can be lost:buffer will be truncated, if there are extension tags inside the <summary> tag
 				// TODO:implement ATOMTextConstruct & ATOMSummary
 				myEntry->setSummary(myBuffer);
@@ -450,7 +440,7 @@ void OPDSXMLParser::endElementHandler(const char *tag) {
 			}
 			break;
 		case FE_CONTENT:
-			if (tagPrefix == myAtomNamespaceId && tagName == TAG_CONTENT) {
+			if (testTag(ZLXMLNamespace::Atom, TAG_CONTENT, tag)) {
 				// TODO:check this accurately
 				if (!mySummaryTagFound) {
 					myEntry->setSummary(myBuffer);
@@ -463,7 +453,7 @@ void OPDSXMLParser::endElementHandler(const char *tag) {
 			myState = FE_CONTENT;
 			break;
 		case FE_SUBTITLE:
-			if (tagPrefix == myAtomNamespaceId && tagName == TAG_SUBTITLE) {
+			if (testTag(ZLXMLNamespace::Atom, TAG_SUBTITLE, tag)) {
 				// TODO:check this accurately
 				if (!mySummaryTagFound) {
 					myEntry->setSummary(myBuffer);
@@ -472,7 +462,7 @@ void OPDSXMLParser::endElementHandler(const char *tag) {
 			}
 			break;
 		case FE_TITLE:
-			if (tagPrefix == myAtomNamespaceId && tagName == TAG_TITLE) {
+			if (testTag(ZLXMLNamespace::Atom, TAG_TITLE, tag)) {
 				// FIXME:title can be lost:buffer will be truncated, if there are extension tags inside the <title> tag
 				// TODO:implement ATOMTextConstruct & ATOMTitle
 				myEntry->setTitle(myBuffer);
@@ -484,7 +474,7 @@ void OPDSXMLParser::endElementHandler(const char *tag) {
 			}
 			break;
 		case FE_UPDATED:
-			if (tagPrefix == myAtomNamespaceId && tagName == TAG_UPDATED) {
+			if (testTag(ZLXMLNamespace::Atom, TAG_UPDATED, tag)) {
 				// FIXME:uri can be lost:buffer will be truncated, if there are extension tags inside the <id> tag
 				ATOMDateConstruct::parse(myBuffer, *myUpdated);
 				myEntry->setUpdated(myUpdated);
@@ -493,14 +483,14 @@ void OPDSXMLParser::endElementHandler(const char *tag) {
 			}
 			break;
 		case FE_DC_LANGUAGE:
-			if (tagPrefix == myDublinCoreNamespaceId && tagName == DC_TAG_LANGUAGE) {
+			if (testTag(ZLXMLNamespace::DublinCoreTerms, DC_TAG_LANGUAGE, tag)) {
 				// FIXME:language can be lost:buffer will be truncated, if there are extension tags inside the <dc:language> tag
 				myEntry->setDCLanguage(myBuffer);
 				myState = F_ENTRY;
 			}
 			break;
 		case FE_DC_ISSUED:
-			if (tagPrefix == myDublinCoreNamespaceId && tagName == DC_TAG_ISSUED) {
+			if (testTag(ZLXMLNamespace::DublinCoreTerms, DC_TAG_ISSUED, tag)) {
 				// FIXME:issued can be lost:buffer will be truncated, if there are extension tags inside the <dc:issued> tag
 				DCDate *issued = new DCDate();
 				ATOMDateConstruct::parse(myBuffer, *issued);
@@ -509,28 +499,27 @@ void OPDSXMLParser::endElementHandler(const char *tag) {
 			}
 			break;
 		case FE_DC_PUBLISHER:
-			if (tagPrefix == myDublinCoreNamespaceId && tagName == DC_TAG_PUBLISHER) {
+			if (testTag(ZLXMLNamespace::DublinCoreTerms, DC_TAG_PUBLISHER, tag)) {
 				// FIXME:publisher can be lost:buffer will be truncated, if there are extension tags inside the <dc:publisher> tag
 				myEntry->setDCPublisher(myBuffer);
 				myState = F_ENTRY;
 			}
 			break;
 		case FE_CALIBRE_SERIES:
-			if (tagPrefix == myCalibreNamespaceId && tagName == CALIBRE_TAG_SERIES) {
+			if (testTag(ZLXMLNamespace::CalibreMetadata, CALIBRE_TAG_SERIES, tag)) {
 				myEntry->setSeriesTitle(myBuffer);
 				myState = F_ENTRY;
 			}
 			break;
 		case FE_CALIBRE_SERIES_INDEX:
-			if (tagPrefix == myCalibreNamespaceId && tagName == CALIBRE_TAG_SERIES_INDEX) {
-				myEntry->setSeriesIndex(atoi(myBuffer.c_str()));
+			if (testTag(ZLXMLNamespace::CalibreMetadata, CALIBRE_TAG_SERIES_INDEX, tag)) {
+				myEntry->setSeriesIndex(std::atoi(myBuffer.c_str()));
 				myState = F_ENTRY;
 			}
 			break;
 		case OPENSEARCH_TOTALRESULTS:
-			if (tagPrefix == myOpenSearchNamespaceId &&
-					tagName == OPENSEARCH_TAG_TOTALRESULTS) {
-				int number = atoi(myBuffer.c_str());
+			if (testTag(ZLXMLNamespace::OpenSearch, OPENSEARCH_TAG_TOTALRESULTS, tag)) {
+				int number = std::atoi(myBuffer.c_str());
 				if (!myFeed.isNull()) {
 					myFeed->setOpensearchTotalResults(number);
 				}
@@ -538,9 +527,8 @@ void OPDSXMLParser::endElementHandler(const char *tag) {
 			}
 			break;
 		case OPENSEARCH_ITEMSPERPAGE:
-			if (tagPrefix == myOpenSearchNamespaceId &&
-					tagName == OPENSEARCH_TAG_ITEMSPERPAGE) {
-				int number = atoi(myBuffer.c_str());
+			if (testTag(ZLXMLNamespace::OpenSearch, OPENSEARCH_TAG_ITEMSPERPAGE, tag)) {
+				int number = std::atoi(myBuffer.c_str());
 				if (!myFeed.isNull()) {
 					myFeed->setOpensearchItemsPerPage(number);
 				}
@@ -548,9 +536,8 @@ void OPDSXMLParser::endElementHandler(const char *tag) {
 			}
 			break;
 		case OPENSEARCH_STARTINDEX:
-			if (tagPrefix == myOpenSearchNamespaceId &&
-					tagName == OPENSEARCH_TAG_STARTINDEX) {
-				int number = atoi(myBuffer.c_str());
+			if (testTag(ZLXMLNamespace::OpenSearch, OPENSEARCH_TAG_STARTINDEX, tag)) {
+				int number = std::atoi(myBuffer.c_str());
 				if (!myFeed.isNull()) {
 					myFeed->setOpensearchStartIndex(number);
 				}
@@ -562,6 +549,6 @@ void OPDSXMLParser::endElementHandler(const char *tag) {
 	myBuffer.clear();
 }
 
-void OPDSXMLParser::characterDataHandler(const char *data, size_t len) {
+void OPDSXMLParser::characterDataHandler(const char *data, std::size_t len) {
 	myBuffer.append(data, len);
 }
