@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2012 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -62,12 +62,3 @@ ZLColorOption &FBOptions::colorOption(const std::string &style) {
 		myColorOptions.find(style);
 	return it != myColorOptions.end() ? *it->second : RegularTextColorOption;
 }
-
-void FBOptions::resynchColorOptions() {
-	BackgroundColorOption.synchronizeFromConfig();
-	RegularTextColorOption.synchronizeFromConfig();
-
-	for (std::map<std::string,shared_ptr<ZLColorOption> >::const_iterator it = myColorOptions.begin(); it != myColorOptions.end(); it++) {
-		it->second->synchronizeFromConfig();
-	}
-}
